@@ -18,6 +18,7 @@ class TestACLS(unittest.TestCase):
         """Ensure pineboo is initialized for testing."""
         init_testing()
         utils_base.FORCE_DESKTOP = True
+        application.PROJECT.db_admin_mode = True
 
         # Install package
         qsa_sys = qsa.qsa.sys
@@ -308,7 +309,7 @@ class TestACLS(unittest.TestCase):
 
         main_form_class = getattr(eneboo, "MainForm", None)
         self.assertTrue(main_form_class)
-        application.PROJECT.main_window = main_form_class()
+        application.PROJECT.main_window = main_form_class()  # type: ignore[misc]
 
         sys_type = systype.SysType()
         sys_type.installACL("tercera")
@@ -335,13 +336,13 @@ class TestACLS(unittest.TestCase):
         application.PROJECT.aq_app.set_acl(acl)
 
         settings.CONFIG.set_value("application/dbadmin_enabled", True)
-        application.PROJECT._db_admin_mode = True
+        application.PROJECT.db_admin_mode = True
         project = application.PROJECT
         # project.main_form = eneboo
         main_form_class = getattr(eneboo, "MainForm", None)
         # main_form_ = getattr(project.main_form, "MainForm", None)
         self.assertTrue(main_form_class)
-        self.main_w = main_form_class()
+        self.main_w = main_form_class()  # type: ignore[misc]
         project.main_window = self.main_w
         self.main_w.initScript()
         self.main_w.show()
@@ -378,7 +379,7 @@ class TestACLS(unittest.TestCase):
         main_form_class = getattr(eneboo, "MainForm", None)
         # main_form_ = getattr(project.main_form, "MainForm", None)
         self.assertTrue(main_form_class)
-        self.main_w = main_form_class()
+        self.main_w = main_form_class()  # type: ignore[misc]
         project.main_window = self.main_w
         self.main_w.initScript()
         self.main_w.show()
@@ -404,7 +405,7 @@ class TestACLS(unittest.TestCase):
         main_form_class = getattr(eneboo, "MainForm", None)
         # main_form_ = getattr(project.main_form, "MainForm", None)
         self.assertTrue(main_form_class)
-        self.main_w = main_form_class()
+        self.main_w = main_form_class()  # type: ignore[misc]
         project.main_window = self.main_w
         self.main_w.initScript()
         self.main_w.show()
