@@ -1,5 +1,6 @@
 """Basemodel module."""
 
+from pineboolib.core import decorators
 from pineboolib.core.utils import logging
 from pineboolib.application.metadata import pnrelationmetadata
 from pineboolib.application import qsadictmodules
@@ -10,7 +11,7 @@ from pineboolib.application.database.orm import dummy_cursor, dummy_signal
 
 from typing import Optional, List, Dict, Union, Callable, Any, TYPE_CHECKING
 
-from sqlalchemy import orm, inspect
+from sqlalchemy import orm, inspect  # type: ignore [import]
 import datetime
 import sys
 import time
@@ -36,6 +37,7 @@ class BaseModel(object):
     """Base Model class."""
 
     __tablename__: str = ""
+    __mapper_args__: Dict[str, Any] = {"confirm_deleted_rows": False}
 
     _session: Optional["orm.session.Session"]
     _buffer_copy: "Copy"
@@ -86,9 +88,7 @@ class BaseModel(object):
             conn_manager = application.PROJECT.conn_manager
             if "conn_name" in kwargs.keys():
                 conn_name = kwargs["conn_name"]
-
             target._session = conn_manager.useConn(conn_name).session()
-
         if target._session is None:
             target._error_manager(
                 "_qsa_init",
@@ -98,6 +98,8 @@ class BaseModel(object):
 
         target._new_object = True
         target.counter = False
+        target.no_init = False
+        target.serial = True
 
         if "serial" in kwargs:
             target.serial = kwargs["serial"]
@@ -249,7 +251,7 @@ class BaseModel(object):
             original_value = getattr(self._buffer_copy, field_name, None)
             current_value = getattr(self, field_name)
 
-            if type(original_value) != type(current_value):
+            if type(original_value) != type(current_value):  # noqa: E721
                 changes[field_name] = current_value
             elif original_value != current_value:
                 changes[field_name] = current_value
@@ -305,7 +307,7 @@ class BaseModel(object):
         """Flush instance to current session."""
 
         if self._session:
-            # if not self._session.transaction:
+            # if not self._session.in_transaction():
             #    self._session.begin()
             # else:
             #    self._session.begin_nested()
@@ -323,15 +325,12 @@ class BaseModel(object):
         for field in self.table_metadata().fieldList():
             relation_list = field.relationList()
             for relation in relation_list:
-
                 foreign_table_mtd = application.PROJECT.conn_manager.manager().metadata(
                     relation.foreignTable()
                 )
                 if foreign_table_mtd is not None:
-
                     foreign_field_mtd = foreign_table_mtd.field(relation.foreignField())
                     if foreign_field_mtd is not None:
-
                         relation_m1 = foreign_field_mtd.relationM1()
                         if relation_m1 is not None and relation_m1.deleteCascade():
                             foreign_table_class = qsadictmodules.QSADictModules.orm_(
@@ -364,7 +363,6 @@ class BaseModel(object):
         if self._session is None:
             self._error_manager("_flush", "_session is empty")
         else:
-
             self._current_mode = self.mode_access
             if not only or "before_flush" in only:
                 self._before_flush()
@@ -391,7 +389,6 @@ class BaseModel(object):
                             ignore_foreignkey=True,
                         )
                 try:
-
                     flush_objects = [self]
                     for relation in relations:
                         list_objects = getattr(self, relation, [])
@@ -516,11 +513,19 @@ class BaseModel(object):
     @classmethod
     def get(cls, pk_value: str, session: Union[str, "orm.Session"] = "default") -> Any:
         """Return instance selected by pk."""
-        qry = cls.query(session)
-        ret_ = qry.get(pk_value) if qry is not None else None
-        return ret_
+        # qry = cls.query(session)
+        # ret_ = qry.get(pk_value) if qry is not None else None
+
+        session_ = (
+            application.PROJECT.conn_manager.useConn(session).session()
+            if isinstance(session, str)
+            else session
+        )
+
+        return session_.get(cls, pk_value) if session_ else None  # type: ignore [attr-defined]
 
     @classmethod
+    @decorators.deprecated
     def query(
         cls, session_or_name: Union[str, "orm.Session"] = "default"
     ) -> Optional["orm.query.Query"]:
@@ -539,7 +544,9 @@ class BaseModel(object):
                 ret_ = session_.query(cls)
 
         if ret_ is None:
-            LOGGER.warning("query: Invalid session %s ", session_or_name)
+            LOGGER.warning(  # type: ignore [unreachable]
+                "query: Invalid session %s " % session_or_name
+            )
 
         return ret_
 
@@ -611,7 +618,6 @@ class BaseModel(object):
             )
 
         else:
-
             if self._session is None:
                 self._error_manager("save", "_session is empty!")
             elif self.mode_access == 2:
@@ -619,14 +625,12 @@ class BaseModel(object):
                     "save", "you are trying to save an instance in the process of deletion!"
                 )
             else:
-
                 if self.mode_access == 0:  # insert
                     self._session.add(self)
 
                 self._flush(relations)
 
             self.update_copy()
-
             return True
         return False
 
@@ -638,10 +642,8 @@ class BaseModel(object):
         table_meta = self.table_metadata()
 
         if not table_meta.isQuery():
-
             for field in table_meta.fieldList():
                 field_name = field.name()
-
                 if mode < 2:  # 0 insert,1 edit
                     # not Null fields.
                     if not field.allowNull():
@@ -651,18 +653,21 @@ class BaseModel(object):
                                 "_check_integrity",
                                 "INTEGRITY::Field %s.%s need a value"
                                 % (table_meta.name(), field_name),
+                                self,
                             )
                         elif field.type() == "date" and not isinstance(value, datetime.date):
                             self._error_manager(
                                 "_check_integrity",
                                 "INTEGRITY::Type Error %s.%s -> Value must be a datetime.date type, but found %s type"
                                 % (table_meta.name(), field_name, type(value)),
+                                self,
                             )
                         elif field.type() == "time" and not isinstance(value, datetime.time):
                             self._error_manager(
                                 "_check_integrity",
                                 "INTEGRITY::Type Error %s.%s -> Value must be a datetime.time type, but found %s type"
                                 % (table_meta.name(), field_name, type(value)),
+                                self,
                             )
 
                 # para poder comprobar relaciones , tengo que mirar primero que los campos not null esten ok, si no , da error.
@@ -696,6 +701,7 @@ class BaseModel(object):
                                     value,
                                     " Use None instead of False" if not value else "",
                                 ),
+                                self,
                             )
 
                         qry_data = None
@@ -712,6 +718,7 @@ class BaseModel(object):
                                 "_check_integrity",
                                 "INTEGRITY::Field relation %s.%s -> %s"
                                 % (table_meta.name(), field_name, error),
+                                self,
                             )
                         # qry_data = (
                         #    foreign_class_.query(self._session)
@@ -733,7 +740,6 @@ class BaseModel(object):
                             and (not field.allowNull() or value)
                             and not ignore_foreignkey
                         ):
-
                             self._error_manager(
                                 "_check_integrity",
                                 "INTEGRITY::Relation %s.%s M1 %s.%s with value '%s' type(%s) is invalid"
@@ -745,6 +751,7 @@ class BaseModel(object):
                                     value,
                                     type(value),
                                 ),
+                                self,
                             )
 
                     elif not field.allowNull():
@@ -757,6 +764,7 @@ class BaseModel(object):
                                 relation_m1.foreignTable(),
                                 relation_m1.foreignField(),
                             ),
+                            self,
                         )
 
         return True
@@ -764,6 +772,7 @@ class BaseModel(object):
     def relationM1(self, field_name: str = "") -> Optional[Callable]:
         """Return relationM1 object if exists."""
 
+        ret_ = None
         if field_name:
             meta = self.table_metadata().field(field_name)
             if meta is not None:
@@ -774,14 +783,15 @@ class BaseModel(object):
                     )
                     if foreign_table_class is not None:
                         foreign_field_obj = getattr(foreign_table_class, meta_rel.foreignField())
-                        return (
+
+                        ret_ = (
                             self._session.query(  # type: ignore [union-attr] # noqa: F821
                                 foreign_table_class
                             )
                             .filter(foreign_field_obj == getattr(self, field_name))
                             .first()
                         )
-        return None
+        return ret_
 
     def relation1M(self, field_name: str = "") -> Dict[str, List[Callable]]:
         """Return relationed instances."""
@@ -815,10 +825,20 @@ class BaseModel(object):
         """Return current transaction level."""
 
         ret_ = -1
-        parent_transaction = self._session.transaction if self._session else None
-        while parent_transaction:
+        current_transaction = None
+        if self._session:
+            if self._session.in_nested_transaction():  # type: ignore [attr-defined]
+                current_transaction = self._session.get_nested_transaction()  # type: ignore [attr-defined]
+            elif self._session.in_transaction():  # type: ignore [attr-defined]
+                current_transaction = self._session.get_transaction()  # type: ignore [attr-defined]
+
+        while True:
+            if current_transaction is None:
+                break
+
             ret_ += 1
-            parent_transaction = parent_transaction.parent
+
+            current_transaction = current_transaction.parent
 
         return ret_
 
@@ -925,7 +945,6 @@ class BaseModel(object):
         """Change slot."""
 
         if hasattr(target, "_deny_buffer_changed"):
-
             # Si no hay funciones conectadas , me voy.
             if not hasattr(target, "bufferChanged") or not target.bufferChanged._remote_funcs:
                 return
@@ -946,7 +965,7 @@ class BaseModel(object):
                 del target._cached_bufferchanged[event.key]
 
     @classmethod
-    def _error_manager(cls, text: str, error: Union[Exception, str]) -> None:
+    def _error_manager(cls, text: str, error: Union[Exception, str], obj: object = None) -> None:
         """Return custom error message."""
 
         exception_: Any = None
@@ -993,7 +1012,7 @@ class BaseModel(object):
     def init_serial(self) -> None:
         """Initialice serial field."""
         if (
-            self.type(self.pk_name) == "serial"
+            self.type(self.pk_name) == "serial"  # noqa E721
             and getattr(self, self.pk_name, None) is None
             and self._session is not None
         ):
