@@ -5,11 +5,11 @@ from typing import List, Any, TYPE_CHECKING
 
 from pineboolib.application import qsadictmodules
 from pineboolib.core.utils import logging
-import sqlalchemy
+import sqlalchemy  # type: ignore [import]
 
 if TYPE_CHECKING:
-    from sqlalchemy.ext import declarative  # pragma: no cover
-    from sqlalchemy.orm import query  # pragma: no cover
+    from sqlalchemy.ext import declarative  # type: ignore [import] # pragma: no cover
+    from sqlalchemy.orm import query  # type: ignore [import] # pragma: no cover
     from sqlalchemy.orm import Session
 
 
@@ -93,7 +93,6 @@ class DynamicFilter(object):
             list_ = filter_str.split(" ")
 
             for number, part in enumerate(list_):
-
                 if part.find("_|_space_|_") > -1:
                     part = part.replace("_|_space_|_", " ")
 
@@ -103,6 +102,7 @@ class DynamicFilter(object):
 
                 if not part:
                     continue
+
                 if part.startswith("upper("):
                     item.append("upper")
                     part = part[6:-1]
@@ -114,13 +114,12 @@ class DynamicFilter(object):
 
                     part = part.replace("'", "")
 
-                elif part.lower() in ["and", "or"]:
+                elif part.lower() in ["and", "or"] and list_[number - 2] != "eq":
                     filter_list.append(item)
                     item = []
                     part = part.lower()
 
                 item.append(part)
-
             if item and item != ["1", "eq", "1"]:
                 filter_list.append(item)
 
@@ -255,7 +254,7 @@ class DynamicFilter(object):
             query_ = query_.filter(filt)
 
         for name, ord in self.order_by:
-            column_order = getattr(model_class, name, None)
+            column_order = getattr(model_class, name)
             query_ = query_.order_by(column_order.desc() if ord == "desc" else column_order.asc())
 
         return query_
