@@ -18,7 +18,7 @@ from typing import List, Optional, Any, Union, TYPE_CHECKING
 if TYPE_CHECKING:
     from pineboolib.interfaces import isqlcursor, isqldriver, isession  # pragma: no cover
     from pineboolib.application.metadata import pntablemetadata  # pragma: no cover
-    from sqlalchemy.engine import base, result  # pragma: no cover
+    from sqlalchemy.engine import base, result  # type: ignore [import] # pragma: no cover
 
     from pineboolib.application.database import pnconnectionmanager  # pragma: no cover
 
@@ -272,7 +272,7 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
             text_ = (
                 "Creando punto de salvaguarda %s:%s" % (self._name, self._transaction_level)
                 if self._transaction_level
-                else "Iniciando Transacción... %s" % self._transaction_level
+                else "Iniciando Transacción... %s:%s" % (self._name, self._transaction_level)
             )
             application.PROJECT.message_manager().send("status_help_msg", "send", [text_])
 
@@ -289,7 +289,7 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
             application.PROJECT.aq_app.emitTransactionBegin(cursor)
 
         self._transaction_level += 1
-        cursor.private_cursor._transactions_opened.insert(0, self._transaction_level)
+        cursor.private_cursor._transactions_opened.append(self._transaction_level)
         return True
 
     def transactionLevel(self) -> int:
@@ -306,7 +306,6 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
             and cur.isModifiedBuffer()
             and cur.private_cursor._ask_for_cancel_changes
         ):
-
             msg_box = getattr(application.PROJECT.DGI, "msgBoxQuestion", None)
             if msg_box is not None:
                 res = msg_box(
@@ -345,7 +344,7 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
                 self._transaction_level,
             )
         else:
-            text_ = "Deshaciendo Transacción... %s" % self._transaction_level
+            text_ = "Deshaciendo Transacción... %s:%s" % (self._name, self._transaction_level)
 
         application.PROJECT.message_manager().send("status_help_msg", "send", [text_])
 
@@ -397,7 +396,6 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
 
             self._transaction_level -= 1
         else:
-
             return True
 
         if self._transaction_level:
@@ -406,7 +404,7 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
                 self._transaction_level,
             )
         else:
-            text_ = "Terminando Transacción... %s" % self._transaction_level
+            text_ = "Terminando Transacción... %s:%s" % (self._name, self._transaction_level)
 
         application.PROJECT.message_manager().send("status_help_msg", "send", [text_])
 
@@ -444,11 +442,13 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
     def transaction(self) -> bool:
         """Create a transaction."""
         try:
-
             session_ = self.session()
 
-            if not session_.transaction:
-                LOGGER.debug("ISOLATION LEVEL %s", session_.connection().get_isolation_level())
+            if not session_.in_transaction():  # type: ignore [attr-defined]
+                LOGGER.debug(
+                    "%s: ISOLATION LEVEL %s"
+                    % (self._name, session_.connection().get_isolation_level())
+                )
                 session_.begin()
             else:
                 session_.begin_nested()
@@ -463,10 +463,14 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
         """Release a transaction."""
 
         try:
-
             session_ = self.session()
-            session_.commit()
+            trans_ = (
+                session_.get_nested_transaction()  # type: ignore [attr-defined]
+                if session_.in_nested_transaction()  # type: ignore [attr-defined]
+                else session_.get_transaction()  # type: ignore [attr-defined]
+            )
 
+            trans_.commit()  # type: ignore [union-attr]
             return True
         except Exception as error:
             LOGGER.warning("Commit: %s", str(error), stack_info=True)
@@ -476,9 +480,16 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
 
     def rollback(self) -> bool:
         """Roll back a transaction."""
+
         try:
             session_ = self.session()
-            session_.rollback()
+            trans_ = (
+                session_.get_nested_transaction()  # type: ignore [attr-defined]
+                if session_.in_nested_transaction()  # type: ignore [attr-defined]
+                else session_.get_transaction()  # type: ignore [attr-defined]
+            )
+            trans_.rollback()  # type: ignore [union-attr]
+
             return True
         except Exception as error:
             self._last_error = "No se pudo deshacer la transacción: %s" % str(error)
@@ -536,7 +547,7 @@ class PNConnection(QtCore.QObject, iconnection.IConnection):
 
     #    return self.driver().queryUpdate(name, update, filter)
 
-    def execute_query(self, qry) -> Optional["result.ResultProxy"]:
+    def execute_query(self, qry) -> Optional["result.Result"]:  # type: ignore [name-defined]
         """Execute a query in a database cursor."""
 
         return self.driver().execute_query(qry)
