@@ -8,7 +8,7 @@ from PyQt6 import QtCore, QtGui, QtWidgets  # type: ignore[import]
 
 from pineboolib.core.utils import logging, utils_base
 
-from sqlalchemy import exc, orm, inspect
+from sqlalchemy import exc, orm, inspect  # type: ignore [import]
 from pineboolib.application.utils import date_conversion, xpm
 
 from pineboolib.application.database.orm import utils as orm_utils
@@ -345,7 +345,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                     result = "No"
 
             elif _type in ("unlock", "pixmap"):
-
                 result = None
 
             elif _type in ("string", "stringlist", "timestamp", "json"):
@@ -418,7 +417,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                             utils_base.filedir("./core/images/icons", "unlock.png")
                         )
                     elif result in (False, "0"):
-
                         pixmap = QtGui.QPixmap(
                             utils_base.filedir("./core/images/icons", "lock.png")
                         )
@@ -426,7 +424,7 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                     if not self._parent.private_cursor._is_system_table:
                         data = self.conn_manager.manager().fetchLargeValue(result)
                     else:
-                        data = xpm.cache_xpm(result)
+                        data = xpm.cache_xpm(result)  # type: ignore [arg-type]
 
                     pixmap = QtGui.QPixmap(data)
                     if not pixmap.isNull():
@@ -473,7 +471,7 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
             else:
                 if res_color_function and len(res_color_function) and res_color_function[0] != "":
                     color_ = QtGui.QColor(res_color_function[0])
-                    style_ = getattr(QtCore.Qt, res_color_function[2], None)
+                    style_ = getattr(QtCore.Qt, res_color_function[2])
                     result = QtGui.QBrush(color_)
                     result.setStyle(style_)
                 else:
@@ -490,7 +488,7 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
             else:
                 if res_color_function and len(res_color_function) and res_color_function[1] != "":
                     color_ = QtGui.QColor(res_color_function[1])
-                    style_ = getattr(QtCore.Qt, res_color_function[2], None)
+                    style_ = getattr(QtCore.Qt, res_color_function[2])
                     result = QtGui.QBrush(color_)
                     result.setStyle(style_)
                 else:
@@ -575,7 +573,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                             break
                     # Omito los campos que aparentemente no existen
                     if not found and not field.name() in self.sql_fields_omited:
-
                         if qry is None:
                             raise Exception("The qry is empty!")
 
@@ -644,10 +641,9 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                 return
 
         self._initialized = False
+        rows = self.rowCount()
 
-        if (
-            self._disable_refresh or self._parent.modeAccess() == self._parent.Del
-        ) and self.rowCount():
+        if (self._disable_refresh or self._parent.modeAccess() == self._parent.Del) and rows:
             return
 
         self._grid_obj = {}
@@ -659,7 +655,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
 
         parent = QtCore.QModelIndex()
 
-        rows = self.rowCount()
         self.beginRemoveRows(parent, 0, rows)
         self.endRemoveRows()
         if rows > 0:
@@ -682,7 +677,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
 
         # self._data_proxy = dynamic_filter_class.return_query()
         if self.metadata().isQuery():
-
             meta_qry = pnsqlquery.PNSqlQuery(self.metadata().query())
             if where_filter.strip().lower().startswith("order"):
                 order_by = where_filter.lower().replace("order by", "")
@@ -703,10 +697,10 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
         # print("COUNT", sql_count)
 
         # print("QUERY", sql_query)
-        result_query = self.session.execute(sql_query)
-        rows_loaded = result_query.rowcount
+        result_query = self.session.execute(sql_query)  # type: ignore [arg-type]
+        rows_loaded = result_query.rowcount  # type: ignore [attr-defined]
 
-        if rows_loaded == -1:
+        if rows_loaded == -1:  # Si rowcount no está disponible...
             sql_count = (
                 "SELECT COUNT(%s) FROM " % self.metadata().primaryKey()
                 + sql_query[sql_query.find(" FROM ") + 6 :]
@@ -717,11 +711,10 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                     sql_count += " WHERE 1 = 1"
                 sql_count = sql_count[: sql_count.find("ORDER BY")]
 
-            result_count = self.session.execute(sql_count)
-            rows_loaded = result_count.fetchone()[0]
+            result_count = self.session.execute(sql_count)  # type: ignore [arg-type]
+            rows_loaded = result_count.fetchone()[0]  # type: ignore [index]
 
         if rows_loaded > 0:
-
             self._data_proxy = ProxyIndex(result_query, rows_loaded)
 
             self.need_update = False
@@ -782,7 +775,7 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
             sql_query += " AND" if sql_query.find("WHERE") > -1 else " WHERE"
             sql_query += extra_where
 
-        result = self.session.execute(sql_query)
+        result = self.session.execute(sql_query)  # type: ignore [arg-type]
         new_data = result.fetchone()
 
         if new_data is None and mode in [1, 2]:  # mode 3 allways returns None
@@ -793,17 +786,15 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
             LOGGER.debug("data_proxy is empty!")
             return True
         elif (
-            mode == 1 and new_data[0] in self._data_proxy._cached_data
+            mode == 1 and new_data[0] in self._data_proxy._cached_data  # type: ignore [index]
         ):  # if exists dont need Insert.
             return True
 
         if mode == 1:  # Insert.
-
             if order_by:
                 LOGGER.warning("FIXME! update chache whit alternative order_by")
                 return False
             else:
-
                 current_pos = None
                 min_val = 0
                 max_val = self._data_proxy._total_rows
@@ -812,7 +803,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                     upper = None
 
                     if self.rowCount():
-
                         if current_pos is None:
                             current_pos = max_val // 2
 
@@ -840,14 +830,12 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                             if current_pos in (max_val, 0):
                                 upper = True
                             else:
-
                                 min_val = current_pos
                                 current_pos += (max_val - min_val) // 2
                         else:
                             if current_pos in (min_val, 0):
                                 upper = False
                             else:
-
                                 max_val = current_pos
                                 current_pos -= (max_val - min_val) // 2
 
@@ -858,7 +846,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                         current_pos = 0
 
                     if upper is not None:
-
                         if upper:
                             current_pos += 1
 
@@ -873,7 +860,7 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
             return True
 
         elif mode == 2:  # Edit.
-            self._data_proxy.update_pk(pk_value, new_data[0])
+            self._data_proxy.update_pk(pk_value, new_data[0])  # type: ignore [index]
 
             return True
 
@@ -897,7 +884,6 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                 or self._grid_obj[row] is not None
                 and inspect(self._grid_obj[row]).expired
             ):
-
                 query = orm_utils.DynamicFilter(
                     query=session_.query(self._parent._cursor_model),
                     model_class=self._parent._cursor_model,
@@ -909,7 +895,9 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
                 try:
                     self._grid_obj[row] = query.return_query().first()
                 except Exception as error:
-                    raise Exception("get_object_from_row %s (%s) : %s" % (row, pk_value, error))
+                    raise Exception(
+                        "get_object_from_row %s (%s) : %s" % (row, pk_value, error)
+                    ) from error
 
             return self._grid_obj[row]
 
@@ -991,7 +979,7 @@ class PNCursorTableModel(QtCore.QAbstractTableModel):
         if self.metadata().isQuery():
             self._refresh_field_info()
 
-    def rowCount(self, parent: QtCore.QModelIndex = None) -> int:
+    def rowCount(self, parent: Optional["QtCore.QModelIndex"] = None) -> int:
         """
         Get current row count.
 
