@@ -16,7 +16,7 @@ if TYPE_CHECKING:
     from pineboolib.interfaces.ifieldmetadata import IFieldMetaData  # noqa: F401 # pragma: no cover
     from pineboolib.interfaces import iconnection  # pragma: no cover
     from pineboolib.interfaces import isqldriver
-    from sqlalchemy.engine import result as result_engine
+    from sqlalchemy.engine import result as result_engine  # type: ignore [import]
     from pineboolib.application.types import Array  # noqa: F401 # pragma: no cover
     from pineboolib.application.database import pngroupbyquery  # noqa: F401 # pragma: no cover
     from pineboolib.application.database import pnparameterquery  # noqa: F401 # pragma: no cover
@@ -109,8 +109,8 @@ class PNSqlQuery(object):
     _is_active: bool
     _field_name_to_pos_dict: Optional[Dict[str, int]]
     _sql_inspector: "sql_tools.SqlInspector"
-    _row: Optional["result_engine.RowProxy"]
-    _datos: List["result_engine.RowProxy"]
+    _row: Optional["result_engine.Row"]  # type: ignore [name-defined]
+    _datos: List["result_engine.Row"]  # type: ignore [name-defined]
     _posicion: int
     _last_query: str
     private_query: "PNSqlQueryPrivate"
@@ -211,7 +211,7 @@ class PNSqlQuery(object):
         )  # type: ignore [misc] # noqa: F821, F401
         result = self.db().execute_query(sql)
         try:
-            self._datos = result.fetchall() if result and result.returns_rows else []
+            self._datos = result.fetchall() if result and result.returns_rows else []  # type: ignore [attr-defined]
         except Exception as error:
             LOGGER.exception("ERROR SQLQUERY!: %s", str(error))
             self._datos = []
@@ -339,7 +339,6 @@ class PNSqlQuery(object):
 
                 prev = ""
                 for child in select.split(sep):
-
                     field_ = prev + child
                     if field_.count("(") == field_.count(")"):
                         list_fields.append(field_)
@@ -357,7 +356,6 @@ class PNSqlQuery(object):
         if not list_fields and isinstance(select, str) and not "*" == select:
             self.private_query._field_list.append(select)
         else:
-
             # fieldListAux = s.split(sep)
             # for f in s:
             #    f = str(f).strip()
@@ -632,7 +630,7 @@ class PNSqlQuery(object):
         )
 
         try:
-            ret = self._row[pos] if self._row else None
+            ret = self._row[pos] if self._row else None  # type: ignore [index]
             return (
                 self.sql_inspector.resolve_empty_value(pos)
                 if ret in (None, "None")
@@ -657,7 +655,7 @@ class PNSqlQuery(object):
         if isinstance(field_name, str):
             pos_ = self.fieldNameToPos(field_name)
 
-            return self._row[pos_] in (None, "None")
+            return self._row[pos_] in (None, "None")  # type: ignore [index]
 
         raise Exception("isNull. field not found %s" % field_name)
 
@@ -796,7 +794,6 @@ class PNSqlQuery(object):
         """
         value_inspector = True
         if self.sql_inspector is not None:
-
             if self.sql_inspector._invalid_tables:
                 real_tables = self.db().tables()
                 for table_name in self.sql_inspector._invalid_tables:
