@@ -4,6 +4,7 @@ import unittest
 from pineboolib.loader.main import init_testing, finish_testing
 from pineboolib.core.utils import logging
 from pineboolib.application.database import pnsqlcursor
+from pineboolib.application.metadata import pnrelationmetadata
 from pineboolib import application
 from pineboolib.application.database.tests import fixture_path
 from pineboolib.core.utils import utils_base
@@ -217,7 +218,35 @@ class TestDeleteData(unittest.TestCase):
     def test_basic_3(self) -> None:
         """Delete data from a database."""
 
+        # añadir relación fake
+        relation_meta = pnrelationmetadata.PNRelationMetaData(
+            "fake", "idarea", pnrelationmetadata.PNRelationMetaData.RELATION_1M
+        )
+
         cursor = pnsqlcursor.PNSqlCursor("flareas")
+
+        field = cursor.metadata().field("idarea")
+        if field is not None:
+            field.addRelationMD(relation_meta)
+        else:
+            self.assertTrue(False, "No se encuentra el campo idarea (1)")
+
+        # comprobar si el cambio es persistente
+
+        metadata_cursor = cursor.metadata()
+        meta_field = metadata_cursor.field("idarea")
+        if meta_field is None:
+            self.assertTrue(False, "No se encuentra el campo idarea (2)")
+
+        relations = meta_field.relationList() if meta_field else []
+        found = False
+        for relation in relations:
+            if relation.foreignTable() == "fake":
+                found = True
+                break
+
+        self.assertTrue(found, "No se encuentra la relacion FAKE")
+
         cursor.setModeAccess(cursor.Insert)
         cursor.refreshBuffer()
         cursor.setValueBuffer("bloqueo", True)
@@ -225,21 +254,41 @@ class TestDeleteData(unittest.TestCase):
         cursor.setValueBuffer("descripcion", "Área de prueba T1")
         self.assertTrue(cursor.commitBuffer())
 
-        cursor2 = pnsqlcursor.PNSqlCursor("flmodules")
-        cursor2.setModeAccess(cursor2.Insert)
-        cursor2.refreshBuffer()
-        cursor2.setValueBuffer("idmodulo", "M1")
-        cursor2.setValueBuffer("idarea", "T1")
-        cursor2.setValueBuffer("descripcion", "Módulo T")
-        cursor2.setValueBuffer("version", "0.0")
-        cursor2.commitBuffer()
+        cursor.select("idarea = 'T1'")
+        self.assertTrue(cursor.first())
+        cursor.setModeAccess(cursor.Del)
+        cursor.refreshBuffer()
+        self.assertTrue(cursor.commitBuffer())
 
-        cursor3 = pnsqlcursor.PNSqlCursor("flareas")
-        cursor3.select("idarea = 'T1'")
-        self.assertTrue(cursor3.first())
-        cursor3.setModeAccess(cursor3.Del)
-        cursor3.refreshBuffer()
-        self.assertFalse(cursor3.commitBuffer())
+    def test_basic_4(self) -> None:
+        """Delete with relation errors."""
+        cursor = pnsqlcursor.PNSqlCursor("flareas")
+        cursor.setModeAccess(cursor.Insert)
+        cursor.refreshBuffer()
+        cursor.setValueBuffer("bloqueo", True)
+        cursor.setValueBuffer("idarea", "T")
+        cursor.setValueBuffer("descripcion", "Área de prueba T")
+        self.assertTrue(cursor.commitBuffer())
+
+        cursor.select("idarea ='T'")
+        first_result = cursor.first()
+        self.assertEqual(first_result, True)
+        size_1 = cursor.size()
+        self.assertEqual(size_1, 1, "tiene que devolver 1 y ha devuelto %s" % size_1)
+        cursor.setForwardOnly(True)
+        cursor.setModeAccess(cursor.Del)
+        cursor.refreshBuffer()
+
+        value_idarea = cursor.valueBuffer("idarea")
+        self.assertEqual(value_idarea, "T")
+        cursor.commitBuffer()
+        cursor.refresh()
+        size_2 = cursor.size()
+        self.assertEqual(size_2, 1)
+        cursor.setForwardOnly(False)
+        cursor.refresh()
+        size_3 = cursor.size()
+        self.assertEqual(size_3, 0, "Tiene que devolver 0 y ha devuelto %s" % size_3)
 
     @classmethod
     def tearDownClass(cls) -> None:
@@ -256,7 +305,6 @@ class TestMove(unittest.TestCase):
         init_testing()
 
     def test_basic(self) -> None:
-
         from pineboolib.application.database import pnsqlcursor
 
         cursor = pnsqlcursor.PNSqlCursor("flareas")
@@ -760,7 +808,6 @@ class TestRelations(unittest.TestCase):
     def test_basic_relations_1(self) -> None:
         """Test basic relations 1."""
         from pineboolib.application.database import pnsqlcursor
-        from pineboolib.application.metadata import pnrelationmetadata
 
         cur_areas = pnsqlcursor.PNSqlCursor("flareas")
 
@@ -831,7 +878,7 @@ class TestRelations(unittest.TestCase):
         cur_areas.transaction()
         cur_modulos = pnsqlcursor.PNSqlCursor("flmodules", True, "default", cur_areas, rel)
         cur_modulos.setModeAccess(cur_modulos.Insert)
-        self.assertEqual(cur_areas.transactionsOpened(), ["2", "1"])
+        self.assertEqual(cur_areas.transactionsOpened(), ["1", "2"])
         cur_modulos.refreshBuffer()
         cur_modulos.transaction()
         cur_modulos.commitOpened(-1, "Mensage de prueba 2º")
@@ -841,7 +888,7 @@ class TestRelations(unittest.TestCase):
         cur_areas.transaction()
         cur_modulos = pnsqlcursor.PNSqlCursor("flmodules", True, "default", cur_areas, rel)
         cur_modulos.setModeAccess(cur_modulos.Insert)
-        self.assertEqual(cur_areas.transactionsOpened(), ["3", "2", "1"])
+        self.assertEqual(cur_areas.transactionsOpened(), ["1", "2", "3"])
         cur_modulos.refreshBuffer()
         cur_modulos.transaction()
         self.assertTrue(cur_modulos.commitBufferCursorRelation())
@@ -862,7 +909,7 @@ class TestRelations(unittest.TestCase):
         self.assertTrue(cur_modulos.rollback())
         self.assertEqual(cur_modulos.transactionsOpened(), [])
         self.assertTrue(cur_areas.rollback())
-        self.assertEqual(cur_areas.transactionsOpened(), ["5", "3", "2"])
+        self.assertEqual(cur_areas.transactionsOpened(), ["1", "2", "3"])
         cur_areas.setModeAccess(cur_areas.Insert)
         cur_areas.refreshBuffer()
         cur_areas.setValueBuffer("bloqueo", True)
@@ -1084,7 +1131,6 @@ class TestCorruption(unittest.TestCase):
         self.assertEqual(cursor_3.size(), 99)
         i = 1
         while cursor_3.next():
-
             if i == 10:
                 self.assertTrue(qsa.FLUtil().sqlDelete("fltest", "string_field = 'Linea 20'"))
                 i += 1
@@ -1096,6 +1142,47 @@ class TestCorruption(unittest.TestCase):
         cursor_3.select()
         self.assertEqual(cursor_3.size(), 98)
 
+    def test_out_transaction(self) -> None:
+        """Out transaction test."""
+
+        from pineboolib.application.database import pnsqlcursor
+        from pineboolib.fllegacy import flutil
+
+        cursor = pnsqlcursor.PNSqlCursor("Fltest3")
+        cursor.setModeAccess(cursor.Insert)
+        cursor.refreshBuffer()
+        cursor.setValueBuffer("bool_field", False)
+        pk_value = cursor.valueBuffer(cursor.primaryKey())
+        self.assertTrue(cursor.commitBuffer())
+        cursor.select("counter_field='%s'" % pk_value)
+        self.assertTrue(cursor.first())
+        cursor.setModeAccess(cursor.Edit)
+        cursor.refreshBuffer()
+        valor_inicial = cursor.valueBuffer("bool_field")
+        valor_inicial_sql = flutil.FLUtil.sqlSelect(
+            "fltest3", "bool_field", "counter_field='%s'" % pk_value
+        )
+        self.assertEqual(valor_inicial, valor_inicial_sql)
+        cursor.setValueBuffer("bool_field", True)
+        valor_intermedio = cursor.valueBuffer("bool_field")
+        self.assertNotEqual(
+            valor_inicial,
+            valor_intermedio,
+            "la pk era %s" % cursor.valueBuffer(cursor.primaryKey()),
+        )
+        valor_intermedio_sql = flutil.FLUtil.sqlSelect(
+            "fltest3", "bool_field", "counter_field='%s'" % pk_value
+        )
+        self.assertEqual(valor_intermedio, valor_intermedio_sql)
+        cursor.setValueBuffer("bool_field", False)
+        valor_final = cursor.valueBuffer("bool_field")
+        self.assertNotEqual(valor_final, valor_intermedio)
+        valor_final_sql = flutil.FLUtil.sqlSelect(
+            "fltest3", "bool_field", "counter_field='%s'" % pk_value
+        )
+        self.assertEqual(valor_final, valor_final_sql)
+        self.assertTrue(cursor.metadata().field("bool_field").outTransaction())  # type: ignore [union-attr]
+
     def test_basic_3(self) -> None:
         """Bad cursor."""
 
