@@ -51,7 +51,7 @@ class TestPNSqlQuery1(unittest.TestCase):
 
         qry2 = pnsqlquery.PNSqlQuery("fltest")
         qry2.setSelect(
-            "id,string_field,date_field,time_field,double_field,bool_field,uint_field,bloqueo"
+            "SUM(id),id,string_field,date_field,time_field,double_field,bool_field,uint_field,bloqueo"
         )
         qry2.setFrom("fltest")
         qry2.setWhere("id>='0' AND id<='1'")
@@ -59,25 +59,26 @@ class TestPNSqlQuery1(unittest.TestCase):
 
         self.assertEqual(
             qry2.sql(),
-            "SELECT id,string_field,date_field,time_field,double_field,bool_field,uint_field,bloqueo FROM fltest"
+            "SELECT SUM(id),id,string_field,date_field,time_field,double_field,bool_field,uint_field,bloqueo FROM fltest"
             + " WHERE id>='0' AND id<='1' ORDER BY string_field",
         )
 
         self.assertEqual(qry.name(), "fltest2")
         self.assertEqual(qry.where(), "id>=[from] AND id<=[to]")
         self.assertEqual(qry.orderBy(), "fltest.id")
-        qry.setSelect(["id", "fltest.string_field"])
+        qry.setSelect(["SUM(id)", "id", "fltest.string_field"])
         self.assertEqual(len(qry.parameterDict()), 2)
         self.assertEqual(len(qry.groupDict()), 1)
-        self.assertEqual(qry.fieldList(), ["id", "fltest.string_field"])
-        self.assertEqual(qry.posToFieldName(0), "id")
-        self.assertEqual(qry.posToFieldName(1), "fltest.string_field")
-        self.assertEqual(qry.fieldNameToPos("fltest.string_field"), 1)
-        self.assertEqual(qry.fieldNameToPos("string_field"), 1)
+        self.assertEqual(qry.fieldList(), ["SUM(id)", "id", "fltest.string_field"])
+        self.assertEqual(qry.posToFieldName(0), "SUM(id)")
+        self.assertEqual(qry.posToFieldName(1), "id")
+        self.assertEqual(qry.posToFieldName(2), "fltest.string_field")
+        self.assertEqual(qry.fieldNameToPos("fltest.string_field"), 2)
+        self.assertEqual(qry.fieldNameToPos("string_field"), 2)
         qry.setName("fltest2_dos")
 
         self.assertEqual(qry.name(), "fltest2_dos")
-        self.assertEqual(len(qry.fieldMetaDataList()), 2)
+        self.assertEqual(len(qry.fieldMetaDataList()), 3)
 
     def test_basic_2(self) -> None:
         """Test basic_2."""
@@ -221,6 +222,17 @@ class TestPNSqlQuery1(unittest.TestCase):
         self.assertEqual(qry.from_(), "agentes")
         self.assertEqual(qry.fieldList(), ["cast (max(codagente) as integer)", "campo_dos"])
 
+    def test_sql_injection(self) -> None:
+        """Test sql injection."""
+
+        qry = pnsqlquery.PNSqlQuery("fake")
+
+        qry.sql_inspector._check_sql_injection(["email", "=", "'ncastanaresrodriguez@gmail.com'"])
+        self.assertFalse(
+            qry.sql_inspector.suspected_injection(),
+            "SOSPECHOSO : %s" % qry.sql_inspector._suspected_injection,
+        )
+
     def test_only_inspector(self) -> None:
         """Test only inspector."""
 
@@ -584,7 +596,6 @@ class TestPNSqlQuery2(unittest.TestCase):
         # self.assertTrue(qry2.isValid())
 
     def test_sql_injection(self) -> None:
-
         sql = (
             "SELECT s.codalmacen,t.descripcion,t.direccion,t.ciudad,t.provincia,t.codpostal,t.codpais,"
             + "t.telefono, s.talla FROM tpv_tiendas t inner join stocks s on t.codalmacen = s.codalmacen "
