@@ -15,7 +15,6 @@ from typing import Any, Union, List, Optional, TYPE_CHECKING
 
 
 if TYPE_CHECKING:
-
     from pineboolib.interfaces import iconnection, isqlcursor  # noqa : F401 # pragma: no cover
     from pineboolib.application import file as file_app  # noqa : F401 # pragma: no cover
 
@@ -68,7 +67,6 @@ def next_counter(
     """
 
     if cursor_ is None:
-
         if not isinstance(cursor_or_name, (pnsqlcursor.PNSqlCursor, dummy_cursor.DummyCursor)):
             raise ValueError
         return _next_counter2(name_or_series, cursor_or_name)
@@ -81,7 +79,6 @@ def next_counter(
 def _next_counter2(
     name_: str, cursor_: Union["isqlcursor.ISqlCursor", "dummy_cursor.DummyCursor"]
 ) -> Optional[Union[str, int]]:
-
     if not cursor_:
         return None
 
@@ -110,14 +107,16 @@ def _next_counter2(
     if not qry.exec_():
         return None
 
-    _numero: int = int(qry.value(0)) if qry.last() else 0
-
-    _numero += 1
+    _value: str = qry.value(0) if qry.last() else "0"
+    _serie: str = "".join(digit for digit in _value if not digit.isdigit())
+    _len_serie = len(_serie)
+    _len_numero = _len - _len_serie
+    print("***", _value, _serie, _len_serie, _len_numero)
+    _numero: int = int(_value[_len_serie:]) + 1
 
     if type_ == "string":
-        _cadena = str(_numero)
-
-        return _cadena.rjust(_len, "0") if len(_cadena) < _len else _cadena
+        _numero_str: str = str(_numero).rjust(_len_numero, "0")
+        return "%s%s" % (_serie, _numero_str)
 
     elif type_ == "double":
         return _numero
@@ -128,7 +127,6 @@ def _next_counter2(
 def _next_counter3(
     serie_: str, name_: str, cursor_: Union["isqlcursor.ISqlCursor", "dummy_cursor.DummyCursor"]
 ) -> Optional[Union[str, int]]:
-
     if not cursor_:
         return None
 
@@ -242,9 +240,11 @@ def sql_insert(
     _value_list: Union[List[Any], types.Array] = (
         value_list_.split(",")
         if isinstance(value_list_, str)
-        else value_list_
-        if isinstance(value_list_, (List, types.Array))
-        else [value_list_]  # type: ignore [list-item]
+        else (
+            value_list_
+            if isinstance(value_list_, (List, types.Array))
+            else [value_list_]  # type: ignore [list-item]
+        )
     )
 
     _field_list: Union[List[Any], types.Array] = (
@@ -261,7 +261,6 @@ def sql_insert(
     _cursor.refreshBuffer()
 
     for _pos in range(len_field_list):
-
         if _value_list[_pos] is None:
             _cursor.setNull(_field_list[_pos])
         else:
@@ -292,7 +291,6 @@ def sql_update(
     _cursor.select(where_)
     _cursor.setForwardOnly(True)
     while _cursor.next():
-
         _cursor.setModeAccess(_cursor.Edit)
         _cursor.refreshBuffer()
 
@@ -300,9 +298,11 @@ def sql_update(
             for _pos in range(len(field_list_)):
                 _cursor.setValueBuffer(
                     field_list_[_pos],
-                    value_list_[_pos]
-                    if isinstance(value_list_, (List, types.Array))
-                    else value_list_,
+                    (
+                        value_list_[_pos]
+                        if isinstance(value_list_, (List, types.Array))
+                        else value_list_
+                    ),
                 )
         else:
             _cursor.setValueBuffer(field_list_, value_list_)
