@@ -12,8 +12,8 @@ from pineboolib import application
 
 import xml.etree.ElementTree as ET
 from importlib import util
-from sqlalchemy.ext import declarative
-from sqlalchemy import exc
+from sqlalchemy.ext import declarative  # type: ignore [import]
+from sqlalchemy import exc  # type: ignore [import]
 
 import shutil
 import time
@@ -22,7 +22,6 @@ import os
 if TYPE_CHECKING:
     from pineboolib.qsa import formdbwidget  # pragma: no cover
     from pineboolib.application import xmlaction  # pragma: no cover
-    from sqlalchemy.ext.declarative import api  # noqa: F401 # pragma: no cover
     from types import ModuleType  # pragma: no cover
 
 LOGGER = logging.get_logger(__name__)
@@ -60,8 +59,8 @@ def load_script(script_name: str, action_: "xmlaction.XMLAction") -> "formdbwidg
     static_flag = (
         "%s/static.xml" % os.path.dirname(cached_script_path_qs) if cached_script_path_qs else ""
     )
-    script_path_qs_static = _static_file("%s.qs" % script_name)
     script_path_py_static = _static_file("%s.py" % script_name)
+    script_path_qs_static = _static_file("%s.qs" % script_name) if not script_path_py_static else ""
 
     # Primera opción carga estática.
     if script_path_py_static:
@@ -111,12 +110,12 @@ def load_script(script_name: str, action_: "xmlaction.XMLAction") -> "formdbwidg
                 )
             if replace_static:
                 shutil.copy(script_path_qs_static, cached_script_path_qs)  # Lo copiamos en tempdata
-                _remove(script_path_py)
+                # _remove(script_path_py)
                 _build_static_flag(static_flag, cached_script_path_qs, script_path_qs_static)
             else:
                 need_parse = not os.path.exists(script_path_py)
         else:
-            if os.path.exists(script_path_py) and not application.PROJECT.no_python_cache:
+            if not application.PROJECT.no_python_cache and os.path.exists(script_path_py):
                 need_parse = False
 
         if need_parse:
@@ -213,15 +212,15 @@ def load_model(script_name: str, script_path_py: str) -> Optional["type"]:
 
     model_class: Optional["type"] = None
     script_path_py = _resolve_script("%s_model.py" % script_name, script_path_py)
-    if os.path.exists(script_path_py) and pnmtdparser.use_mtd_fields(script_path_py):
-        script_path_py = pnmtdparser.populate_fields(script_path_py, "%s.mtd" % script_name)
-        LOGGER.warning(
-            "El model %s no contenía legacy_metadata. Se rellena con datos de %s.mtd",
-            script_name,
-            script_name,
-        )
-
     if script_path_py:
+        if pnmtdparser.use_mtd_fields(script_path_py):
+            script_path_py = pnmtdparser.populate_fields(script_path_py, "%s.mtd" % script_name)
+            LOGGER.info(
+                "El model %s no contenía legacy_metadata. Se rellena con datos de %s.mtd",
+                script_name,
+                script_name,
+            )
+
         class_name = "%s%s" % (script_name[0].upper(), script_name[1:])
         script_loaded = _load("model.%s" % class_name, script_path_py)
         module_class = getattr(script_loaded, class_name, None)
@@ -291,8 +290,13 @@ def _load(  # type: ignore [return] # noqa: F821, F723
         else:
             raise PermissionError
 
-    try:
+    return import_path(module_name, script_name, capture_error)
 
+
+def import_path(module_name: str, script_name: str, capture_error: bool = True) -> "ModuleType":  # type: ignore [return]
+    """Import path."""
+
+    try:
         spec: Optional["ModuleSpec"] = util.spec_from_file_location(module_name, script_name)
         if spec and spec.loader is not None:
             module = util.module_from_spec(spec)
