@@ -64,7 +64,9 @@ class PNTableMetaData(itablemetadata.ITableMetaData):
         self.private = PNTableMetaDataPrivate()
         self.copy(other)
 
-    def inicializeNewFLTableMetaData(self, name: str, alias: str, query_name: str = None) -> None:
+    def inicializeNewFLTableMetaData(
+        self, name: str, alias: str, query_name: Optional[str] = None
+    ) -> None:
         """
         Initialize the data with the basic information.
 
@@ -201,8 +203,9 @@ class PNTableMetaData(itablemetadata.ITableMetaData):
         """
 
         if not self.private._primary_key:
-            length_field_list = len(self.fieldList())
-            for field in self.fieldList():
+            field_list = self.fieldList()
+            length_field_list = len(field_list)
+            for field in field_list:
                 if field.type() == "serial" or length_field_list == 1:
                     LOGGER.debug(
                         "Forzando %s(serial) como primaryKey de %s", field.name(), self.name()
@@ -214,11 +217,11 @@ class PNTableMetaData(itablemetadata.ITableMetaData):
             if not self.private._primary_key:
                 raise Exception("No primaryKey in %s" % self.private._name)
 
-        if prefix_table:
-            if "." not in self.private._primary_key:
-                return "%s.%s" % (self.private._name, self.private._primary_key)
-
-        return self.private._primary_key
+        return (
+            "%s.%s" % (self.private._name, self.private._primary_key)
+            if prefix_table and "." not in self.private._primary_key
+            else self.private._primary_key
+        )
 
     def fieldNameToAlias(self, field_name: str = "") -> str:
         """
@@ -493,14 +496,14 @@ class PNTableMetaData(itablemetadata.ITableMetaData):
             else None
         )
 
-    def fieldList(self) -> List["pnfieldmetadata.PNFieldMetaData"]:
+    def fieldList(self, only_names: bool = False) -> List["pnfieldmetadata.PNFieldMetaData"]:
         """
         Return a list of field definitions.
 
         @return Object with the table field deficits list
         """
 
-        return list(self.private._fields_dict.values())
+        return self.fieldNames() if only_names else list(self.private._fields_dict.values())  # type: ignore [return-value, arg-type]
 
     def fieldListArray(self, prefix_table: bool = False) -> List[str]:
         """
@@ -668,6 +671,20 @@ class PNTableMetaData(itablemetadata.ITableMetaData):
 
         return True
 
+    def setCachedFields(self, cached_fields: str) -> None:
+        """Set cached fields."""
+        self.private._cached_fields = cached_fields
+
+    def useCachedFields(self) -> bool:
+        """Return if use cached fields."""
+
+        return self.private._cached_fields != ""
+
+    def cachedFields(self) -> str:
+        """Return cached fields."""
+
+        return self.private._cached_fields
+
 
 class PNTableMetaDataPrivate:
     """PNTableMetaData Class."""
@@ -754,7 +771,14 @@ class PNTableMetaDataPrivate:
 
     count_ = 0
 
-    def __init__(self, name: str = None, alias=None, qry_name: str = None) -> None:
+    _cached_fields: str
+
+    def __init__(
+        self,
+        name: Optional[str] = None,
+        alias: Optional[str] = None,
+        qry_name: Optional[str] = None,
+    ) -> None:
         """
         Initialize the class.
 
@@ -775,13 +799,17 @@ class PNTableMetaDataPrivate:
         self._detect_locks = True
         self._query = ""
         self._in_cache = False
+        self._cached_fields = ""
         # print("Vaciando field list ahora",  len(self._field_list))
-        if name is None:
-            self.inicializeFLTableMetaDataPrivate()
-        elif name and not alias and not qry_name:
-            self.inicializeFLTableMetaDataPrivateS(name)
+
+        if name:
+            if alias:
+                self.inicializeNewFLTableMetaDataPrivate(name, alias, qry_name)
+            else:
+                self.inicializeFLTableMetaDataPrivateS(name)
         else:
-            self.inicializeNewFLTableMetaDataPrivate(name, alias, qry_name)
+            self.inicializeFLTableMetaDataPrivate()
+
         self.count_ += 1
 
     def inicializeFLTableMetaDataPrivate(self) -> None:
@@ -791,7 +819,9 @@ class PNTableMetaDataPrivate:
 
         self._compound_key = None
 
-    def inicializeNewFLTableMetaDataPrivate(self, name: str, alias: str, query: str = None) -> None:
+    def inicializeNewFLTableMetaDataPrivate(
+        self, name: str, alias: str, query: Optional[str] = None
+    ) -> None:
         """
         Initialize the class end with data.
 
