@@ -97,12 +97,12 @@ class Kut2FPDF(object):
         @return Path to PDF file.
         """
         try:
-            self._xml = self._parser_tools.loadKut(kut).getroot()
+            self._xml = self._parser_tools.loadKut(kut).getroot()  # type: ignore [assignment]
         except Exception:
             LOGGER.exception("KUT2FPDF: Problema al procesar %s.kut", name)
             return None
         try:
-            self._xml_data = load2xml(data).getroot()
+            self._xml_data = load2xml(data).getroot()  # type: ignore [assignment]
         except Exception:
             LOGGER.exception("KUT2FPDF: Problema al procesar xml_data")
             return None
@@ -324,7 +324,6 @@ class Kut2FPDF(object):
             draw_if = section.get("DrawIf")
             show = True
             if draw_if:
-
                 show = data.get(draw_if) not in ("", "False", "None", False)
             if section.get("Level") == str(data_level) and show:
                 current_size = self._parser_tools.getHeight(section)
@@ -588,7 +587,6 @@ class Kut2FPDF(object):
         text: str = xml.get("Text") or ""
         # borderColor = xml.get("BorderColor")
         field_name = xml.get("Field") or ""
-
         # x,y,W,H se calcula y corrigen aquí para luego estar correctos en los diferentes destinos posibles
         width = int(xml.get("Width") or "0")
 
@@ -607,7 +605,7 @@ class Kut2FPDF(object):
         data_type = xml.get("DataType")
 
         if xml.tag == "Field" and data_row is not None:
-            text = data_row.get(field_name) or ""
+            text = data_row.get(field_name)  # type: ignore [assignment]
 
         elif xml.tag == "Special":
             alternative_text = text
@@ -672,8 +670,8 @@ class Kut2FPDF(object):
 
                 text = data_row.get(field_name) or ""
 
-        if data_type is not None:
-            text = self._parser_tools.calculated(text, int(data_type), xml, data_row)
+        if data_type not in [None, ""]:
+            text = self._parser_tools.calculated(text, int(data_type), xml, data_row)  # type: ignore [arg-type]
 
             if data_type == "5":
                 is_image = True
@@ -687,7 +685,6 @@ class Kut2FPDF(object):
                 return
 
         if text is not None:
-
             temporal = settings.CONFIG.value("ebcomportamiento/temp_dir")
             if text.startswith(temporal):
                 is_image = True
@@ -862,7 +859,6 @@ class Kut2FPDF(object):
                 # height_resized = True
                 array_text = self.split_text(text_line, width - 10)
             else:
-
                 array_text.append(text_line)
 
         # calculated_h = orig_h * len(array_text)
@@ -871,7 +867,6 @@ class Kut2FPDF(object):
         processed_lines = 0
         extra_size = 0
         for actual_text in array_text:
-
             processed_lines += 1
 
             if processed_lines > 1:
@@ -884,7 +879,6 @@ class Kut2FPDF(object):
                 pos_x = pos_x + (width / 2) - (self._document.get_string_width(actual_text) / 2)
                 # x = x + (width / 2) - (str_width if not height_resized else width / 2)
             elif horizontal_alignment == "2":
-
                 # Derecha
                 pos_x = (
                     pos_x + width - self._document.get_string_width(actual_text) - 2
@@ -989,7 +983,7 @@ class Kut2FPDF(object):
         return [red, green, blue]
 
     def drawRect(
-        self, pos_x: int, pos_y: int, width: int, height: int, xml: "Element" = None
+        self, pos_x: int, pos_y: int, width: int, height: int, xml: Optional["Element"] = None
     ) -> None:
         """
         Draw a rectangle in current page.
@@ -1014,7 +1008,6 @@ class Kut2FPDF(object):
 
         if xml is not None and not self.design_mode:
             if xml.get("BorderStyle") == "1":
-
                 border_color = self.get_color(xml.get("BorderColor") or "")
                 self._document.set_draw_color(border_color[0], border_color[1], border_color[2])
                 style_ += "D"
@@ -1132,7 +1125,6 @@ class Kut2FPDF(object):
         codbartype = xml.get("CodBarType")
 
         if not os.path.exists(file_name):
-
             bar_code = flcodbar.FLCodBar(text)  # Code128
             if codbartype is not None:
                 type: int = bar_code.nameToType(codbartype.lower())
