@@ -41,7 +41,7 @@ from pineboolib.application import load_script, qsadictmodules
 from pineboolib.application.database.orm import basemodel
 from pineboolib import logging, application
 from pineboolib.application.parsers.parser_mtd import pnmtdparser
-import sqlalchemy
+import sqlalchemy  # type: ignore [import]
 
 
 from typing import Any, List, Dict, cast, TYPE_CHECKING
@@ -118,7 +118,7 @@ def save_model(path_, name: str) -> bool:
 def load_models() -> None:
     """Load all sqlAlchemy models."""
     # print("LOADING MODELS!!!")
-    db_admin = application.PROJECT._db_admin_mode
+    db_admin = application.PROJECT.db_admin_mode
 
     if application.PROJECT.conn_manager is None:
         raise Exception("Project is not connected yet")
@@ -165,7 +165,7 @@ def load_models() -> None:
             if metadata.isQuery():
                 views_[name] = data
             else:
-                application.PROJECT.conn_manager.manager().metadata(name, not db_admin)
+                application.PROJECT.conn_manager.manager().metadata(name)
     # views las últimas...
     for key, data in views_.items():
         save_model(data, key)
