@@ -2,26 +2,24 @@
 """
 Simplify AST-XML structures for later generation of Python files.
 """
-from importlib.machinery import ModuleSpec
+from importlib import machinery, util
 from optparse import OptionParser
 import os
 import sys
-import importlib
+
 from xml.etree import ElementTree as ET
 from xml.dom import minidom  # type: ignore
 from pineboolib import logging
 from pineboolib.application.parsers.parser_qsa import pytnyzer, flscriptparse
+from pineboolib.application.parsers import parser_qsa
 from typing import List, Type, Optional, Dict, Tuple, Any, Callable, cast, Iterable
 
-STRICT_MODE = pytnyzer.STRICT_MODE
-importlib.reload(pytnyzer)
-pytnyzer.STRICT_MODE = STRICT_MODE
 
 TreeData = Dict[str, Any]
 
 LOGGER = logging.get_logger(__name__)
 
-USEFUL_TOKENS = "ID,ICONST,FCONST,SCONST,CCONST,RXCONST".split(",")
+USEFUL_TOKENS = "ID,ICONST,FCONST,SCONST,CCONST,RXCONST,STATIC".split(",")
 
 KNOWN_PARSERS: Dict[str, Type["TagObjectBase"]] = {}
 UNKNOWN_PARSERS = {}
@@ -29,7 +27,7 @@ UNKNOWN_PARSERS = {}
 
 def parse_for(*tag_names: str) -> Callable:
     """Decorate functions for registering tags."""
-    global KNOWN_PARSERS
+    global KNOWN_PARSERS  # noqa: F824
 
     def decorator(func: Type["TagObjectBase"]) -> Type["TagObjectBase"]:
         for tag_name in tag_names:
@@ -41,7 +39,7 @@ def parse_for(*tag_names: str) -> Callable:
 
 def parse(tag_name: str, tree_data: TreeData) -> "TagObject":
     """Excecute registered function for given tagname on treedata."""
-    global KNOWN_PARSERS, UNKNOWN_PARSERS
+    global KNOWN_PARSERS, UNKNOWN_PARSERS  # noqa: F824
     if tag_name not in KNOWN_PARSERS:
         UNKNOWN_PARSERS[tag_name] = 1
         func = parse_unknown
@@ -96,7 +94,7 @@ class TagObjectFactory(type):
 
     def __init__(cls, name: str, bases: Any, dct: Any) -> None:
         """Register a new class as tag processor."""
-        global XML_CLASS_TYPES
+        global XML_CLASS_TYPES  # noqa: F824
         if issubclass(cls, TagObjectBase):
             XML_CLASS_TYPES.append(cast(Type[TagObjectBase], cls))
         else:
@@ -719,11 +717,11 @@ class Module(object):
     def loadModule(self):
         """Import and return Python file."""
         try:
-            from importlib import util
-
             module_name = self.name[: self.name.find(".")]
             script_name = os.path.join(self.path, self.name)
-            spec: Optional["ModuleSpec"] = util.spec_from_file_location(module_name, script_name)
+            spec: Optional["machinery.ModuleSpec"] = util.spec_from_file_location(
+                module_name, script_name
+            )
             if spec and spec.loader is not None:
                 module = util.module_from_spec(spec)
                 spec.loader.exec_module(module)  # type: ignore [attr-defined]
@@ -796,7 +794,7 @@ def parse_args(argv: List[str]) -> Tuple[Any, List[str]]:
     )
 
     parser.add_option(
-        "--full", action="store_true", dest="full", default=False, help="write xml file from qs"
+        "--full", action="store_true", dest="full", default=False, help="write py file from qs"
     )
 
     parser.add_option(
@@ -828,7 +826,7 @@ def parse_args(argv: List[str]) -> Tuple[Any, List[str]]:
 
 def main() -> None:
     """Run the program from command line."""
-    pytnyzer.STRICT_MODE = True
+
     log_format = "%(asctime)s - %(levelname)s: %(name)s: %(message)s"
     logging.basicConfig(format=log_format, level=0)
     blib_logger = logging.get_logger("blib2to3.pgen2.driver")
@@ -863,6 +861,8 @@ def pythonify_string(
 ) -> str:
     """Convert QS string to Python. For unit-testing, only evaluates expressions."""
 
+    qs_code = flscriptparse.clean_no_python_tags(qs_code)
+
     ast = common_parse(qs_code)
     ast.set("parser-template", parser_template)  # type: ignore [attr-defined] # noqa: F821
     return pytnyzer.pythonize2(ast, known_refs)
@@ -884,7 +884,7 @@ def common_parse(data: str):
 def execute(options: Any, args: List[str]) -> None:
     """Execute conversion orders given by options and args. Can be used to emulate program calls."""
 
-    pytnyzer.STRICT_MODE = options.strict
+    parser_qsa.STRICT_MODE = options.strict
 
     if options.full:
         execpython = options.exec_python
