@@ -12,9 +12,10 @@ import pathlib
 import re
 from xml.etree import ElementTree as ET
 from typing import Any, Generator, Tuple, Type, List, Dict, Set, cast, Optional, TextIO, Callable
-
 from pineboolib.core.utils import logging
+from pineboolib.application.parsers import parser_qsa
 
+ANON_NO = 0
 LOGGER = logging.get_logger(__name__)
 ASTGenerator = Generator[Tuple[str, str], None, None]
 
@@ -26,9 +27,6 @@ except ImportError:
     black = None  # type: ignore [assignment]
     BLACK_FILEMODE = None  # type: ignore [assignment]
 
-
-STRICT_MODE = False
-
 # To get the following list updated, do:
 # In [1]: from pineboolib.qsa import qsa
 # In [2]: dir(qsa)
@@ -236,6 +234,7 @@ QSA_KNOWN_ATTRS = {
     "killTimers",
     "logger",
     "parseFloat",
+    "toJson",
     "parseInt",
     "parseString",
     "print_",
@@ -261,50 +260,54 @@ QSA_KNOWN_ATTRS = {
     "ustr1",
     "util",
     "weakref",
+    "require",
 }
 
 DISALLOW_CONVERSION_FOR_NONSTRICT = {"connect", "disconnect", "form"}
+PYTHON_KEYWORDS = [
+    "and",
+    "del",
+    "for",
+    "is",
+    "raise",
+    "assert",
+    "elif",
+    "from",
+    "lambda",
+    "return",
+    "break",
+    "else",
+    "global",
+    "not",
+    "try",
+    "class",
+    "except",
+    "if",
+    "or",
+    "while",
+    "continue",
+    "from",
+    "exec",
+    "import",
+    "pass",
+    "yield",
+    "def",
+    "finally",
+    "in",
+    "print",
+    "str",
+    "qsa",
+    "self",
+]
 classesDefined: List[str] = []
 
 
-def id_translate(name: str, qsa_exclude: Set[str] = None, transform: Dict[str, str] = None) -> str:
+def id_translate(
+    name: str, qsa_exclude: Optional[Set[str]] = None, transform: Optional[Dict[str, str]] = None
+) -> str:
     """Translate identifiers to avoid "import *" issues."""
     orig_name = name
-    python_keywords = [
-        "and",
-        "del",
-        "for",
-        "is",
-        "raise",
-        "assert",
-        "elif",
-        "from",
-        "lambda",
-        "return",
-        "break",
-        "else",
-        "global",
-        "not",
-        "try",
-        "class",
-        "except",
-        "if",
-        "or",
-        "while",
-        "continue",
-        "from",
-        "exec",
-        "import",
-        "pass",
-        "yield",
-        "def",
-        "finally",
-        "in",
-        "print",
-        "str",
-        "qsa",
-        "self",
-    ]
+
     if "(" in name:
         raise ValueError("Parenthesis not allowed in ID for translation")
     if "." in name:
@@ -346,50 +349,31 @@ def id_translate(name: str, qsa_exclude: Set[str] = None, transform: Dict[str, s
         name = "arg"
     # if name == "Process":
     #    name = "qsatype.Process"
-    if name in python_keywords:
-        name = name + "_"
+
+    name = "%s_" % name if name in PYTHON_KEYWORDS else name
 
     if qsa_exclude is not None:
-        qsa_lower = {
-            x.lower(): x
-            for x in qsa_exclude | QSA_KNOWN_ATTRS
-            if x.lower() != x and x.lower() not in qsa_exclude
-        }
-        if orig_name.lower() in qsa_lower:
-            new_name = qsa_lower[orig_name.lower()]
-            count_diff_chars = len([1 for a, b in zip(new_name, orig_name) if a != b])
-            if count_diff_chars <= 2:
-                orig_name = name = new_name
-                if name in python_keywords:
-                    name = name + "_"
-
         if orig_name in qsa_exclude:
+            # if orig_name == "form":
+            #    return "self.form"
             return name
+        # elif orig_name == "form":
+        #    return "self"
 
-        if name in QSA_KNOWN_ATTRS:
+        if orig_name in QSA_KNOWN_ATTRS:
             if name in DISALLOW_CONVERSION_FOR_NONSTRICT:
-                if name in ["connect", "disconnect"]:  # self.module_connect
-                    return "self.module_%s" % name
-                else:
-                    return name
-            return "qsa.%s" % name
+                return "self.module_%s" % name if name in ["connect", "disconnect"] else name
+            else:
+                return "qsa.%s" % name
 
-        if transform is not None and name in transform:
+        if transform and name in transform:
             return transform[name]
 
         if name.startswith("form") and len(name) > 4:
             return 'qsa.from_project("%s")' % name
-
-        if STRICT_MODE:
-            return "__undef__" + name
-        else:
-
-            return name
+        return "%s%s" % ("__undef__" if parser_qsa.STRICT_MODE else "", name)
     else:
-        if transform is not None and name in transform:
-            return transform[name]
-
-        return name
+        return transform[name] if transform and name in transform else name  # type: ignore [unreachable]
 
 
 CONT_SWITCH = 0
@@ -399,11 +383,11 @@ CONT_DO_WHILE = 0
 class ASTPythonBase(object):
     """Generate python lines. Base class."""
 
-    elem: ET.Element
+    elem: "ET.Element"
 
-    def __init__(self, elem: ET.Element) -> None:
+    def __init__(self, elem: "ET.Element") -> None:
         """Create ASTPythonBase."""
-        self.elem: ET.Element = elem
+        self.elem = elem
         self.parent: Optional["ASTPythonBase"] = None
         self.source: Optional["Source"] = None
 
@@ -529,7 +513,7 @@ class Source(ASTPython):
         *,
         break_mode: bool = False,
         include_pass: bool = True,
-        declare_identifiers: Set[str] = None,
+        declare_identifiers: Optional[Set[str]] = None,
         **kwargs: Any
     ) -> ASTGenerator:
         """Generate python code."""
@@ -538,6 +522,10 @@ class Source(ASTPython):
         prev_ast_type = None
         if declare_identifiers:
             self.locals |= declare_identifiers
+
+        if not len(self.elem):
+            include_pass = False
+
         for child in self.elem:
             # yield "debug", "<%s %s>" % (child.tag, repr(child.attrib))
             child.set("parent_", self.elem)  # type: ignore
@@ -570,6 +558,7 @@ class Source(ASTPython):
         for line in after_lines:
             elems += 1
             yield "line", line
+
         if not elems and include_pass:
             yield "line", "pass"
 
@@ -601,14 +590,21 @@ class Function(ASTPython):
 
     def generate(self, **kwargs: Any) -> ASTGenerator:
         """Generate python code."""
+
+        global ANON_NO
+
         _name = self.elem.get("name")
         anonymous = False
         if _name:
             name = self.other_var(_name)
         else:
             # Anonima:
-            name = "_anonymous_fn_"
+            name = "_anonymous_%s_fn" % ANON_NO
+            ANON_NO += 1
             anonymous = True
+
+        static_flag = self.elem.get("arg00")
+        is_static_function = static_flag is not None and str(static_flag).startswith("STATIC")
         withoutself = self.elem.get("withoutself")
         parent = cast(ET.Element, self.elem.get("parent_"))  # FIXME
         grandparent = None
@@ -663,7 +659,6 @@ class Function(ASTPython):
                 yield "debug", ET.tostring(arg)  # type: ignore
             else:
                 if len(expr) == 1:
-
                     dtype_: Optional[str] = arg.get("type")
                     dtyping_ = ""
                     if dtype_ is not None:
@@ -690,7 +685,8 @@ class Function(ASTPython):
                     #    def_value = "0"
                     # expr += ["=", def_value]
                 arguments.append("".join(expr))
-
+        if is_static_function:
+            yield "line", "@classmethod"
         yield "line", "def %s(%s)%s:" % (
             name,
             ", ".join(arguments),
@@ -790,13 +786,10 @@ class FunctionCall(ASTPython):
                 arg1 = arg1.replace(" )", ")")
                 arguments.append(arg1)
 
-        comment = ""
-        if STRICT_MODE and name.startswith("__undef__"):
-            name = name[9:]
-            name = "self.%s" % name
-            comment = ""
+        if not parser_qsa.STRICT_MODE and name.startswith("__undef__"):
+            name = "self.%s" % name[9:]
 
-        yield "expr", "%s(%s)%s" % (name, ", ".join(arguments), comment)
+        yield "expr", "%s(%s)" % (name, ", ".join(arguments))
 
 
 class FunctionAnonExec(FunctionCall):
@@ -837,7 +830,6 @@ class If(ASTPython):
                 yield "debug", "Expression %d not understood" % number
                 yield "debug", ET.tostring(arg)  # type: ignore
             else:
-
                 if len(expr) == 3:
                     # FIXME: This works if the pattern is alone in the IF. But if it has AND/Or does not work
                     if expr[1] == "==":
@@ -905,12 +897,13 @@ class TryCatch(ASTPython):
                 else:
                     yield dtype, data
             identifier = " ".join(expr)
-        yield "line", "except Exception:"
+        yield "line", "except Exception as exc_:"
         yield "begin", "block-except"
         if identifier:
             self.source.locals.add(identifier)
-            # yield "line", "%s = str(%s)" % (identifier, identifier)
-            yield "line", "%s = qsa.format_exc()" % (identifier)
+            yield "line", "%s = exc_" % (identifier)
+        else:
+            yield "line", "print(qsa.format_exc())"
         for obj in parse_ast(catchblock, parent=self).generate(include_pass=identifier is None):
             yield obj
         yield "end", "block-except"
@@ -1004,9 +997,8 @@ class For(ASTPython):
                 init_expr.append(" ".join(expr))
         if init_expr:
             yield "line", " ".join(init_expr)
-            yield "line", "while_pass = True"
-        else:
-            yield "line", "while_pass = True"
+
+        yield "line", "while_pass = True"
 
         incr_expr = []
         incr_lines = []
@@ -1092,7 +1084,10 @@ class ForIn(ASTPython):
             myelems.append(" ".join(expr))
         list_elem, main_list = myelems
         yield "debug", "FOR-IN: " + repr(myelems)
-        yield "line", "for %s in %s:" % (list_elem, main_list)
+        yield "line", "for %s in %s:" % (
+            list_elem,
+            main_list,
+        )
         for source_elem in self.elem.findall("Source"):
             source = cast(Source, parse_ast(source_elem, parent=self))
             source.locals.add(list_elem)
@@ -1102,93 +1097,6 @@ class ForIn(ASTPython):
             yield "end", "block-for-in"
 
 
-class OldSwitch(ASTPython):
-    """Process OldSwitch XML tags."""
-
-    def generate(self, **kwargs: Any) -> ASTGenerator:
-        """Generate python code."""
-
-        global CONT_SWITCH
-        CONT_SWITCH += 1
-        key = "%02x" % CONT_SWITCH
-        name = "s%s_when" % key
-        name_pr = "s%s_do_work" % key
-        name_pr2 = "s%s_work_done" % key
-        main_expr = []
-        for number, arg in enumerate(self.elem.findall("Condition/*")):
-            arg.set("parent_", self.elem)  # type: ignore
-            expr = []
-            for dtype, data in parse_ast(arg, parent=self).generate(isolate=False):
-                if dtype == "expr":
-                    expr.append(data)
-                else:
-                    yield dtype, data
-            if len(expr) == 0:
-                main_expr.append("False")
-                yield "debug", "Expression %d not understood" % number
-                yield "debug", ET.tostring(arg)  # type: ignore
-            else:
-                main_expr.append(" ".join(expr))
-        yield "line", "%s = %s" % (name, " ".join(main_expr))
-        yield "line", "%s, %s = %s, %s" % (name_pr, name_pr2, "False", "False")
-        for scase in self.elem.findall("Case"):
-            scase.set("parent_", self.elem)  # type: ignore
-            value_expr = []
-            for number, arg in enumerate(scase.findall("Value")):
-                arg.set("parent_", self.elem)  # type: ignore
-                expr = []
-                for dtype, data in parse_ast(arg, parent=self).generate(isolate=False):
-                    if dtype == "expr":
-                        expr.append(data)
-                    else:
-                        yield dtype, data
-                if len(expr) == 0:
-                    value_expr.append("False")
-                    yield "debug", "Expression %d not understood" % number
-                    yield "debug", ET.tostring(arg)  # type: ignore
-                else:
-                    value_expr.append(" ".join(expr))
-
-            yield "line", "if %s == %s:" % (name, " ".join(value_expr))
-            yield "begin", "block-if"
-            yield "line", "%s, %s = %s, %s" % (name_pr, name_pr2, "True", "True")
-            yield "end", "block-if"
-            yield "line", "if %s:" % (name_pr)
-            yield "begin", "block-if"
-            count = 0
-            for source in scase.findall("Source"):
-                source.set("parent_", self.elem)  # type: ignore
-                for obj in parse_ast(source, parent=self).generate(break_mode=True):
-                    if obj[0] == "break":
-                        yield "line", "%s = %s  # BREAK" % (name_pr, "False")
-                        count += 1
-                    else:
-                        yield obj
-                        count += 1
-            if count < 1:
-                yield "line", "pass"
-            yield "end", "block-if"
-
-        for scasedefault in self.elem.findall("CaseDefault"):
-            scasedefault.set("parent_", self.elem)  # type: ignore
-            yield "line", "if not %s:" % (name_pr2)
-            yield "begin", "block-if"
-            yield "line", "%s, %s = %s, %s" % (name_pr, name_pr2, "True", "True")
-            yield "end", "block-if"
-            yield "line", "if %s:" % (name_pr)
-            yield "begin", "block-if"
-            for source in scasedefault.findall("Source"):
-                source.set("parent_", self.elem)  # type: ignore
-                for obj in parse_ast(source, parent=self).generate(break_mode=True):
-                    if obj[0] == "break":
-                        yield "line", "%s = %s  # BREAK" % (name_pr, "False")
-                    else:
-                        yield obj
-            yield "end", "block-if"
-        # yield "line", "assert( not %s )" % name_pr
-        # yield "line", "assert( %s )" % name_pr2
-
-
 class Switch(ASTPython):
     """Process Switch XML tags."""
 
@@ -1413,7 +1321,6 @@ class Variable(ASTPython):
 
         if force_value:
             if values == 0:
-
                 if dtype is None:
                     yield "expr", ": Any = None"
                 else:
@@ -1422,11 +1329,11 @@ class Variable(ASTPython):
                     elif dtype == "Number":
                         yield "expr", " = 0"
                     elif dtype == "Boolean":
-                        yield "expr", ": bool"
+                        yield "expr", ": bool = False"
                     elif dtype in ("FLUtil", "Array"):
                         yield "expr", ': "qsa.%s" = qsa.%s() # Please initialize!' % (dtype, dtype)
                     elif dtype in QSA_KNOWN_ATTRS:
-                        yield "expr", ': "qsa.%s"' % dtype
+                        yield "expr", ': Optional["qsa.%s"] = None' % dtype
                     else:
                         yield "expr", "= %s()" % self.local_var(dtype)
 
@@ -1448,7 +1355,6 @@ class InstructionUpdate(ASTPython):
             for dtype, data in parse_ast(arg, parent=self).generate(
                 isolate=False, is_member=(number == 0)
             ):
-
                 if dtype == "expr":
                     if not data:
                         raise ValueError(ET.tostring(arg))
@@ -1465,6 +1371,39 @@ class InstructionUpdate(ASTPython):
             else:
                 if number == 0 and len(expr) == 1:
                     identifier = expr[0]
+                    parent: Optional["ET.Element"] = cast(ET.Element, self.elem.get("parent_"))
+                    new_parent: Optional["ET.Element"] = (
+                        None if "ifaceCtx" in self.source.locals else parent
+                    )
+                    found_global = None
+
+                    while new_parent is not None:
+                        if new_parent.tag == "Value":
+                            for variable in new_parent.findall("*/*/Variable"):
+                                if variable.get("name") == identifier:
+                                    found_global = False
+                                    break
+
+                        parent = new_parent
+
+                        if found_global is None:
+                            if parent.tag == "Source":
+                                grand_parent = cast(ET.Element, parent.get("parent_"))
+                                if grand_parent is not None and grand_parent.tag == "Source":
+                                    for variable_global in parent.findall(
+                                        "DeclarationBlock/Variable"
+                                    ):
+                                        if variable_global.get("name") == identifier:
+                                            found_global = True
+                                            break
+
+                        if found_global:
+                            yield "line", "global %s" % identifier
+
+                        new_parent = None
+                        if found_global is None:
+                            new_parent = cast(ET.Element, parent.get("parent_"))
+
                 arguments.append(" ".join(expr))
 
         yield "line", " ".join(arguments)
@@ -1651,6 +1590,9 @@ class Member(ASTPython):
             arguments.append(txtarg)
             arg_expr.append(expr)
 
+        if not parser_qsa.STRICT_MODE:
+            arguments[0] = arguments[0].replace("__undef__", "")
+
         # Deteccion de llamada a modulo externo
         if (
             len(arguments) >= 2
@@ -1768,23 +1710,19 @@ class Member(ASTPython):
                     elif member == "isEmpty()":
                         arguments = ["%s == ''" % (".".join(part1))] + part2
                     elif member == "left":
-                        value = arg1[5:]
-                        value = value[: len(value) - 1]
+                        value = arg1[5:-1]
                         arguments = ["%s[0:%s]" % (".".join(part1), value)] + part2
                     elif member == "right":
-                        value = arg1[6:]
-                        value = value[: len(value) - 1]
+                        value = arg1[6:-1]
                         arguments = [
                             "%s[(len(%s) - (%s)):]" % (".".join(part1), ".".join(part1), value)
                         ] + part2
                     elif member == "substring":
-                        value = arg1[10:]
-                        value = value[: len(value) - 1]
+                        value = arg1[10:-1]
                         value = value.replace(",", ":")
                         arguments = ["%s[ %s]" % (".".join(part1), value)] + part2
                     elif member == "mid":
-                        value = arg1[4:]
-                        value = value[: len(value) - 1]
+                        value = arg1[4:-1]
                         if value.find(",") > -1:
                             if (value.find("(") < value.find(",")) and value.find(")") < value.find(
                                 ","
@@ -1811,27 +1749,25 @@ class Member(ASTPython):
                         arguments = ["%s[%s]" % (".".join(part1), value)] + part2
 
                     elif member == "length":
-                        value = arg1[7:]
-                        value = value[: len(value) - 1]
-                        arguments = ["qsa.length(%s)" % (".".join(part1))] + part2
+                        if arguments[0] == "self" and arguments[1] == member:
+                            continue
+                        else:
+                            value = arg1[7:-1]
+                            arguments = ["qsa.length(%s)" % (".".join(part1))] + part2
                     elif member == "charAt":
-                        value = arg1[7:]
-                        value = value[: len(value) - 1]
+                        value = arg1[7:-1]
                         arguments = ["%s[%s]" % (".".join(part1), value)] + part2
                     elif member == "search":
                         if not part1:
                             # Algunas veces ve una variable "search" y cree que es una llamada
                             continue
-                        value = arg1[7:]
-                        value = value[: len(value) - 1]
+                        value = arg1[7:-1]
                         arguments = ["%s.find('%s')" % (".".join(part1), value)] + part2
                     elif member == "charCodeAt":
-                        value = arg1[11:]
-                        value = value[: len(value) - 1]
+                        value = arg1[11:-1]
                         arguments = ["ord(%s[%s])" % (".".join(part1), value)] + part2
                     elif member == "arg":
-                        value = arg1[4:]
-                        value = value[: len(value) - 1]
+                        value = arg1[4:-1]
                         new_part_1 = ".".join(part1)
                         str_value = "str(" + value + ")"
                         if new_part_1.find(str_value) > -1:
@@ -1840,7 +1776,6 @@ class Member(ASTPython):
                             new_part_2 = ""
                             if len(part2) > 0:
                                 for i in range(len(part2)):
-
                                     part2[i] = str(part2[i]).replace("arg(", "str(")
                                 new_part_2 = ", " + ", ".join(part2)
                             new_part_1 = re.sub(r"%\d", "%s", new_part_1)
@@ -1848,28 +1783,22 @@ class Member(ASTPython):
                                 "%s %% (str(%s" % (new_part_1, value + ")" + new_part_2 + ")")
                             ]
                     elif member == "join":
-                        value = arg1[5:]
-                        value = value[: len(value) - 1] or '""'
+                        value = arg1[5:-1] or '""'
                         arguments = ["%s.join(%s)" % (value, ".".join(part1))] + part2
                     elif member == "match":
-                        value = arg1[6:]
-                        value = value[: len(value) - 1]
+                        value = arg1[6:-1]
                         arguments = ["qsa.re.match(%s, %s)" % (value, ".".join(part1))] + part2
                     elif member == "sort":
-                        value = arg1[5:]
-                        value = value[: len(value) - 1] or ""
+                        value = arg1[5:-1] or ""
                         arguments = ["qsa.Sort(%s).sort_(%s)" % (value, ".".join(part1))] + part2
                     elif member == "splice":
-                        value = arg1[7:]
-                        value = value[: len(value) - 1] or ""
+                        value = arg1[7:-1] or ""
                         arguments = ["qsa.splice(%s, %s)" % (".".join(part1), value)] + part2
                     elif member == "push":
-                        value = arg1[5:]
-                        value = value[: len(value) - 1]
+                        value = arg1[5:-1]
                         arguments = ["%s.append(%s)" % (".".join(part1), value)] + part2
                     elif member == "attributeValue":
-                        value = arg1[15:]
-                        value = value[: len(value) - 1]
+                        value = arg1[15:-1]
                         arguments = [
                             "%s.attributes().namedItem(%s).nodeValue()" % (".".join(part1), value)
                         ] + part2
@@ -1889,21 +1818,6 @@ class Member(ASTPython):
                                 % (part_list[0], ",".join(part_list[1:]), ".".join(part1))
                             ] + part2
                         else:
-                            # if not part2:
-                            # if ".".join(part1) and "replace(" in " ".join(arguments[0:1]):
-                            # arguments = ['numeroCSV', 'replace(".", ",")']
-                            #    rep_str = arguments[0]
-                            #    rep_from_to = arguments[1].replace("replace", "").strip()
-                            #    if rep_from_to[0] == "(" and rep_from_to[-1] == ")":
-                            #        rep_from_to = rep_from_to[1:-1]
-
-                            #    rep_extra = arguments[2:]
-                            # print(arguments)
-                            #    arguments = [
-                            #        "qsa.replace(%s, %s)" % (rep_str, rep_from_to)
-                            #    ] + rep_extra
-                            # print(arguments)
-                            # print("*")
                             rep_str = arguments[0]
                             rep_from_to = arguments[1].replace("replace", "").strip()
                             if rep_from_to[0] == "(" and rep_from_to[-1] == ")":
@@ -2030,12 +1944,7 @@ class Expression(ASTPython):
                     new_expr += [["expr", valor] for valor in cadena.split(" ")]
                     expr = new_expr
 
-                    found_in = False
-
-                if data == "in":
-                    found_in = True
-                else:
-                    found_in = False
+                found_in = data == "in"
 
         for dtype, data in expr:
             yield dtype, data
@@ -2199,18 +2108,18 @@ class New(ASTPython):
                     yield dtype, data
                     continue
                 if child.tag == "Identifier":
-                    data = data + "()"
-                ident = data[: data.find("(")]
-                if ident.find(".") == -1:
-                    parent_class = cast(ET.Element, self.elem.get("parent_"))
-                    # classIdent_ = False
-                    while parent_class is not None:
-                        if parent_class.tag == "Source":
-                            for item in parent_class.findall("Class"):
-                                if item.get("name") == ident:
-                                    # classIdent_ = True
-                                    break
-                        parent_class = cast(ET.Element, parent_class.get("parent_"))
+                    data += "()"
+                # ident = data[: data.find("(")]
+                # if ident.find(".") == -1:
+                #    parent_class = cast(ET.Element, self.elem.get("parent_"))
+                #    # classIdent_ = False
+                #    while parent_class is not None:
+                #        if parent_class.tag == "Source":
+                #            for item in parent_class.findall("Class"):
+                #                if item.get("name") == ident:
+                #                    # classIdent_ = True
+                #                    break
+                #        parent_class = cast(ET.Element, parent_class.get("parent_"))
 
                 yield dtype, data
 
@@ -2487,7 +2396,22 @@ class DeclarationBlock(ASTPython):
         # if mode == "CONST": yield "debug", "Const Declaration:"
         for var in self.elem:
             var.set("parent_", self.elem)  # type: ignore
+
+            is_valid = True
+
+            grand_parent_ = cast(ET.Element, self.elem.get("parent_"))
+            if grand_parent_ is not None and grand_parent_.tag == "Source":
+                class_parent_ = cast(ET.Element, grand_parent_.get("parent_"))
+                if (
+                    class_parent_ is not None
+                    and class_parent_.tag == "Class"
+                    and not class_parent_.get("extends")
+                ):
+                    static_flag: Optional[str] = self.elem.get("arg00")
+                    is_valid = static_flag and str(static_flag).startswith("STATIC")  # type: ignore [assignment]
+
             expr = []
+
             for dtype, data in parse_ast(var, parent=self).generate(force_value=True):
                 if dtype == "expr":
                     if data is None:
@@ -2496,7 +2420,6 @@ class DeclarationBlock(ASTPython):
                 else:
                     yield dtype, data
             if is_constructor:
-
                 if expr[0] in list(self.source.locals):
                     if expr[0] not in ["form", "iface"]:
                         # LOGGER.warning("Pasando de %s", expr[0])
@@ -2521,8 +2444,12 @@ class DeclarationBlock(ASTPython):
                             expr[1] = " :"
                             expr[2] = ' "%s"' % expr[2].replace("(self)", "")
             else:
-                if expr[0] == "ctx" and expr[1].find("qsa.Object") > -1:
-                    expr[1] = ': "FormInternalObj"'
+                if expr[0] == "ctx":
+                    if expr[1].find("qsa.Object") > -1:
+                        expr[1] = ': "FormInternalObj"'
+                else:
+                    if dtype == "expr" and not is_valid:
+                        expr.insert(0, "#")
             yield "line", " ".join(expr)
 
 
@@ -2581,10 +2508,7 @@ def file_template(ast: ET.Element, import_refs: Dict[str, Tuple[str, str]] = {})
 
     yield "line", "# -*- coding: utf-8 -*-"
     yield "line", "# Translated with pineboolib %s" % PINEBOO_VER
-    yield "line", "from typing import TYPE_CHECKING, Any, Union"
-
-    if not STRICT_MODE:
-        yield "line", "from pineboolib.qsa.qsa import *  # noqa: F403"
+    yield "line", "from typing import TYPE_CHECKING, Any, Optional, Union"
     yield "line", "from pineboolib.qsa import qsa"
     # yield "line", "from pineboolib.qsaglobals import *"
     for alias, (path, name) in import_refs.items():
@@ -2595,19 +2519,25 @@ def file_template(ast: ET.Element, import_refs: Dict[str, Tuple[str, str]] = {})
     yield "line", ""
 
     sourceclasses = ET.Element("Source")
+    add_form_internal_object = False
     for cls_ in ast.findall("Class"):
-        # LOGGER.warning("Element %s type(%s)", cls, type(cls_))
-        # cls_.set("parent_", cast(str, ast))  # FIXME: AST is an XML Element, not a string.
         sourceclasses.append(cast(ET.Element, cls_))
+        if cls_.get("name") == "ifaceCtx":
+            add_form_internal_object = True
 
-    mainclass = ET.SubElement(
-        sourceclasses, "Class", name="FormInternalObj", extends="qsa.FormDBWidget"
-    )
-    mainsource = ET.SubElement(mainclass, "Source")
+    only_iface = False
+    if add_form_internal_object:
+        mainclass = ET.SubElement(
+            sourceclasses, "Class", name="FormInternalObj", extends="qsa.FormDBWidget"
+        )
+        mainsource = ET.SubElement(mainclass, "Source")
 
-    constructor = ET.SubElement(mainsource, "Function", name="_class_init")
-    # args = etree.SubElement(constructor, "Arguments")
-    csource = ET.SubElement(constructor, "Source")
+        constructor = ET.SubElement(mainsource, "Function", name="_class_init")
+        # args = etree.SubElement(constructor, "Arguments")
+        csource = ET.SubElement(constructor, "Source")
+    else:
+        csource = mainsource = ET.SubElement(sourceclasses, "Source")
+        only_iface = True
 
     for child in ast:
         if child.tag != "Function":
@@ -2615,8 +2545,11 @@ def file_template(ast: ET.Element, import_refs: Dict[str, Tuple[str, str]] = {})
                 def_iface = copy.deepcopy(child)
                 def_iface.set("definition", "1")
                 child.set("constructor", "1")
-                csource.append(child)
-                mainsource.insert(0, def_iface)
+                if not only_iface:
+                    csource.append(child)
+                    mainsource.insert(0, def_iface)
+                else:
+                    mainsource.append(def_iface)
         else:
             mainsource.append(child)
 
@@ -2656,7 +2589,6 @@ def write_python_file(
     last_dtype = None
 
     parser_template = template_list[ast.get("parser-template", default="file_template")]
-
     for dtype, data in parser_template(ast, import_refs):
         # if isinstance(data, bytes):
         #    data = data.decode("UTF-8", "replace")
