@@ -5,13 +5,11 @@ from PyQt6 import QtCore, QtWidgets  # type: ignore[import]
 
 import unittest
 from pineboolib.application.parsers.parser_qsa.postparse import pythonify_string as qs2py
-from pineboolib.application.parsers.parser_qsa import pytnyzer
+from pineboolib.application.parsers import parser_qsa
 from pineboolib.application.parsers.parser_qsa.tests import fixture_read, fixture_path
 from pineboolib.loader.main import init_testing, finish_testing
 
 from pineboolib.core.utils import utils_base
-from pineboolib.application.parsers import parser_qsa
-
 import os
 import shutil
 
@@ -22,7 +20,8 @@ class TestParser(unittest.TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         """Enable strict parsing."""
-        pytnyzer.STRICT_MODE = True
+
+        parser_qsa.STRICT_MODE = True
         init_testing()
 
     def test_basic(self) -> None:
@@ -113,6 +112,8 @@ class TestParser(unittest.TestCase):
 
     def test_lib_str(self) -> None:
         """Test conveting fixture lib_str."""
+
+        parser_qsa.STRICT_MODE = False
         self.maxDiff = None  # pylint: disable=invalid-name
         flfacturac_qs = fixture_read("lib_str.qs")
         flfacturac_py = fixture_read("lib_str.python")
@@ -124,7 +125,7 @@ class TestParser(unittest.TestCase):
         flfacturac_qs_py = flfacturac_qs_py.replace(
             flfacturac_qs_py[pos_ini : pos_ini + pos_fin + 1], ""
         )
-
+        parser_qsa.STRICT_MODE = True
         # Write onto git so we have an example.
         with open(fixture_path("lib_str.qs.python"), "w") as file_:
             file_.write(flfacturac_qs_py)
@@ -389,6 +390,97 @@ qsa.from_project("flfactppal").iface.replace(listaOutlet, ", ", " ", " ")\n""",
         self.assertTrue(qs_py.find("TYPE_INT_") > -1)
         self.assertTrue(qs_py.find("TYPE_UINT_") > -1)
 
+    def test_anon_class(self) -> None:
+        """Test converting anon class"""
+
+        qsa = """class ProveedorDefectoSetter {
+        var esta_no;
+        static var esta_si;
+        static function fun1() {
+
+            }
+        function fun2() {
+            }
+        }"""
+
+        valid = """# /** @class_declaration ProveedorDefectoSetter */
+class ProveedorDefectoSetter(qsa.ObjectClass):
+    # esta_no : Any = None
+    esta_si: Any = None
+
+    @classmethod
+    def fun1(self):
+        pass
+
+    def fun2(self):
+        pass
+"""
+        require_qs_py = qs2py(qsa)
+
+        self.assertEqual(require_qs_py, valid)
+
+    def test_require(self) -> None:
+        """Test conveting fixture require.qs"""
+        self.maxDiff = None
+        require_qs = fixture_read("require.qs")
+
+        old_tags = parser_qsa.IGNORE_NO_PYTHON_TAGS
+        old_desktop = utils_base.FORCE_DESKTOP
+        parser_qsa.IGNORE_NO_PYTHON_TAGS = False
+        utils_base.FORCE_DESKTOP = False
+        require_qs_py = qs2py(require_qs)
+        require_py = fixture_read("require.python")
+
+        # Delete version translator tag.
+        pos_ini = require_qs_py.find("# Translated with pineboolib ")
+        pos_fin = require_qs_py[pos_ini:].find("\n")
+        require_qs_py = require_qs_py.replace(require_qs_py[pos_ini : pos_ini + pos_fin + 1], "")
+        parser_qsa.IGNORE_NO_PYTHON_TAGS = old_tags
+        utils_base.FORCE_DESKTOP = old_desktop
+        self.assertEqual(require_qs_py, require_py)
+
+    def test_staticclass(self) -> None:
+        """Test static class."""
+
+        self.maxDiff = None
+        file_qs = fixture_read("static_class.qs")
+        require_qs_py = qs2py(file_qs)
+        require_py = fixture_read("static_class.python")
+
+        # Delete version translator tag.
+        pos_ini = require_qs_py.find("# Translated with pineboolib ")
+        pos_fin = require_qs_py[pos_ini:].find("\n")
+        require_qs_py = require_qs_py.replace(require_qs_py[pos_ini : pos_ini + pos_fin + 1], "")
+        self.assertEqual(require_qs_py, require_py)
+
+        """     def test_var_first(self) -> None:
+        "Test when a var is first."
+
+        self.maxDiff = None
+        file_qs = fixture_read("varfirst.qs")
+        require_qs_py = qs2py(file_qs)
+
+        require_py = fixture_read("varfirst.python")
+
+        # Delete version translator tag.
+        pos_ini = require_qs_py.find("# Translated with pineboolib ")
+        pos_fin = require_qs_py[pos_ini:].find("\n")
+        require_qs_py = require_qs_py.replace(require_qs_py[pos_ini : pos_ini + pos_fin + 1], "")
+        self.assertEqual(require_qs_py, require_py) """
+
+    def test_dict(self) -> None:
+        """Test dictionary."""
+
+        qsa = """const _i = this.iface;
+
+                const aDatosFactRect = {
+                "codalmacen" : _i.calcularCodAlmacenFacturaRect(cursor, facturaRect),
+                "regimeniva" : _i.calcularRegimenIvaFacturaRect(cursor, facturaRect),
+                "codagente" : _i.calcularCodAgenteFacturaRect(cursor, facturaRect),
+                }"""
+        require_qs_py = qs2py(qsa)
+        self.assertTrue(require_qs_py)
+
     @classmethod
     def tearDownClass(cls) -> None:
         """Ensure test clear all data."""
