@@ -74,10 +74,10 @@ def load_ui(form_path: str, widget: Any, parent: Optional["QtWidgets.QWidget"] =
     # if application.PROJECT.DGI.localDesktop():
     widget.hide()
 
-    for xmlimage in ROOT.findall("images//image"):
+    for xmlimage in ROOT.findall("images//image"):  # type: ignore [union-attr]
         load_icon(xmlimage)
 
-    for xmlwidget in ROOT.findall("widget"):
+    for xmlwidget in ROOT.findall("widget"):  # type: ignore [union-attr]
         LoadWidget(xmlwidget, widget, parent)
 
     # print("----------------------------------")
@@ -94,17 +94,17 @@ def load_ui(form_path: str, widget: Any, parent: Optional["QtWidgets.QWidget"] =
     #    load_action(action, widget)
 
     # Cargamos menubar ...
-    xmlmenubar = ROOT.find("menubar")
+    xmlmenubar = ROOT.find("menubar")  # type: ignore [union-attr]
     # print("Cargamos menubar!")
-    if xmlmenubar:
+    if xmlmenubar is not None:
         load_menu_bar(xmlmenubar, widget)
 
     # Cargamos toolbars ...
     # print("Cargamos toolbar!")
-    for xmltoolbar in ROOT.findall("toolbars//toolbar"):
+    for xmltoolbar in ROOT.findall("toolbars//toolbar"):  # type: ignore [union-attr]
         load_tool_bar(xmltoolbar, widget)
 
-    for xmlconnection in ROOT.findall("connections//connection"):
+    for xmlconnection in ROOT.findall("connections//connection"):  # type: ignore [union-attr]
         sender_elem = xmlconnection.find("sender")
         signal_elem = xmlconnection.find("signal")
         receiv_elem = xmlconnection.find("receiver")
@@ -137,7 +137,6 @@ def load_ui(form_path: str, widget: Any, parent: Optional["QtWidgets.QWidget"] =
         else:
             senders = widget.findChildren(QtCore.QObject, sender_name)
             for sender in senders:
-
                 # if not application.PROJECT.DGI.localDesktop():
                 #    wui = hasattr(widget, "ui_") and sender_name in widget.ui_
                 #    if sender is None and wui:
@@ -187,7 +186,6 @@ def load_ui(form_path: str, widget: Any, parent: Optional["QtWidgets.QWidget"] =
                     #    ifx = widget.iface
                     if hasattr(ifx, fn_name):
                         try:
-
                             # getattr(sender, sg_name).connect(
                             #    getattr(ifx, fn_name))
                             connections.connect(sender, signal_name, ifx, fn_name)
@@ -297,16 +295,18 @@ def load_tool_bar(xml: ET.Element, widget: QtWidgets.QMainWindow) -> None:
         if action.tag == "action":
             name = action.get("name") or "action"
             new_action = tool_bar.addAction(name)
-            new_action.setObjectName(name)
-            # print("**", name, new_action, tool_bar)
-            load_action(action, widget, new_action)
-            # print("**", new_action.objectName())
-            # clone_action(new_action, widget)
+            if new_action:
+                new_action.setObjectName(name)
+                # print("**", name, new_action, tool_bar)
+                load_action(action, widget, new_action)
+                # print("**", new_action.objectName())
+                # clone_action(new_action, widget)
 
             # FIXME!!, meter el icono y resto de datos!!
         elif action.tag == "separator":
             separator = tool_bar.addSeparator()
-            separator.setObjectName("separator")
+            if separator:
+                separator.setObjectName("separator")
         elif action.tag == "widget":
             new_widget = WidgetResolver.get_widget_class(action.get("class") or "")(tool_bar)
             LoadWidget(action, new_widget, None, tool_bar)
@@ -327,29 +327,31 @@ def load_menu_bar(xml: "ET.Element", widget: "QtWidgets.QWidget") -> None:
         menu_bar = widget.menuBar()
     else:
         menu_bar = QtWidgets.QMenuBar(widget)
-        widget.layout().setMenuBar(menu_bar)  # quitamos _layout()
+        if menu_bar:
+            widget.layout().setMenuBar(menu_bar)  # type: ignore [union-attr] # quitamos _layout()
     for item in xml:
         if item.tag == "property":
             name = item.get("name")
             if name == "name":
                 cstring = item.find("cstring")
-                if cstring is not None and cstring.text is not None:
+                if cstring is not None and cstring.text is not None and menu_bar:
                     menu_bar.setObjectName(cstring.text)
             elif name == "geometry":
                 geo_ = item.find("rect")
-                if geo_:
+                if geo_ is not None:
                     geo_x = geo_.find("x")
                     geo_y = geo_.find("y")
                     geo_width = geo_.find("width")
                     geo_height = geo_.find("height")
 
-                    pos_x = geo_x.text if geo_x else None
-                    pos_y = geo_y.text if geo_y else None
-                    width = geo_width.text if geo_width else None
-                    height = geo_height.text if geo_height else None
+                    pos_x = geo_x.text if geo_x is not None else None
+                    pos_y = geo_y.text if geo_y is not None else None
+                    width = geo_width.text if geo_width is not None else None
+                    height = geo_height.text if geo_height is not None else None
                     if pos_x is None or pos_y is None or width is None or height is None:
                         continue
-                    menu_bar.setGeometry(int(pos_x), int(pos_y), int(width), int(height))
+                    if menu_bar:
+                        menu_bar.setGeometry(int(pos_x), int(pos_y), int(width), int(height))
             elif name in ("acceptDrops", "defaultUp"):
                 bool_elem = item.find("bool")
                 if bool_elem is not None:
@@ -361,7 +363,7 @@ def load_menu_bar(xml: "ET.Element", widget: "QtWidgets.QWidget") -> None:
             #    bool_elem = item.find("bool")
             #    if bool_elem is not None:
             #        menu_bar.setDefaultUp(bool_elem.text == "true")
-        elif item.tag == "item":
+        elif item.tag == "item" and menu_bar:
             process_item(item, menu_bar, widget)
 
 
@@ -380,19 +382,21 @@ def process_item(
     # accel = xml.get("accel")
 
     menu_ = parent.addMenu(text)
-    menu_.setObjectName(name)
+    if menu_:
+        menu_.setObjectName(name)
 
-    for item in xml:
-        if item.tag == "action":
-            name_ = item.get("name") or ""
-            new_action = menu_.addAction(name_)
-            new_action.setObjectName(name_)
+        for item in xml:
+            if item.tag == "action":
+                name_ = item.get("name") or ""
+                new_action = menu_.addAction(name_)
+                if new_action:
+                    new_action.setObjectName(name_)
 
-            load_action(item, widget, new_action)
-            # action.setObjectName(name_)
-            # clone_action(action, widget)
-        elif item.tag == "item":
-            process_item(item, menu_, widget)
+                    load_action(item, widget, new_action)
+                # action.setObjectName(name_)
+                # clone_action(action, widget)
+            elif item.tag == "item":
+                process_item(item, menu_, widget)
 
 
 def clone_action(action: "QtGui.QAction", widget: "QtWidgets.QWidget") -> None:
@@ -417,18 +421,18 @@ def clone_action(action: "QtGui.QAction", widget: "QtWidgets.QWidget") -> None:
 
 
 def load_action(
-    action: "ET.Element", widget: "QtWidgets.QWidget", action_widget: "QtGui.QAction" = None
+    action: "ET.Element",
+    widget: "QtWidgets.QWidget",
+    action_widget: Optional["QtGui.QAction"] = None,
 ) -> None:
     """
     Load Action into widget.
 
     widget: pre-created widget to store the object.
     """
-    global ICONS
-    if action_widget is not None:
-        new_action = action_widget
-    else:
-        new_action = QtGui.QAction(widget)
+    global ICONS  # noqa: F824
+
+    new_action = action_widget if action_widget is not None else QtGui.QAction(widget)
 
     action_name = action.get("name")
     for root_action in ROOT.findall("actions//action"):  # type: ignore [union-attr] # noqa: F821
@@ -944,7 +948,7 @@ class LoadWidget:
 
                 if isinstance(widget, qbuttongroup.QButtonGroup):
                     if isinstance(new_widget, qtoolbutton.QToolButton):
-                        widget.addButton(new_widget)
+                        widget.addButton(new_widget)  # type: ignore [misc]
                         continue
 
                 LoadWidget(item, new_widget, self.parent, self.orig_widget)
@@ -1037,7 +1041,7 @@ class LoadWidget:
 
 def load_icon(xml: "ET.Element") -> None:
     """Load Icon from XML."""
-    global ICONS
+    global ICONS  # noqa: F824
 
     name = xml.get("name")
     xmldata = xml.find("data")
@@ -1101,9 +1105,8 @@ def _load_variant(variant: ET.Element, widget: Optional[QtCore.QObject] = None)
     if variant.tag == "cstring":
         return text
     elif variant.tag in ["iconset", "pixmap"]:
-        global ICONS
+        global ICONS  # noqa: F824
         if text in ICONS.keys():
-
             return ICONS[text]
         else:
             LOGGER.warning("Icon %s not found:", text)
@@ -1123,13 +1126,12 @@ def _load_variant(variant: ET.Element, widget: Optional[QtCore.QObject] = None)
         return QtCore.QRect(rect_["x"], rect_["y"], rect_["width"], rect_["height"])
 
     elif variant.tag == "sizepolicy":
-
         policy = QtWidgets.QSizePolicy()
         for item in variant:
             ivalue_policy = int((item.text or "0").strip())
             real_policy: Any = None
             for it_ in policy.Policy:
-                if it_.value == ivalue_policy:
+                if it_.value == ivalue_policy:  # type: ignore [comparison-overlap]
                     real_policy = it_
                     break
 
@@ -1185,9 +1187,9 @@ def _load_variant(variant: ET.Element, widget: Optional[QtCore.QObject] = None)
             text = text.replace("WordBreak|", "")
 
         for item_ in text.split("|"):
-            value = getattr(QtCore.Qt, item_, None)
-            if value is not None:
-                final = final + int(value)
+            value3 = getattr(QtCore.Qt, item_, None)
+            if value3 is not None:
+                final = final + int(value3)
 
         return QtCore.Qt.AlignmentFlag(final)
 
@@ -1208,9 +1210,9 @@ def _load_variant(variant: ET.Element, widget: Optional[QtCore.QObject] = None)
             QtWidgets.QLineEdit.EchoMode,
         ]
         for lib in libs_2:
-            value = getattr(lib, text, None)
-            if value is not None:
-                return value
+            value2 = getattr(lib, text, None)
+            if value2 is not None:
+                return value2
         if text in ["GroupBoxPanel", "LineEditPanel", "ToolBarPanel"]:
             return QtWidgets.QFrame.Shape.StyledPanel
         if text in ("Single", "SingleRow"):
@@ -1271,7 +1273,6 @@ def _load_variant(variant: ET.Element, widget: Optional[QtCore.QObject] = None)
         return pal_
 
     elif variant.tag == "date":
-
         year_ = 2000
         month_ = 1
         day_ = 1
