@@ -11,8 +11,10 @@ from pineboolib import application
 from pineboolib.application.database import DB_SIGNALS, utils
 from pineboolib.application.qsatypes import sysbasetype
 from pineboolib.application import qsadictmodules
+from pineboolib.application.utils import external
 
 import sys
+import os
 from typing import Any, Optional, List, TextIO, cast, Union, Dict, TYPE_CHECKING
 
 
@@ -233,14 +235,15 @@ class PNApplication(QtCore.QObject):
             action_group = QtGui.QActionGroup(style_menu)
             for style_ in QtWidgets.QStyleFactory.keys():
                 action_ = style_menu.addAction(style_)  # type: ignore [union-attr] # noqa : F821
-                action_.setObjectName("style_%s" % style_)
-                action_.setCheckable(True)
-                if style_ == style_read:
-                    action_.setChecked(True)
+                if action_:
+                    action_.setObjectName("style_%s" % style_)
+                    action_.setCheckable(True)
+                    if style_ == style_read:
+                        action_.setChecked(True)
 
-                action_.triggered.connect(self.style_mapper.map)
-                self.style_mapper.setMapping(action_, style_)
-                action_group.addAction(action_)
+                    action_.triggered.connect(self.style_mapper.map)  # type: ignore [union-attr, arg-type]
+                    self.style_mapper.setMapping(action_, style_)
+                    action_group.addAction(action_)
             action_group.setExclusive(True)
 
         self.style = True
@@ -272,15 +275,17 @@ class PNApplication(QtCore.QObject):
 
         tab_names: str = ""
         for number in range(tab_widget.count()):
-            item: "QtWidgets.QWidget" = tab_widget.widget(number)
-            tab_names += "%s/%s*" % (item.objectName(), tab_widget.tabText(number))
+            item: Optional["QtWidgets.QWidget"] = tab_widget.widget(number)
+            if item:
+                tab_names += "%s/%s*" % (item.objectName(), tab_widget.tabText(number))
 
         return tab_names
 
     @decorators.not_implemented_warn
     def getWidgetList(self, widget_name: str, class_name: str) -> List:
         """Get widgets."""
-        pass
+
+        return []
 
     def aboutQt(self) -> None:
         """Show About QT."""
@@ -306,7 +311,7 @@ class PNApplication(QtCore.QObject):
         if main_widget is None:
             return
 
-        cast(QtWidgets.QMainWindow, main_widget).statusBar().showMessage(text, 2000)
+        cast(QtWidgets.QMainWindow, main_widget).statusBar().showMessage(text, 2000)  # type: ignore [union-attr]
 
     def loadScriptsFromModule(self, id_module: str) -> None:
         """Load scripts from named module."""
@@ -392,7 +397,6 @@ class PNApplication(QtCore.QObject):
         )
 
         if ctx is not None:
-
             msg += self.tr("Contexto: %s\n" % ctx)
 
         # FIXME: Missing _gui parameter
@@ -449,6 +453,9 @@ class PNApplication(QtCore.QObject):
         application.PROJECT.files = {}
         application.PROJECT.conn_manager.useConn("default")
         application.PROJECT.conn_manager.useConn("dbaux")
+
+        external.reload_project_config()
+
         application.PROJECT.run()
         # application.PROJECT.load_classes()
         # application.PROJECT.load_orm()
@@ -471,7 +478,6 @@ class PNApplication(QtCore.QObject):
 
         self._inicializing = False
         if not utils_base.is_library():
-
             if application.PROJECT.main_window:
                 if not hasattr(application.PROJECT.main_window, "initModule"):
                     self.call("sys.init()", [])
@@ -658,12 +664,11 @@ class PNApplication(QtCore.QObject):
 
         if application.PROJECT.main_window is not None:
             if self._ted_output:
-                self._ted_output.parentWidget().close()
+                self._ted_output.parentWidget().close()  # type: ignore [union-attr]
 
             dock_widget = QtWidgets.QDockWidget("tedOutputDock", application.PROJECT.main_window)
 
             if dock_widget is not None:
-
                 self._ted_output = TextEditOutput(dock_widget)
                 dock_widget.setWidget(self._ted_output)
                 dock_widget.setWindowTitle(self.tr("Mensajes de Eneboo"))
@@ -674,8 +679,8 @@ class PNApplication(QtCore.QObject):
     def consoleShown(self) -> bool:
         """Return if console is shown."""
 
-        hidden = getattr(self._ted_output, "isHidden", False)
-        return hidden() if hidden is not None else False
+        hidden = getattr(self._ted_output, "isHidden", None)
+        return False if hidden is None else hidden()
 
     def modMainWidget(self, id_modulo: str) -> Optional["QtWidgets.QWidget"]:
         """Set module main widget."""
@@ -799,7 +804,6 @@ class PNApplication(QtCore.QObject):
             return False
 
         if application.PROJECT.conn_manager.mainConn().interactiveGUI():
-
             main_widget = application.PROJECT.main_window
             if main_widget is not None:
                 ret = QtWidgets.QMessageBox.question(
@@ -958,8 +962,8 @@ class PNApplication(QtCore.QObject):
 
     def applicationDirPath(self) -> str:
         """Return application dir path."""
-
-        return application.PROJECT.app.applicationDirPath()
+        return os.path.abspath(os.path.join(os.path.dirname(__file__), "..", ".."))
+        # return application.PROJECT.app.applicationDirPath()
 
     def transactionLevel(self):
         """Return number of concurrent transactions."""
