@@ -2,7 +2,6 @@
 Project Module.
 """
 
-
 from pineboolib import logging
 
 from pineboolib.core.utils import utils_base, struct
@@ -24,7 +23,11 @@ from typing import List, Optional, Any, Dict, Callable, Union, TYPE_CHECKING
 from pineboolib import application
 
 if TYPE_CHECKING:
-    from pineboolib.interfaces import dgi_schema, imainwindow  # noqa: F401 # pragma: no cover
+    from pineboolib.interfaces import (
+        dgi_schema,
+        imainwindow,
+        iconnection,
+    )  # noqa: F401 # pragma: no cover
     from pineboolib.application.database import pnconnection  # pragma: no cover
     from pineboolib.application import xmlaction, pnapplication  # noqa: F401 # pragma: no cover
     from PyQt6 import QtWidgets  # type: ignore[import] # pragma: no cover
@@ -45,14 +48,11 @@ class Project(object):
 
     _app: "QtWidgets.QApplication"
     _aq_app: Optional["pnapplication.PNApplication"] = None
-    # _conn: Optional["PNConnection"] = None  # Almacena la conexión principal a la base de datos
-    debug_level = 100
-    # options: Values
 
     main_window: Optional["imainwindow.IMainWindow"] = None
     dgi: Optional["dgi_schema.dgi_schema"] = None
     delete_cache: bool = False
-    parse_project: bool
+    delete_base_cache: bool
     path = None
     _splash = None
     sql_drivers_manager = None
@@ -69,7 +69,7 @@ class Project(object):
     modules: Dict[str, "module.Module"]
     pending_conversion_list: List[str]
     USE_FLFILES_FOLDER: str = ""
-    _db_admin_mode: bool = False
+    db_admin_mode: bool = False
 
     def __init__(self) -> None:
         """Initialize."""
@@ -81,15 +81,16 @@ class Project(object):
         self.apppath = ""
         self.tmpdir = settings.CONFIG.value("ebcomportamiento/temp_dir", "")
         self.parser = None
-        self.delete_cache = False
-        self.parse_project = True
-        self.no_python_cache = False
 
+        self.no_python_cache = settings.CONFIG.value("ebcomportamiento/noPythonCache", False)
+        self.apppath = utils_base.filedir("..")
+        self.delete_base_cache = settings.CONFIG.value("ebcomportamiento/keep_general_cache", False)
+        self.delete_cache = settings.CONFIG.value("ebcomportamiento/deleteCache", False)
         self.actions = {}
         self.files = {}
         self.areas = {}
         self.modules = {}
-        self._db_admin_mode = settings.CONFIG.value("application/dbadmin_enabled", False)
+        self.db_admin_mode = settings.CONFIG.value("application/dbadmin_enabled", False)
 
         import pathlib
 
@@ -158,24 +159,7 @@ class Project(object):
         #    del self._conn
         #    self._conn = None
 
-        result_init_conn = self.conn_manager.setMainConn(connection)
-
-        if result_init_conn:
-            self.apppath = utils_base.filedir("..")
-            self.delete_cache = settings.CONFIG.value("ebcomportamiento/deleteCache", False)
-
-            self.parse_project = (
-                settings.CONFIG.value("ebcomportamiento/parseProject", True)
-                if application.PARSE_PROJECT_ON_INIT
-                else False
-            )
-
-            if not self.no_python_cache:
-                self.no_python_cache = settings.CONFIG.value(
-                    "ebcomportamiento/noPythonCache", False
-                )
-
-        return result_init_conn
+        return self.conn_manager.setMainConn(connection)
 
     def init_dgi(self, dgi: "dgi_schema.dgi_schema") -> None:
         """Load and associate the defined DGI onto this project."""
@@ -228,15 +212,6 @@ class Project(object):
 
             db_utils.process_file_class(self.files[key])
 
-    def setDebugLevel(self, level: int) -> None:
-        """
-        Set debug level for application.
-
-        @param q Número con el nivel espeficicado
-        ***DEPRECATED***
-        """
-        self.debug_level = level
-
     def run(self) -> bool:
         """Run project. Connects to DB and loads data."""
 
@@ -268,11 +243,13 @@ class Project(object):
                     if not os.path.exists(path_med):
                         os.mkdir(path_med)
             except Exception as error:
-                raise Exception("Error building cache folder (%s) : %s" % (path_build, error))
+                raise Exception(
+                    "Error building cache folder (%s) : %s" % (path_build, error)
+                ) from error
 
         if os.path.exists(db_cache_folder):
-
             if not os.path.exists(cache_version_file_path):
+                LOGGER.warning("QSA parser version not found in %s.", cache_version_file_path)
                 delete_cache = True
             else:
                 cache_ver = ""
@@ -281,6 +258,7 @@ class Project(object):
                     cache_ver = file_ver.read()
                     file_ver.close()
                 except Exception:
+                    LOGGER.warning("Error reading %s", cache_version_file_path)
                     pass
                 if cache_ver != parser_qsa.PARSER_QSA_VERSION:
                     delete_cache = True
@@ -288,15 +266,15 @@ class Project(object):
             if delete_cache:
                 if cache_ver != parser_qsa.PARSER_QSA_VERSION:
                     LOGGER.warning(
-                        "QSA parser version has changed from %s to %s!. Deleting cache.",
+                        "QSA parser version has changed from %s (%s) to %s!. Deleting cache.",
                         cache_ver,
+                        cache_version_file_path,
                         parser_qsa.PARSER_QSA_VERSION,
                     )
                 else:
                     LOGGER.warning("Deleting cache.")
 
         if delete_cache and os.path.exists(db_cache_folder):
-
             self.message_manager().send("splash", "showMessage", ["Borrando caché ..."])
             LOGGER.info("DEVELOP: delete_cache Activado\nBorrando %s", db_cache_folder)
 
@@ -309,19 +287,15 @@ class Project(object):
                         if os.path.exists(os.path.join(root, name)):
                             os.rmdir(os.path.join(root, name))
 
-        else:
-            keep_images = settings.CONFIG.value("ebcomportamiento/keep_general_cache", False)
-            if keep_images is False:
-                for file_name in os.listdir(self.tmpdir):
-                    if file_name.find(".") > -1 and not file_name.endswith("sqlite3"):
-                        file_path = os.path.join(self.tmpdir, file_name)
-                        try:
-                            os.remove(file_path)
-                        except Exception:
-                            LOGGER.warning(
-                                "No se ha podido borrar %s al limpiar la cache", file_path
-                            )
-                            pass
+        elif self.delete_base_cache:
+            for file_name in os.listdir(self.tmpdir):
+                if file_name.find(".") > -1 and not file_name.endswith("sqlite3"):
+                    file_path = os.path.join(self.tmpdir, file_name)
+                    try:
+                        os.remove(file_path)
+                    except Exception:
+                        LOGGER.warning("No se ha podido borrar %s al limpiar la cache", file_path)
+                        pass
 
         if not os.path.exists(cache_folder):
             LOGGER.info("RUN: Creating %s folder.", cache_folder)
@@ -331,10 +305,12 @@ class Project(object):
             LOGGER.info("RUN: Creating %s folder.", db_cache_folder)
             os.makedirs(db_cache_folder)
 
-        file_ver = open(cache_version_file_path, "w", encoding="UTF8")
-        file_ver.write(parser_qsa.PARSER_QSA_VERSION)
-        file_ver.close()
-        del file_ver
+        if delete_cache or not os.path.exists(cache_version_file_path):
+            LOGGER.warning("RUN: Writing %s file.", cache_version_file_path)
+            file_ver = open(cache_version_file_path, "w", encoding="UTF8")
+            file_ver.write(parser_qsa.PARSER_QSA_VERSION)
+            file_ver.close()
+            del file_ver
 
         return self.load_system_module() and self.load_database_modules()
 
@@ -384,7 +360,6 @@ class Project(object):
         function_object = getattr(object_context, function_name, None)
         if function_object is not None:
             try:
-
                 # Controlar numero de argumentos
                 args_num = connections.get_expected_args_num(function_object)
                 while args_num > len(args):
@@ -440,7 +415,7 @@ class Project(object):
     def parse_script_list(self, path_list: List[str]) -> bool:
         """Convert QS scripts list into Python and stores it in the same folders."""
 
-        from pineboolib.application.parsers.parser_qsa import pytnyzer, pyconvert
+        from pineboolib.application.parsers.parser_qsa import pyconvert
 
         if not path_list:
             return True
@@ -449,8 +424,6 @@ class Project(object):
             if not os.path.isfile(file_path):
                 raise IOError
 
-        pytnyzer.STRICT_MODE = True
-
         itemlist = []
         size_list = len(path_list)
         for num, orig_file_name in enumerate(path_list):
@@ -508,7 +481,7 @@ class Project(object):
         """Initialize current version numbers."""
         from pineboolib.application import PINEBOO_VER
 
-        return "DBAdmin v%s" % PINEBOO_VER if self._db_admin_mode else "Quick v%s" % PINEBOO_VER
+        return "DBAdmin v%s" % PINEBOO_VER if self.db_admin_mode else "Quick v%s" % PINEBOO_VER
 
     def message_manager(self):
         """Return message manager for splash and progress."""
@@ -530,7 +503,9 @@ class Project(object):
         base_dir = utils_base.get_base_dir()
         is_library = utils_base.is_library()
 
-        file_object = open(utils_base.filedir(base_dir, "system_module", "sys.xpm"), "r")
+        file_object = open(
+            utils_base.filedir(base_dir, "system_module", "sys.xpm"), "r", encoding="UTF-8"
+        )
         icono = file_object.read()
         file_object.close()
 
@@ -539,7 +514,6 @@ class Project(object):
         self.modules["sys"] = module.Module("sys", "sys", "Administración", icono, "1.0")
         for root, dirs, files in os.walk(utils_base.filedir(base_dir, "system_module")):
             for nombre in files:
-
                 if "tests" in root:
                     continue
 
@@ -571,11 +545,8 @@ class Project(object):
             "flmetadata",
             "flsettings",
             "flupdates",
-            "flmetadata",
             "flseqs",
-            "flsettings",
         ):
-
             self.conn_manager.manager().createSystemTable(table)
 
         return True
@@ -616,7 +587,6 @@ class Project(object):
             )
 
         for idarea, idmodulo, descripcion, icono, version in list(result_modules):
-
             if idmodulo not in self.modules:
                 icon_cached = xpm.cache_xpm(icono)
                 self.modules[idmodulo] = module.Module(
@@ -631,12 +601,11 @@ class Project(object):
                 """SELECT idmodulo, nombre, sha, bloqueo FROM flfiles WHERE NOT sha = '' ORDER BY idmodulo, nombre """
             )
 
-        log_file = open(path._dir("project.txt"), "w")
+        log_file = open(path._dir("project.txt"), "w", encoding="UTF-8")
 
         list_files: List[str] = []
         LOGGER.info("RUN: Populating cache.")
         for idmodulo, nombre, sha, contenido_or_bloqueo in list(result_files):
-
             if idmodulo not in self.modules.keys():  # Si el módulo no existe.
                 continue
 
@@ -658,11 +627,13 @@ class Project(object):
 
             fileobjdir = os.path.dirname(path._dir("cache", fileobj.filekey))
             file_name = path._dir("cache", fileobj.filekey)
-            if not os.path.exists(file_name):  # Borra
+            if not os.path.isfile(file_name) or not os.path.getsize(
+                file_name
+            ):  # Borra si no existe el fichero o está vacio.
                 if os.path.exists(fileobjdir):
                     utils_base.empty_dir(fileobjdir)
                 else:
-                    os.makedirs(fileobjdir)
+                    os.makedirs(fileobjdir, exist_ok=True)
 
                 contenido_content: Optional[str] = None
 
@@ -676,7 +647,7 @@ class Project(object):
                     )
 
                     result_content: Any = None
-                    if qry is not None:
+                    if qry:
                         result_content = qry.first()
 
                     if result_content is not None:
@@ -701,7 +672,7 @@ class Project(object):
                     if os.path.exists(static_flag):
                         os.remove(static_flag)
 
-            if self.parse_project:
+            if application.PARSE_PROJECT_ON_INIT:
                 if nombre.endswith(".qs"):
                     if self.no_python_cache or not os.path.exists(
                         "%spy" % file_name[:-2]
@@ -710,6 +681,9 @@ class Project(object):
 
         log_file.close()
         LOGGER.info("RUN: End populating cache.")
+        if self.USE_FLFILES_FOLDER and application.UPDATE_FLFILES_FROM_FLFOLDER:
+            self.update_flfiles(result_files, conn)
+
         self.conn_manager.removeConn("dbaux")
         del log_file
 
@@ -725,3 +699,101 @@ class Project(object):
                 return False
 
         return True
+
+    def update_flfiles(self, files_list: List[List[str]], conn: "iconnection.IConnection") -> None:
+        """Actualiza la tabla flfiles con el contenido de flfiles_folder."""
+
+        model_flsettins = qsadictmodules.QSADictModules.orm_("flsettings").get("sha_flfiles")
+        sha_flfiles = model_flsettins.valor if model_flsettins else None
+        sha_flfolder = ""
+        for id_module, file_name, string_sha, data in files_list:
+            sha_flfolder = utils_base.sha1("%s%s" % (sha_flfolder, string_sha))
+
+        if not sha_flfolder or sha_flfolder == sha_flfiles:
+            LOGGER.warning("SHA_FLFILES:%s" % (sha_flfiles))
+            return
+        LOGGER.warning("SHA_FLFILES CHANGED: OLD:%s, NEW:%s" % (sha_flfiles, sha_flfolder))
+        LOGGER.warning("Updating flfiles table from flfiles folder.")
+        # 1 vaciar flfiles
+        LOGGER.warning("(1/5) Deleting older data from tables ...")
+        conn.execute_query("DELETE FROM flareas")
+        conn.execute_query("DELETE FROM flmodules")
+        conn.execute_query("DELETE FROM flfiles")
+        # 2 insertar flareas
+        LOGGER.warning("(2/5) Updating flareas ...")
+        for data_area in self.areas.values():
+            model_areas = qsadictmodules.QSADictModules.orm_("flareas")()
+            model_areas.idarea = data_area.idarea
+            model_areas.descripcion = data_area.descripcion
+            model_areas.bloqueo = data_area.idarea != "sys"
+            if not model_areas.save():
+                LOGGER.error("Error saving area %s", data_area.idarea)
+                continue
+        LOGGER.warning("(3/5) Updating flmodules ...")
+        for data_module in self.modules.values():
+            model_modules = qsadictmodules.QSADictModules.orm_("flmodules")()
+            model_modules.idarea = data_module.areaid
+            model_modules.idmodulo = data_module.name
+            model_modules.descripcion = data_module.description
+            model_modules.icono = data_module.icon
+            model_modules.version = data_module.version
+            model_modules.bloqueo = data_module.name != "sys"
+            if not model_modules.save():
+                LOGGER.error("Error saving module %s", data_module.name)
+                continue
+
+        LOGGER.warning("(4/5) Updating flfiles ...")
+        for id_module, file_name, string_sha, data_str in files_list:
+            if id_module == "sys":
+                continue
+
+            if not file_name.endswith(
+                (
+                    ".ar",
+                    ".jrxml",
+                    ".kut",
+                    ".mod",
+                    ".mtd",
+                    ".py",
+                    ".qs",
+                    ".qry",
+                    ".ts",
+                    ".ui",
+                    ".xml",
+                    ".xpm",
+                )
+            ):
+                LOGGER.debug("\t* Skipping %s", file_name)
+                continue
+
+            model_files = qsadictmodules.QSADictModules.orm_("flfiles")()
+            model_files.idmodulo = id_module
+            model_files.nombre = file_name
+            model_files.sha = string_sha
+            model_files.contenido = data_str
+            result = False
+            error = ""
+            try:
+                result = model_files.save()
+            except Exception as err:
+                error = str(err)
+
+            if not result:
+                LOGGER.error("Error saving file %s. %s", file_name, error)
+
+        # 6 Limpiar/actualizar flmetadata
+        LOGGER.warning("(5/5) Updating flmetadata ...")
+        self.conn_manager.manager().cleanupMetaData()
+        # 7 actualizar sha
+        # flutil.FLUtil.writeDBSettingEntry("sha_flfiles", sha_flfolder)
+        model_settings = (
+            qsadictmodules.QSADictModules.orm_("flsettings").get("sha_flfiles")
+            or qsadictmodules.QSADictModules.orm_("flsettings")()
+        )
+        model_settings.flkey = "sha_flfiles"
+        model_settings.valor = sha_flfolder
+        if not model_settings.save():
+            LOGGER.error("Error saving sha_flfiles")
+            return
+
+        LOGGER.warning("Update completed. New sha_flfiles:%s" % (sha_flfolder))
