@@ -4,13 +4,12 @@ QSADictModules.
 Manages read and writting QSA dynamic properties that are loaded during project startup.
 """
 
-
 from pineboolib.application import xmlaction, proxy, safeqsa
 from pineboolib import logging, application
+from pineboolib.core import garbage_collector
 
-import sqlalchemy
+import sqlalchemy  # type: ignore [import]
 import gc
-
 from typing import Any, Optional, Union, TYPE_CHECKING
 
 LOGGER = logging.get_logger(__name__)
@@ -19,6 +18,12 @@ if TYPE_CHECKING:
     from pineboolib.application.database.orm import basemodel
 
 
+class QSADictModulesThread:
+    """QSADictModulesThread class."""
+
+    pass
+
+
 class QSADictModules:
     """
     Manage read and write dynamic properties for QSA.
@@ -44,10 +49,12 @@ class QSADictModules:
         Return project object for given name.
         """
         module_name = "sys_module" if script_name == "sys" else script_name
+        # limpieza de objetos
+        garbage_collector.register_script_name(script_name)
 
         ret_ = getattr(cls.qsa_dict_modules(), module_name, None)
         if ret_ is None and not module_name.endswith("orm"):
-            LOGGER.warning("Module %s not found!", module_name)
+            LOGGER.debug("Module %s not found!", module_name)
 
         return ret_
 
