@@ -75,7 +75,7 @@ class SysBaseType(object):
     @classmethod
     def isDebuggerEnabled(cls) -> bool:
         """Check if this debugger is on."""
-        return bool(application.PROJECT._db_admin_mode)
+        return bool(application.PROJECT.db_admin_mode)
 
     @classmethod
     def isQuickBuild(cls) -> bool:
@@ -218,7 +218,10 @@ class SysBaseType(object):
                 conn_db._is_open = True
 
         else:
-            LOGGER.warning("addDatabase: '%s' connection is already open", conn_name)
+            LOGGER.debug(
+                "addDatabase: '%s' connection is already open",
+                conn_name if conn_name else driver_or_conn,
+            )
 
         return True
 
@@ -359,7 +362,7 @@ class SysBaseType(object):
         application.PROJECT.message_manager().send("msgBoxWarning", None, new_list)
 
     @classmethod
-    def errorMsgBox(cls, msg: str = None) -> None:
+    def errorMsgBox(cls, msg: Optional[str] = None) -> None:
         """Show error message box."""
         msg = ustr(msg)
         msg += "\n"
