@@ -5,6 +5,7 @@ Tests for application.types module.
 import unittest
 import os
 from pineboolib.loader.main import init_cli
+from pineboolib.loader.main import init_testing, finish_testing
 from pineboolib.core import settings
 from pineboolib.application import types
 
@@ -47,6 +48,11 @@ class TestQString(unittest.TestCase):
 class TestFunction(unittest.TestCase):
     """Test function. Parses QSA into Python."""
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        """Ensure test clear all data."""
+        finish_testing()
+
     def test_basic(self) -> None:
         """Basic testing."""
         source = "return x + 1"
@@ -92,6 +98,11 @@ class TestFunction(unittest.TestCase):
         result = fun_([data])
         self.assertEqual(result, 30)
 
+    @classmethod
+    def setUpClass(cls) -> None:
+        """Ensure pineboo is initialized for testing."""
+        init_testing()
+
 
 class TestObject(unittest.TestCase):
     """Test object."""
@@ -370,7 +381,7 @@ class TestFile(unittest.TestCase):
         )
         contenido = "Texto escrito en bytes\n".encode("utf-8")
         types.File(temporal).write(contenido)
-        contenido_2 = types.File(temporal).read(True)
+        contenido_2 = types.File(temporal).read()
         self.assertEqual(contenido, contenido_2.encode("utf-8"))
         os.remove(temporal)
 
@@ -383,7 +394,7 @@ class TestFile(unittest.TestCase):
         )
         contenido = "Texto\n".encode("utf-8")
         types.File(temporal).write(contenido)
-        contenido_2 = types.File(temporal).read(True)
+        contenido_2 = types.File(temporal).read()
         self.assertEqual(contenido, contenido_2.encode("utf-8"))
         os.remove(temporal)
 
