@@ -1,6 +1,7 @@
 """
 Data Types for QSA.
 """
+
 import codecs
 
 import os
@@ -10,16 +11,14 @@ import collections
 from PyQt6 import QtCore  # type: ignore [import]
 
 from pineboolib.core.utils import utils_base
-from pineboolib.core import decorators, settings
+from pineboolib.core import decorators
 
 from pineboolib.application.qsatypes.date import Date  # noqa: F401
-
+from pineboolib.application.utils import modules
 from pineboolib import logging
 
-from typing import Any, Optional, Dict, Union, Generator, List, TYPE_CHECKING
+from typing import Any, Optional, Dict, Union, Generator, List
 
-if TYPE_CHECKING:
-    from importlib.machinery import ModuleSpec
 
 LOGGER = logging.get_logger(__name__)
 
@@ -78,14 +77,13 @@ def function(*args: str) -> Any:
     Parses it to Python and return the pointer to the function.
     """
 
-    import sys as python_sys
-
     # Leer código QS embebido en Source
     # asumir que es una funcion anónima, tal que:
     #  -> function($args) { source }
     # compilar la funcion y devolver el puntero
-    arguments = args[: len(args) - 1]
-    source = args[len(args) - 1]
+    source_pos = len(args) - 1
+    arguments = args[:source_pos]
+    source = args[source_pos]
     qs_source = """
 
 function anon(%s) {
@@ -95,43 +93,9 @@ function anon(%s) {
         source,
     )
 
-    # print("Compilando QS en línea: ", qs_source)
-    from pineboolib.application.parsers.parser_qsa import flscriptparse, postparse, pytnyzer
-    from importlib import util
+    module = modules.text_to_module(qs_source)
 
-    module_name = "anon_%s" % QtCore.QDateTime.currentDateTime().toString("ddMMyyyyhhmmsszzz")
-
-    prog = flscriptparse.parse(qs_source)
-    if prog is None:
-        raise ValueError("Failed to convert to Python")
-    tree_data = flscriptparse.calctree(prog, alias_mode=0)
-    ast = postparse.post_parse(tree_data)
-    dest_filename = "%s/%s.py" % (
-        settings.CONFIG.value("ebcomportamiento/temp_dir"),
-        module_name,
-    )
-    # f1 = io.StringIO()
-    if os.path.exists(dest_filename):
-        os.remove(dest_filename)
-
-    file_ = open(dest_filename, "w", encoding="UTF-8")
-
-    pytnyzer.write_python_file(file_, ast)
-    file_.close()
-    module = None
-    module_path = "tempdata.%s" % (module_name)
-
-    spec: Optional["ModuleSpec"] = util.spec_from_file_location(module_path, dest_filename)
-    if spec and spec.loader is not None:
-        module = util.module_from_spec(spec)
-        python_sys.modules[spec.name] = module
-        spec.loader.exec_module(module)  # type: ignore [attr-defined]
-    else:
-        raise Exception("Module named %s can't be loaded from %s" % (module_path, dest_filename))
-
-    forminternalobj = getattr(module, "FormInternalObj", None)
-    # os.remove(dest_filename)
-    return getattr(forminternalobj(), "anon", None)
+    return module.anon
 
 
 def object_(value: Optional[Dict[str, Any]] = None) -> "utils_base.StructMyDict":
@@ -252,12 +216,10 @@ class Array(object):
         new_dict = {}
 
         if len(args) == 2:  # Delete
-
             for key in list(self._dict.keys())[args[0] : args[0] + args[1]]:
                 new_dict[key] = self._dict[key]
 
         elif len(args) > 2 and args[1] == 0:  # Insertion
-
             fix_pos = 0
             for pos in range(len(self._dict.keys())):
                 new_dict[pos + fix_pos] = self._dict[pos]
@@ -267,7 +229,6 @@ class Array(object):
                         new_dict[pos + fix_pos] = new_value
 
         elif len(args) > 2 and args[1] > 0:  # Replacement
-
             for pos, key in enumerate(self._dict.keys()):
                 if pos == args[0]:
                     for new_value in args[2:]:
@@ -362,7 +323,7 @@ class Dir(object):
     def entryList(
         self,
         patron: str,
-        type_: "QtCore.QDir.Filter" = QtCore.QDir.Filter.NoFilter,
+        filter: "QtCore.QDir.Filter" = QtCore.QDir.Filter.NoFilter,
         sort: "QtCore.QDir.SortFlag" = QtCore.QDir.SortFlag.NoSort,
     ) -> list:
         """
@@ -371,22 +332,7 @@ class Dir(object):
         @param patron. Patron a usa para identificar los ficheros
         @return lista con los ficheros que coinciden con el patrón
         """
-        # p = os.walk(self.path)
-        retorno: List[str] = []
-        try:
-            import fnmatch
-
-            if self.path is None:
-                raise ValueError("self.path is not defined!")
-
-            if os.path.exists(self.path):
-                for file in os.listdir(self.path):
-                    if fnmatch.fnmatch(file, patron):
-                        retorno.append(file)
-        except Exception as exception:
-            print("Dir_Class.entryList:", exception)
-
-        return retorno
+        return QtCore.QDir(self.path).entryList([patron], filter, sort)  # type: ignore [arg-type]
 
     @staticmethod
     def fileExists(file_name: str) -> bool:
@@ -577,7 +523,7 @@ class File(FileBaseClass):  # FIXME : Rehacer!!
         """Return error string."""
         return self._q_file.errorString()
 
-    def read(self, bytes: bool = False) -> str:
+    def read(self, bytes_: bool = False) -> str:
         """
         Read file completely.
 
@@ -587,8 +533,10 @@ class File(FileBaseClass):  # FIXME : Rehacer!!
 
         if not self._file_name:
             raise ValueError("self._file_name is not defined!")
-
-        file_ = codecs.open(self._file_name, "r" if not bytes else "rb", encoding=self._encode)
+        if not bytes_:
+            file_ = codecs.open(self._file_name, "r", encoding=self._encode)
+        else:
+            file_ = open(self._file_name, "rb")  # type: ignore [assignment] # noqa: F821
         ret = file_.read()
         file_.close()
         self.eof = True
@@ -596,7 +544,7 @@ class File(FileBaseClass):  # FIXME : Rehacer!!
 
     def readAll(self) -> str:
         """Read file completely."""
-        return self.read()
+        return self.read(True)
 
     def write(self, data: Union[str, bytes], length: int = -1) -> None:
         """
@@ -814,7 +762,7 @@ class FileStatic(FileBaseClass):
         return file.remove()
 
     @staticmethod
-    def read(file_: str, bytes: bool = False) -> str:
+    def read(file_: str, bytes: bool = False) -> Union[str, bytes]:
         """
         Read file completely.
 
