@@ -2,7 +2,6 @@
 Collect information from the query, such as field tables, lines, etc ...
 """
 
-
 from pineboolib import application, logging
 from pineboolib.application.database import utils
 
@@ -21,6 +20,7 @@ class SqlInspector(object):
 
     _sql_list: List[str]
     _sql: str
+    _sql_original: str
     _invalid_tables: List[str]
     _mtd_fields: Dict[int, "ifieldmetadata.IFieldMetaData"]
     _field_list: Dict[str, int]
@@ -30,13 +30,13 @@ class SqlInspector(object):
     _list_sql: List[str]
 
     _suspected_injection: Optional[str]
-    _suspicious_keywords: List[str] = [
-        "ASCII(",
-        "SUBSTRING(",
-        "SELECT",
-        "COALESCE",
-        "CAST",
-        "CHARACTER",
+    _suspicious_keywords: List[str] = [  # en minuscula!!
+        "ascii(",
+        "substring(",
+        "select",
+        "coalesce",
+        "cast(",
+        "character",
         "/**/",
         "current_database()",
         "::text",
@@ -65,6 +65,7 @@ class SqlInspector(object):
         Initialize the class.
         """
         self._sql = ""
+        self._sql_original = ""
         self._list_sql = []
         self._field_list = {}
         self._table_names = []
@@ -164,6 +165,7 @@ class SqlInspector(object):
 
     def set_sql(self, sql: str) -> None:
         """Set sql query."""
+        self._sql_original = sql
         sql = sql.lower()
         sql = sql.replace("\n", " ")
         sql = sql.replace("\t", " ")
@@ -242,7 +244,9 @@ class SqlInspector(object):
         """
         for k in self._field_list.keys():
             if int(self._field_list[k]) == pos:
-                return k
+                idx_inicio = self._sql.find(k)
+                return self._sql_original[idx_inicio : idx_inicio + len(k)]
+
         raise Exception("fieldName not found! %s")
 
     def _resolve_fields(self) -> None:
@@ -272,7 +276,6 @@ class SqlInspector(object):
             inicio_parentesis: List[str] = []
             composed_field: Dict[str, List[str]] = {}
             for field in list(fields_list):
-
                 # Comprueba si hay field_names compuestos
                 if (field.find("(") > -1 and not field.find(")") > -1) or field in [
                     "case",
@@ -302,9 +305,7 @@ class SqlInspector(object):
                     or field == "end"
                     and inicio_parentesis
                 ):  # si es multiple de verdad
-
                     if field == "end":
-
                         composed_field[inicio_parentesis[-1]].append(field)
                         if len(inicio_parentesis) == 1:
                             new_fields_list.append(" ".join(composed_field[inicio_parentesis[-1]]))
@@ -338,7 +339,6 @@ class SqlInspector(object):
                                 break
 
                 elif inicio_parentesis:  # si estoy en medio de un multiple
-
                     composed_field[inicio_parentesis[-1]].append(field)
                 else:
                     new_fields_list.append(field)
@@ -384,16 +384,22 @@ class SqlInspector(object):
             # next_is_alias = None
             prev_ = ""
             last_was_table = False
+            and_ = False
             for table in tables_list:
                 if table == "cast":
                     jump += 3
                     last_was_table = False
 
                 if jump > 0:
-                    jump -= 1
-                    prev_ = table
-                    last_was_table = False
-                    continue
+                    if and_ and jump == 2 and len(table) > 2:  # entra si = <= > is ...
+                        jump = 0
+                        and_ = False
+                        last_was_table = False
+                    else:
+                        jump -= 1
+                        prev_ = table
+                        last_was_table = False
+                        continue
 
                 if table.find(")") > -1:
                     last_was_table = False
@@ -420,12 +426,12 @@ class SqlInspector(object):
                     continue
 
                 elif table == "as":
-
                     last_was_table = True
                     continue
 
                 elif table in ("and", "or"):
                     jump = 3
+                    and_ = table == "and"
                     last_was_table = False
 
                 else:
@@ -536,7 +542,6 @@ class SqlInspector(object):
                     type_ = field_metadata.type()
 
         if type_ == "pixmap":
-
             if application.PROJECT.conn_manager is None:
                 raise Exception("Project is not connected yet")
 
@@ -567,8 +572,6 @@ class SqlInspector(object):
         if application.PROJECT.conn_manager is None:
             raise Exception("Project is not connected yet")
 
-        db_admin = application.PROJECT._db_admin_mode
-
         _filter = ["sum(", "max(", "distint("]
 
         self._mtd_fields = {}
@@ -580,9 +583,7 @@ class SqlInspector(object):
             self._field_list[field_name_org] = number_
             field_name = field_name_org
             for table_name in list(tables_list):
-                mtd_table = application.PROJECT.conn_manager.manager().metadata(
-                    table_name, not db_admin
-                )
+                mtd_table = application.PROJECT.conn_manager.manager().metadata(table_name)
                 mtd_field = None
                 if mtd_table is not None:
                     for fil in _filter:
@@ -624,17 +625,15 @@ class SqlInspector(object):
         infected = ""
 
         # 1 concatenado.
-        for word in where:
-            if len(word) > 30:
-                contador = [
-                    suspicious_word
-                    for suspicious_word in self._suspicious_keywords
-                    if suspicious_word.lower() in word.lower()
-                ]
-                if len(contador) > 1:
-                    infected = word
-                    break
-
+        for word in (item for item in where if len(item) > 30):
+            word_lower = word.lower()
+            if [
+                suspicious_word
+                for suspicious_word in self._suspicious_keywords
+                if suspicious_word in word_lower
+            ]:
+                infected = word
+                break
         # 2 bypass
         if not infected:
             rep = dict((re.escape(character), "") for character in self._suspicious_characters)
