@@ -224,7 +224,6 @@ def ustr(*full_text: Union[bytes, str, int, "Date", None, float]) -> str:
     """Convert and concatenate types to text."""
 
     def ustr1(text_: Union[bytes, str, int, "Date", None, float]) -> str:
-
         if isinstance(text_, str):
             return text_
 
@@ -294,15 +293,15 @@ def load2xml(form_path_or_str: str) -> ElementTree.ElementTree:
 
     try:
         parser = ElementTree.XMLParser()
-        return ElementTree.parse(file_ptr or form_path_or_str, parser)
+        return ElementTree.parse(file_ptr or form_path_or_str, parser)  # type: ignore [return-value]
     except Exception:
         try:
             parser = ElementTree.XMLParser(encoding="ISO-8859-15")
-            return ElementTree.parse(file_ptr or form_path_or_str, parser)
+            return ElementTree.parse(file_ptr or form_path_or_str, parser)  # type: ignore [return-value]
         except Exception:
-            LOGGER.exception(
+            """LOGGER.exception(
                 "Error cargando UI después de intentar con UTF8 e ISO \n%s", form_path_or_str
-            )
+            )"""
             raise
 
 
@@ -310,26 +309,30 @@ def _parse_for_duplicates(text: str) -> str:
     """load2xml helper for Kugar XML."""
     ret_ = ""
     text = text.replace("+", "__PLUS__")
+    text = text.replace("-", "__MINUS__")
     text = text.replace("(", "__LPAREN__")
     text = text.replace(")", "__RPAREN__")
     text = text.replace("*", "__ASTERISK__")
 
     for section_orig in text.split(">"):
         # print("section", section)
+        if "<!__MINUS____MINUS__" in section_orig:
+            continue
+
         duplicate_ = False
         attr_list: List[str] = []
 
         # print("--->", section_orig)
         ret2_ = ""
         section = ""
-        for action in section_orig.split(" "):
-
+        for num, action in enumerate(section_orig.split(" ")):
             count_ = action.count("=")
             if count_ > 1:
                 # part_ = ""
                 text_to_process = action
                 for item in range(count_):
                     pos_ini = text_to_process.find('"')
+
                     pos_fin = text_to_process[pos_ini + 1 :].find('"')
                     # print("Duplicado", item, pos_ini, pos_fin, text_to_process, "***" , text_to_process[0:pos_ini + 2 + pos_fin])
                     ret2_ += " %s " % text_to_process[0 : pos_ini + 2 + pos_fin]
@@ -350,7 +353,6 @@ def _parse_for_duplicates(text: str) -> str:
         section = section.replace('= "', '="')
 
         for attribute_ in section.split(" "):
-
             # print("attribute", attribute_)
             if attribute_.find("=") > -1:
                 attr_name = attribute_[0 : attribute_.find("=")]
@@ -372,10 +374,20 @@ def _parse_for_duplicates(text: str) -> str:
 
             duplicate_ = False
 
-        if (section.find(">") == -1 and section.find("<") > -1) or section.endswith("--"):
+        if (section.find(">") == -1 and section.find("<") > -1) or section.endswith(
+            "__MINUS____MINUS__"
+        ):
             ret_ += ">"
 
     # print(ret_)
+    ret_ = ret_.replace(">__MINUS____MINUS__", ">")
+    ret_ = ret_.replace(" __", "__BLANCK__")
+    ret_ = ret_.replace("__ ", "__BLANCK__")
+    ret_ = ret_.replace('"__', '" __')
+    ret_ = ret_.replace('__"', '__ "')
+    # ret_ = ret_.replace('=" __', '"__')
+    # ret_ = ret_.replace('__ "', '__"')
+
     return ret_
 
 
@@ -504,11 +516,6 @@ def pixmap_from_mime_source(name: str) -> Any:
     return QtGui.QPixmap(file_name) if os.path.exists(file_name) else None
 
 
-def sha1(text_: str) -> str:
-    """Get SHA1 hash from string in hex form."""
-    return hashlib.sha1(str(text_).encode("UTF-8")).hexdigest()
-
-
 def print_stack(maxsize: int = 1) -> None:
     """Print Python stack, like a traceback."""
     for item in traceback.format_list(traceback.extract_stack())[1:-2][-maxsize:]:
@@ -531,3 +538,18 @@ def empty_dir(dir_name: str) -> None:
     for root, dirs, files in os.walk(dir_name):
         for file_item in files:
             os.remove(os.path.join(root, file_item))
+
+
+def sha1(value: Union[str, bytes, None] = "") -> str:
+    """Return sha1 value."""
+
+    if value is None:
+        value = ""
+
+    if isinstance(value, str):
+        value = value.encode()
+
+    sha_ = hashlib.new("sha1", value)
+    string = "%s" % sha_.hexdigest()
+
+    return string.upper()
