@@ -22,10 +22,10 @@ LOGGER = logging.get_logger(__name__)
 class TableType(Enum):
     """TableType class."""
 
-    Tables: int = 1  # pylint: disable=invalid-name
-    SystemTables: int = 2  # pylint: disable=invalid-name
-    Views: int = 3  # pylint: disable=invalid-name
-    AllTables: int = 0  # pylint: disable=invalid-name
+    Tables = 1  # pylint: disable=invalid-name
+    SystemTables = 2  # pylint: disable=invalid-name
+    Views = 3  # pylint: disable=invalid-name
+    AllTables = 0  # pylint: disable=invalid-name
 
 
 class AQSql(object):
@@ -106,16 +106,16 @@ class AQSql(object):
         table_or_cursor: Union[str, "isqlcursor.ISqlCursor"],
         fields: Union[List[str], types.Array],
         values: Union[List[Any], types.Array],
-        where: str = "",
         conn: str = "default",
     ):
         """Insert a record in a cursor."""
         cur: "isqlcursor.ISqlCursor"
 
-        if isinstance(table_or_cursor, str):
-            cur = pnsqlcursor.PNSqlCursor(table_or_cursor, conn)
-        else:
-            cur = table_or_cursor
+        cur = (
+            pnsqlcursor.PNSqlCursor(table_or_cursor, conn)
+            if isinstance(table_or_cursor, str)
+            else table_or_cursor
+        )
 
         if not cur.metadata():
             return False
