@@ -9,7 +9,9 @@ from typing import Optional
 class FLCheckBox(qcheckbox.QCheckBox):
     """FLCheckBox class."""
 
-    def __init__(self, parent: Optional["QtWidgets.QWidget"] = None, num_rows: int = None) -> None:
+    def __init__(
+        self, parent: Optional["QtWidgets.QWidget"] = None, num_rows: Optional[int] = None
+    ) -> None:
         """Inicialize."""
         super().__init__(parent)
         self.setContentsMargins(0, 0, 0, 0)
