@@ -69,6 +69,7 @@ class FLManager(QtCore.QObject, IManager):
         self._cache_action = {}
         QtCore.QTimer.singleShot(100, self.init)
         self.init_count_ += 1
+        self._util = flutil.FLUtil()
 
     def init(self) -> None:
         """
@@ -123,20 +124,20 @@ class FLManager(QtCore.QObject, IManager):
         @return A PNTableMetaData object with the metadata of the requested table
         """
 
-        if not metadata_name_or_xml:
+        if metadata_name_or_xml in (None, ""):
             return None
 
         if not self.db_:
             raise Exception("metadata. self.db_ is empty!")
 
-        util = flutil.FLUtil()
+        if not quick:
+            quick = not application.PROJECT.db_admin_mode
 
         # if quick is None:
         #    dbadmin = settings.CONFIG.value("application/dbadmin_enabled", False)
         #    quick = not bool(dbadmin)
 
         if isinstance(metadata_name_or_xml, str):
-
             ret: Optional["pntablemetadata.PNTableMetaData"] = None
             acl: Optional["pnaccesscontrollists.PNAccessControlLists"] = None
             key = metadata_name_or_xml.strip()
@@ -147,7 +148,6 @@ class FLManager(QtCore.QObject, IManager):
             if table_name in self.cache_metadata_.keys():
                 ret = copy.copy(self.cache_metadata_[table_name])
             if not ret:
-
                 # Buscamos primero si es un model_.
                 model_name = (
                     metadata_name_or_xml[: metadata_name_or_xml.find(".mtd")]
@@ -156,7 +156,7 @@ class FLManager(QtCore.QObject, IManager):
                 )
                 model_ = qsadictmodules.QSADictModules.from_project("%s_orm" % model_name)
                 if model_ is not None:
-                    ret = self.metadata(model_.legacy_metadata)
+                    ret = self.metadata(model_.legacy_metadata, quick)
                 else:  # extraer datos del mtd (modo clásico)
                     # LOGGER.warning("metadata %s from xml is deprecated", metadata_name_or_xml)
                     stream = self.db_.connManager().managerModules().contentCached(table_name)
@@ -165,7 +165,7 @@ class FLManager(QtCore.QObject, IManager):
                         if metadata_name_or_xml.find("alteredtable") == -1:
                             LOGGER.info(
                                 "FLManager : "
-                                + util.translate(
+                                + self._util.translate(
                                     "FLManager",
                                     "Error al cargar los metadatos para la tabla %s"
                                     % metadata_name_or_xml,
@@ -201,7 +201,7 @@ class FLManager(QtCore.QObject, IManager):
                     else:
                         if self.db_.mismatchedTable(metadata_name_or_xml, ret):
                             if ret.name():
-                                msg = util.translate(
+                                msg = self._util.translate(
                                     "application",
                                     "La estructura de los metadatos de la %s '%s'"
                                     " y su estructura interna en la base de datos no coinciden.\n"
@@ -235,7 +235,6 @@ class FLManager(QtCore.QObject, IManager):
             return ret
 
         elif isinstance(metadata_name_or_xml, dict):
-
             meta_dict = metadata_name_or_xml
 
             name = meta_dict["name"]
@@ -246,11 +245,13 @@ class FLManager(QtCore.QObject, IManager):
             ftsfun = meta_dict["ftsfunction"] if "ftsfunction" in meta_dict.keys() else ""
             concur_warn = meta_dict["concurwarn"] if "concurwarn" in meta_dict.keys() else False
             detect_locks = meta_dict["detectlocks"] if "detectlocks" in meta_dict.keys() else False
+            cached_fields = meta_dict["cachedfields"] if "cachedfields" in meta_dict.keys() else ""
 
             table_metadata = pntablemetadata.PNTableMetaData(name, alias, query)
             table_metadata.setFTSFunction(ftsfun)
             table_metadata.setConcurWarn(concur_warn)
             table_metadata.setDetectLocks(detect_locks)
+            table_metadata.setCachedFields(cached_fields)
 
             compound_key = pncompoundkeymetadata.PNCompoundKeyMetaData()
             assocs = []
@@ -281,6 +282,7 @@ class FLManager(QtCore.QObject, IManager):
             editable = True
             concur_warn = False
             detect_locks = False
+            cached_fields = ""
             child_list: List["ElementTree.Element"] = []
             for child in metadata_name_or_xml:
                 if child.tag == "field":
@@ -290,7 +292,7 @@ class FLManager(QtCore.QObject, IManager):
                 elif child.tag == "query":
                     query = child.text or ""
                 elif child.tag == "alias":
-                    alias = util.translate(
+                    alias = self._util.translate(
                         "Metadata", utils_base.auto_qt_translate_text(child.text)
                     )
                 elif child.tag == "visible":
@@ -303,12 +305,17 @@ class FLManager(QtCore.QObject, IManager):
                     concur_warn = child.text == "true"
                 elif child.tag == "FTSFunction":
                     ftsfun = child.text or ""
+                elif child.tag == "cachedfields":
+                    cached_fields = child.text or ""
+                    if cached_fields:
+                        LOGGER.warning("MTD(%s): cachedfields found :%s" % (name, cached_fields))
 
             table_metadata = pntablemetadata.PNTableMetaData(name, alias, query)
 
             table_metadata.setFTSFunction(ftsfun)
             table_metadata.setConcurWarn(concur_warn)
             table_metadata.setDetectLocks(detect_locks)
+            table_metadata.setCachedFields(cached_fields)
 
             compound_key = pncompoundkeymetadata.PNCompoundKeyMetaData()
             assocs = []
@@ -434,7 +441,6 @@ class FLManager(QtCore.QObject, IManager):
         if action_name in self._cache_action.keys():
             pnaction_ = self._cache_action[action_name]
         else:
-
             pnaction_ = convert_flaction.convert_to_flaction(action_name)
             if not pnaction_.table():
                 pnaction_.setTable(action_name)
@@ -491,7 +497,6 @@ class FLManager(QtCore.QObject, IManager):
                 return False
 
             for field1 in [field for field in metadata_or_name.fieldList() if not field.isCheck()]:
-
                 field2 = metadata2.field(field1.name())
                 if field2 is None:
                     return False
@@ -545,7 +550,7 @@ class FLManager(QtCore.QObject, IManager):
             raise Exception("createTable. self.db_ is empty!")
 
         if isinstance(metadata_or_name, str):
-            metadata_or_name = self.metadata(metadata_or_name, False)
+            metadata_or_name = self.metadata(metadata_or_name)
 
         if metadata_or_name is None:
             return None
@@ -603,8 +608,8 @@ class FLManager(QtCore.QObject, IManager):
         Return the value content of a formatted field to be recognized by the current database, within the SQL WHERE closing.
 
         This method takes as parameters the field metadata defined with
-        PNFieldMetaData. In addition to TRUE and FALSE as possible values ​​of a field
-        logical also accepts the values ​​Yes and No (or its translation into the corresponding language).
+        PNFieldMetaData. In addition to TRUE and FALSE as possible values of a field
+        logical also accepts the values Yes and No (or its translation into the corresponding language).
         The dates are adapted to the YYYY-MM-DD form, which is the format recognized by PostgreSQL.
 
         @param field_metadata PNFieldMetaData object that describes the metadata for the field
@@ -619,7 +624,6 @@ class FLManager(QtCore.QObject, IManager):
         upper_: bool = args[2]
 
         if isinstance(args_0, pnfieldmetadata.PNFieldMetaData):
-
             field_name_ = args_0.name()
             type_ = args_0.type()
 
@@ -709,9 +713,7 @@ class FLManager(QtCore.QObject, IManager):
                         qry = self.query(mtd.query())
 
                         if qry:
-
                             for field in qry.fieldList():
-
                                 field_section_ = field
                                 pos = field.find(".")
                                 if pos > -1:
@@ -731,7 +733,6 @@ class FLManager(QtCore.QObject, IManager):
                 upper_ = args[2]
 
             elif len(args) == 2:
-
                 field_name_ = args[0].name()
                 field_type_ = args[0].type()
                 value_ = args[1]
@@ -784,7 +785,7 @@ class FLManager(QtCore.QObject, IManager):
         @param ed Value used by default for editable property
         @return PNFieldMetaData object that contains the description of the field
         """
-        if not field:
+        if field in (None, ""):  # type: ignore [comparison-overlap]
             raise ValueError("field is required")
 
         valid_types = [
@@ -803,7 +804,6 @@ class FLManager(QtCore.QObject, IManager):
             "timestamp",
             "json",
         ]
-        util = flutil.FLUtil()
 
         compound_key = False
         name: str = ""
@@ -996,7 +996,7 @@ class FLManager(QtCore.QObject, IManager):
 
         field_mtd = pnfieldmetadata.PNFieldMetaData(
             name,
-            util.translate("Metadata", alias),
+            self._util.translate("Metadata", alias),
             as_null,
             is_primary_key,
             type_,
@@ -1043,7 +1043,6 @@ class FLManager(QtCore.QObject, IManager):
                 field_mtd.setAssociatedField(assoc_with, assoc_by)
 
         else:
-
             for child in field:
                 tag = child.tag
                 if tag == "relation":
@@ -1076,7 +1075,7 @@ class FLManager(QtCore.QObject, IManager):
         @param relation XML element with the description of the relationship
         @return FLRelationMetaData object that contains the description of the relationship
         """
-        if not relation:
+        if relation in (None, ""):
             raise ValueError("relation is required")
 
         foreign_table = ""
@@ -1095,7 +1094,6 @@ class FLManager(QtCore.QObject, IManager):
             while not node.isNull():
                 elem = node.toElement()
                 if not elem.isNull():
-
                     if elem.tagName() == "table":
                         foreign_table = elem.text()
                         node = node.nextSibling()
@@ -1239,7 +1237,6 @@ class FLManager(QtCore.QObject, IManager):
         if not self.db_:
             raise Exception("cleanupMetaData. self.db_ is empty!")
 
-        # util = flutil.FLUtil()
         if not self.existsTable("flfiles") or not self.existsTable("flmetadata"):
             return
 
@@ -1273,13 +1270,13 @@ class FLManager(QtCore.QObject, IManager):
         while qry2.next():
             table = str(qry2.value(0))
             table = table.replace(".mtd", "")
-            tmd = self.metadata(table)
+            tmd = self.metadata(table, True)
             if not self.existsTable(table):
                 self.createTable(table)
             if not tmd:
                 LOGGER.warning(
                     "FLManager::cleanupMetaData %s",
-                    flutil.FLUtil().translate(
+                    self._util.translate(
                         "application", "No se ha podido crear los metadatatos para la tabla %s"
                     )
                     % table,
@@ -1324,7 +1321,7 @@ class FLManager(QtCore.QObject, IManager):
         self, mtd: "pntablemetadata.PNTableMetaData", large_value: str
     ) -> Optional[str]:
         """
-        Store large field values ​​in separate indexed tables by SHA keys of the value content.
+        Store large field values in separate indexed tables by SHA keys of the value content.
 
         It is used to optimize queries that include fields with large values,
         such as images, to handle the reference to the value in the SQL queries
@@ -1371,8 +1368,7 @@ class FLManager(QtCore.QObject, IManager):
                 if not self.createTable(mtd_large):
                     return None
 
-        util = flutil.FLUtil()
-        sha = str(util.sha1(large_value))
+        sha = str(self._util.sha1(large_value))
         ref_key = "RK@%s@%s" % (table_name, sha)
         qry = pnsqlquery.PNSqlQuery(None, "dbAux")
         qry.setSelect("refkey")
@@ -1404,7 +1400,6 @@ class FLManager(QtCore.QObject, IManager):
         @return Large value stored
         """
         if ref_key and ref_key[0:3] == "RK@":
-
             table_name = (
                 "fllarge"
                 if application.PROJECT.aq_app.singleFLLarge()
