@@ -87,7 +87,7 @@ class FLManagerModules(object):
     Informacion para la carga estatica desde el disco local
     """
     static_db_info_: "pnmodulesstaticloader.AQStaticBdInfo"
-    _file_watcher: "observers.Observer"
+    _file_watcher: "observers.Observer"  # type: ignore [valid-type]
     root_dir_: str
     scripts_dir_: str
     tables_dir_: str
@@ -97,12 +97,12 @@ class FLManagerModules(object):
     trans_dir_: str
     _files_cached: Dict[str, str]
 
-    def __init__(self, db: "iconnection.IConnection") -> None:
+    def __init__(self, db_: "iconnection.IConnection") -> None:
         """Inicialize."""
 
-        if db is None:
+        if db_ is None:
             raise ValueError("Database is required")
-        self.conn_ = db
+        self.conn_ = db_
 
         self.commonInit()
         self.active_id_module_ = ""
@@ -128,12 +128,12 @@ class FLManagerModules(object):
             if flfiles_folder and application.USE_FLFILES_FOLDER_AS_STATIC_LOAD:
                 LOGGER.warning("USING FLFILES_FOLDER AS STATIC LOAD FOLDER!")
                 num_folders += 1 if self.addFolder(flfiles_folder, event_handler) else 0
-            else:
-                self.static_db_info_.readSettings()
-                for dir_path in self.static_db_info_.dirs_:
-                    LOGGER.warning("STATIC LOAD: %s IS %s", dir_path.path_, dir_path.active_)
-                    if dir_path.active_:
-                        num_folders += 1 if self.addFolder(dir_path.path_, event_handler) else 0
+
+            self.static_db_info_.readSettings()
+            for dir_path in self.static_db_info_.dirs_:
+                LOGGER.warning("STATIC LOAD: %s IS %s", dir_path.path_, dir_path.active_)
+                if dir_path.active_:
+                    num_folders += 1 if self.addFolder(dir_path.path_, event_handler) else 0
 
             if num_folders > 0:
                 event_handler.on_any_event = self.static_db_info_.msg_static_changed  # type: ignore [assignment]
@@ -145,7 +145,7 @@ class FLManagerModules(object):
         """Add folder."""
 
         if os.path.exists(folder):
-            self._file_watcher.schedule(event_handler, folder, recursive=True)
+            self._file_watcher.schedule(event_handler, folder, recursive=True)  # type: ignore [attr-defined]
         else:
             LOGGER.warning("STATIC LOAD: %s FOLDER DOESN'T EXISTS !" % folder)
             return False
@@ -156,7 +156,7 @@ class FLManagerModules(object):
         """Reload static loader."""
         pnmodulesstaticloader.SHOW_REINIT_MESSAGE = True
         if hasattr(self, "_file_watcher"):
-            self._file_watcher.stop()
+            self._file_watcher.stop()  # type: ignore [attr-defined]
             del self._file_watcher
         del self.static_db_info_
 
@@ -370,8 +370,8 @@ class FLManagerModules(object):
 
         root_ = tree.getroot()
 
-        ui_version = root_.get("version") or "1.0"
-        wid = root_.find("widget")
+        ui_version = root_.get("version") or "1.0"  # type: ignore [union-attr]
+        wid = root_.find("widget")  # type: ignore [union-attr]
         geometry = []
 
         if wid is not None:
@@ -390,7 +390,6 @@ class FLManagerModules(object):
                     break
 
         if parent is None:
-
             if wid is None:
                 raise Exception("No parent provided and also no <widget> found")
             xclass = wid.get("class")
