@@ -1,6 +1,6 @@
 """Flutil module."""
+
 # -*- coding: utf-8 -*-
-import hashlib
 import datetime
 import glob
 from datetime import date
@@ -11,6 +11,7 @@ from pineboolib.application.qsatypes import sysbasetype
 from pineboolib.application.utils import date_conversion
 from pineboolib.application.database import utils, pnsqlquery
 from pineboolib.application import types
+from pineboolib.core.utils import utils_base
 
 from pineboolib.core import decorators, translate, settings
 from pineboolib import logging, application
@@ -264,7 +265,6 @@ class FLUtil(object):
             buffer = "Sólo hay capacidad hasta mil millones"
 
         elif num < 1000000:
-
             buffer = cls.centenamillar(int(num))
 
         else:
@@ -303,15 +303,12 @@ class FLUtil(object):
             res = "%s %s" % (cls.enLetra(entero), currency)
 
             if decimal > 0:
-
                 res += " con %s céntimos" % cls.enLetra(decimal)
 
         if entero <= 0 and decimal > 0:
-
             res = "%s céntimos" % cls.enLetra(decimal)
 
         if num < 0.00:
-
             res = "menos %s" % res
 
         return res.upper()
@@ -687,7 +684,7 @@ class FLUtil(object):
         @return Setting value
         """
 
-        return settings.SETTINGS.value(key, def_)
+        return settings.CONFIG.value(key, def_)
 
     @classmethod
     def writeSettingEntry(cls, key: str, value: Any) -> None:
@@ -700,7 +697,7 @@ class FLUtil(object):
         @return Indicator if the writing of the settings is successful
         """
 
-        return settings.SETTINGS.set_value(key, value)
+        return settings.CONFIG.set_value(key, value)
 
     @classmethod
     def readDBSettingEntry(cls, key: str) -> Any:
@@ -736,20 +733,10 @@ class FLUtil(object):
 
         where = "flkey = '%s'" % key
         found = cls.readDBSettingEntry(key)
-        session_ = application.PROJECT.conn_manager.useConn("default").session()
-        if found is None:
-            sql = "INSERT INTO flsettings (flkey, valor) VALUES ('%s', '%s')" % (key, value)
+        if found:
+            return cls.sqlUpdate("flsettins", ["flkey", "valor"], [key, value], where)
         else:
-            sql = "UPDATE flsettings SET valor = '%s' WHERE %s" % (value, where)
-        try:
-            session_.execute(sql)
-
-        except Exception:
-            LOGGER.exception("writeDBSettingEntry: Error al ejecutar SQL: %s", sql)
-            return False
-
-        # session_.close()
-        return True
+            return cls.sqlInsert("flsettings", ["flkey", "valor"], [key, value])
 
     @classmethod
     def roundFieldValue(
@@ -769,7 +756,8 @@ class FLUtil(object):
         if metadata is not None:
             field_metadata = metadata.field(field_name)
             if field_metadata is not None:
-                return cls.buildNumber(value or 0.00, "float", field_metadata.partDecimal())
+                # value = 0.00 if math.isnan(value) else value
+                return cls.buildNumber(value, "float", field_metadata.partDecimal())
 
         return ""
 
@@ -997,15 +985,7 @@ class FLUtil(object):
         @param str String from which to obtain the SHA1 key.
         @return Corresponding key in hexadecimal digits.
         """
-        if value is None:
-            value = ""
-
-        if isinstance(value, str):
-            value = value.encode()
-
-        sha_ = hashlib.new("sha1", value)
-        string = "%s" % sha_.hexdigest()
-        return string.upper()
+        return utils_base.sha1(value)
 
     @classmethod
     @decorators.not_implemented_warn
@@ -1184,7 +1164,7 @@ class FLUtil(object):
         @param field_name. Field Name.
         @param table_name. Name of the table containing the field.
         @param conn_name. Name of the connection to use.
-        @return Alias ​​of the specified field.
+        @return Alias of the specified field.
         """
         conn = application.PROJECT.conn_manager.useConn(conn_name)
         metadata = conn.connManager().manager().metadata(table_name)
@@ -1200,7 +1180,7 @@ class FLUtil(object):
 
         @param table_name. Table name
         @param conn_name. Name of the connection to use
-        @return Alias ​​of the specified table
+        @return Alias of the specified table
         """
         conn = application.PROJECT.conn_manager.useConn(conn_name)
         metadata = conn.connManager().manager().metadata(table_name)
@@ -1217,7 +1197,7 @@ class FLUtil(object):
         @param alias. Field Name
         @param table_name. Name of the table containing the field
         @param conn_name. Name of the connection to use
-        @return Alias ​​of the specified field
+        @return Alias of the specified field
         """
         conn = application.PROJECT.conn_manager.useConn(conn_name)
         metadata = conn.connManager().manager().metadata(table_name)
