@@ -22,7 +22,7 @@ if TYPE_CHECKING:
         pnaction,
     )
     from pineboolib.interfaces import iconnection  # pragma: no cover
-    import sqlalchemy  # type: ignore [import] # noqa: F821 # pragma: no cover
+    from sqlalchemy.ext import declarative  # type: ignore [import]
 
 
 class ICursorPrivate(QtCore.QObject):
@@ -195,6 +195,7 @@ class ICursorPrivate(QtCore.QObject):
     _id_acos = 0
     _id_cond = 0
     id_ = "000"
+    _init_orm: bool = False
 
     """ Uso interno """
     _is_system_table: bool
@@ -233,7 +234,7 @@ class ICursorPrivate(QtCore.QObject):
 
         pass  # pragma: no cover
 
-    def needUpdate(self) -> bool:
+    def needUpdate(self) -> bool:  # type: ignore [empty-body]
         """Indicate if the cursor needs to be updated."""
 
         pass  # pragma: no cover
@@ -326,10 +327,11 @@ class ISqlCursor(QtCore.QObject):
     transactionEnd: QtCore.pyqtSignal = QtCore.pyqtSignal()
     transactionRollback: QtCore.pyqtSignal = QtCore.pyqtSignal()
 
-    _cursor_model: "sqlalchemy.ext.declarative.api.DeclarativeMeta"
+    _cursor_model: "declarative.DeclarativeMeta"
 
     _is_delegate_commit: bool
     _last_delegate_commit_result: bool
+    _persistent_filter_deletegate: Optional[str]
 
     def __init__(
         self,
@@ -347,7 +349,7 @@ class ISqlCursor(QtCore.QObject):
         """Initialize cursor."""
         pass  # pragma: no cover
 
-    def conn(self) -> "iconnection.IConnection":
+    def conn(self) -> "iconnection.IConnection":  # type: ignore [empty-body]
         """Retrieve connection object."""
         pass  # pragma: no cover
 
@@ -359,15 +361,15 @@ class ISqlCursor(QtCore.QObject):
         """Set cursor name."""
         pass  # pragma: no cover
 
-    def metadata(self) -> "pntablemetadata.PNTableMetaData":
+    def metadata(self) -> "pntablemetadata.PNTableMetaData":  # type: ignore [empty-body]
         """Get table metadata for this cursor table."""
         pass  # pragma: no cover
 
-    def currentRegister(self) -> int:
+    def currentRegister(self) -> int:  # type: ignore [empty-body]
         """Get current row number."""
         pass  # pragma: no cover
 
-    def modeAccess(self) -> int:
+    def modeAccess(self) -> int:  # type: ignore [empty-body]
         """Get current access mode."""
         pass  # pragma: no cover
 
@@ -375,7 +377,7 @@ class ISqlCursor(QtCore.QObject):
         """Get SQL filter as a string."""
         return ""
 
-    def mainFilter(self) -> str:
+    def mainFilter(self) -> str:  # type: ignore [empty-body]
         """Get SQL Main filter as a string."""
         pass  # pragma: no cover
 
@@ -383,11 +385,11 @@ class ISqlCursor(QtCore.QObject):
         """Get action object."""
         pass  # pragma: no cover
 
-    def actionName(self) -> str:
+    def actionName(self) -> str:  # type: ignore [empty-body]
         """Get action name."""
         pass  # pragma: no cover
 
-    def setAction(self, action) -> bool:
+    def setAction(self, action) -> bool:  # type: ignore [empty-body]
         """Set Action object."""
         pass  # pragma: no cover
 
@@ -399,7 +401,7 @@ class ISqlCursor(QtCore.QObject):
         """Set Access mode for the cursor."""
         pass  # pragma: no cover
 
-    def connectionName(self) -> str:
+    def connectionName(self) -> str:  # type: ignore [empty-body]
         """Get current connection name."""
         pass  # pragma: no cover
 
@@ -447,27 +449,27 @@ class ISqlCursor(QtCore.QObject):
         """Get script execution context."""
         pass  # pragma: no cover
 
-    def fieldDisabled(self, field_name) -> bool:
+    def fieldDisabled(self, field_name) -> bool:  # type: ignore [empty-body]
         """Get if field is disabled."""
         pass  # pragma: no cover
 
-    def inTransaction(self) -> bool:
+    def inTransaction(self) -> bool:  # type: ignore [empty-body]
         """Return if transaction is in progress."""
         pass  # pragma: no cover
 
-    def transaction(self, lock=False) -> bool:
+    def transaction(self, lock=False) -> bool:  # type: ignore [empty-body]
         """Open transaction."""
         pass  # pragma: no cover
 
-    def rollback(self) -> bool:
+    def rollback(self) -> bool:  # type: ignore [empty-body]
         """Rollback transaction."""
         pass  # pragma: no cover
 
-    def commit(self, notify=True) -> bool:
+    def commit(self, notify=True) -> bool:  # type: ignore [empty-body]
         """Commit transaction."""
         pass  # pragma: no cover
 
-    def size(self) -> int:
+    def size(self) -> int:  # type: ignore [empty-body]
         """Get current cursor size in rows."""
         pass  # pragma: no cover
 
@@ -475,7 +477,7 @@ class ISqlCursor(QtCore.QObject):
         """Open record form in specified mode."""
         pass  # pragma: no cover
 
-    def isNull(self, field_name) -> bool:
+    def isNull(self, field_name) -> bool:  # type: ignore [empty-body]
         """Get if field is null."""
         pass  # pragma: no cover
 
@@ -483,7 +485,7 @@ class ISqlCursor(QtCore.QObject):
         """Refresh buffer copy."""
         pass  # pragma: no cover
 
-    def isModifiedBuffer(self) -> bool:
+    def isModifiedBuffer(self) -> bool:  # type: ignore [empty-body]
         """Get if buffer is modified."""
         pass  # pragma: no cover
 
@@ -495,7 +497,7 @@ class ISqlCursor(QtCore.QObject):
         """Activate integrity checks."""
         pass  # pragma: no cover
 
-    def activatedCheckIntegrity(self) -> bool:
+    def activatedCheckIntegrity(self) -> bool:  # type: ignore [empty-body]
         """Get integrity check state."""
         pass  # pragma: no cover
 
@@ -503,7 +505,7 @@ class ISqlCursor(QtCore.QObject):
         """Activate before/after commit."""
         pass  # pragma: no cover
 
-    def activatedCommitActions(self) -> bool:
+    def activatedCommitActions(self) -> bool:  # type: ignore [empty-body]
         """Get before/after commit status."""
         pass  # pragma: no cover
 
@@ -519,15 +521,15 @@ class ISqlCursor(QtCore.QObject):
         """Set unlock field."""
         pass  # pragma: no cover
 
-    def isLocked(self) -> bool:
+    def isLocked(self) -> bool:  # type: ignore [empty-body]
         """Get if record is locked."""
         pass  # pragma: no cover
 
-    def buffer(self) -> "pnbuffer.PNBuffer":
+    def buffer(self) -> "pnbuffer.PNBuffer":  # type: ignore [empty-body]
         """Get buffer object."""
         pass  # pragma: no cover
 
-    def bufferCopy(self) -> "pnbuffer.PNBuffer":
+    def bufferCopy(self) -> "pnbuffer.PNBuffer":  # type: ignore [empty-body]
         """Get buffer copy."""
         pass  # pragma: no cover
 
@@ -535,11 +537,11 @@ class ISqlCursor(QtCore.QObject):
         """Set field to null."""
         pass  # pragma: no cover
 
-    def db(self) -> "iconnection.IConnection":
+    def db(self) -> "iconnection.IConnection":  # type: ignore [empty-body]
         """Return database object."""
         pass  # pragma: no cover
 
-    def curName(self) -> str:
+    def curName(self) -> str:  # type: ignore [empty-body]
         """Get cursor name."""
         pass  # pragma: no cover
 
@@ -547,11 +549,11 @@ class ISqlCursor(QtCore.QObject):
         """Retrieve filter for associated field."""
         pass  # pragma: no cover
 
-    def calculateField(self, field_name) -> bool:
+    def calculateField(self, field_name) -> bool:  # type: ignore [empty-body]
         """Return the result of a field calculation."""
         pass  # pragma: no cover
 
-    def model(self) -> "pncursortablemodel.PNCursorTableModel":
+    def model(self) -> "pncursortablemodel.PNCursorTableModel":  # type: ignore [empty-body]
         """Get sqlAlchemy model."""
         pass  # pragma: no cover
 
@@ -559,11 +561,11 @@ class ISqlCursor(QtCore.QObject):
         """Get selection."""
         pass  # pragma: no cover
 
-    def at(self) -> int:
+    def at(self) -> int:  # type: ignore [empty-body]
         """Get row number."""
         pass  # pragma: no cover
 
-    def isValid(self) -> bool:
+    def isValid(self) -> bool:  # type: ignore [empty-body]
         """Return if cursor is valid."""
         pass  # pragma: no cover
 
@@ -571,43 +573,43 @@ class ISqlCursor(QtCore.QObject):
         """Refresh cursor."""
         pass  # pragma: no cover
 
-    def refreshBuffer(self) -> bool:
+    def refreshBuffer(self) -> bool:  # type: ignore [empty-body]
         """Refresh buffer."""
         pass  # pragma: no cover
 
-    def setEditMode(self) -> bool:
+    def setEditMode(self) -> bool:  # type: ignore [empty-body]
         """Set cursor in edit mode."""
         pass  # pragma: no cover
 
-    def seek(self, i, relative=None, emite=None) -> bool:
+    def seek(self, i, relative=None, emite=None) -> bool:  # type: ignore [empty-body]
         """Move cursor without fetching."""
         pass  # pragma: no cover
 
-    def next(self, emite=True) -> bool:
+    def next(self, emite=True) -> bool:  # type: ignore [empty-body]
         """Get next row."""
         pass  # pragma: no cover
 
-    def moveby(self, pos) -> bool:
+    def moveby(self, pos) -> bool:  # type: ignore [empty-body]
         """Move cursor down "pos" rows."""
         pass  # pragma: no cover
 
-    def prev(self, emite=True) -> bool:
+    def prev(self, emite=True) -> bool:  # type: ignore [empty-body]
         """Get previous row."""
         pass  # pragma: no cover
 
-    def move(self, row) -> bool:
+    def move(self, row) -> bool:  # type: ignore [empty-body]
         """Move cursor to row number."""
         pass  # pragma: no cover
 
-    def first(self, emite=True) -> bool:
+    def first(self, emite=True) -> bool:  # type: ignore [empty-body]
         """Move cursor to first row."""
         pass  # pragma: no cover
 
-    def last(self, emite=True) -> bool:
+    def last(self, emite=True) -> bool:  # type: ignore [empty-body]
         """Move cursor to last row."""
         pass  # pragma: no cover
 
-    def select(self, _filter=None, sort=None) -> bool:
+    def select(self, _filter=None, sort=None) -> bool:  # type: ignore [empty-body]
         """Perform SQL Select."""
         pass  # pragma: no cover
 
@@ -643,19 +645,19 @@ class ISqlCursor(QtCore.QObject):
         """Set forward only."""
         pass  # pragma: no cover
 
-    def commitBuffer(self, emite=True, check_locks=False) -> bool:
+    def commitBuffer(self, emite=True, check_locks=False) -> bool:  # type: ignore [empty-body]
         """Commit current buffer to db."""
         pass  # pragma: no cover
 
-    def commitBufferCursorRelation(self) -> bool:
+    def commitBufferCursorRelation(self) -> bool:  # type: ignore [empty-body]
         """Commit buffer from cursor relation."""
         pass  # pragma: no cover
 
-    def transactionLevel(self) -> int:
+    def transactionLevel(self) -> int:  # type: ignore [empty-body]
         """Get number of nested transactions."""
         pass  # pragma: no cover
 
-    def transactionsOpened(self) -> List[str]:
+    def transactionsOpened(self) -> List[str]:  # type: ignore [empty-body]
         """Return if any transaction is open."""
         pass  # pragma: no cover
 
@@ -667,31 +669,27 @@ class ISqlCursor(QtCore.QObject):
         """Return if in commit."""
         pass  # pragma: no cover
 
-    def checkIntegrity(self, show_error: bool = True) -> bool:
+    def checkIntegrity(self, show_error: bool = True) -> bool:  # type: ignore [empty-body]
         """Return check integrity result."""
         pass  # pragma: no cover
 
-    def checkRisksLocks(self, terminate: bool = False) -> bool:
+    def checkRisksLocks(self, terminate: bool = False) -> bool:  # type: ignore [empty-body]
         """Return risks locks result."""
 
         pass  # pragma: no cover
 
-    def msgCheckIntegrity(self) -> str:
+    def msgCheckIntegrity(self) -> str:  # type: ignore [empty-body]
         """Return msg check integrity."""
 
         pass  # pragma: no cover
 
-    def aqWasDeleted(self) -> bool:
+    def aqWasDeleted(self) -> bool:  # type: ignore [empty-body]
         """Indicate if the cursor has been deleted."""
 
         pass  # pragma: no cover
 
-    def concurrencyFields(self) -> List[str]:
-        """
-        Check if there is a collision of fields edited by two sessions simultaneously.
-
-        @return List with the names of the colliding fields
-        """
+    def concurrencyFields(self) -> List[str]:  # type: ignore [empty-body]
+        """Return list of concurrency fields."""
 
         pass  # pragma: no cover
 
@@ -769,3 +767,18 @@ class ISqlCursor(QtCore.QObject):
         """Retorna si se cumplen las condiciones para usar delegateCommit."""
 
         return False
+
+    def setPersistentFilterDelegate(self, filter: str) -> None:
+        """Añade a persistent filter datos de delegate."""
+
+        pass
+
+    def restorePersistentFilterBeforeDelegate(self):
+        """Restaura persistent filter despues de hacer commit."""
+
+        pass
+
+    def setInitOrm(self, initorm: bool) -> None:
+        """Set init orm."""
+
+        pass
