@@ -23,7 +23,7 @@ from sqlalchemy.engine import base, create_engine  # type: ignore [import] # noq
 from sqlalchemy.inspection import inspect  # type: ignore [import] # noqa: F821, F401
 from sqlalchemy.orm import sessionmaker  # type: ignore [import] # noqa: F821
 
-from sqlalchemy import event, pool, text
+from sqlalchemy import event, pool, text  # type: ignore [import]
 import sqlalchemy  # type: ignore [import] # noqa: F821, F401
 import traceback
 
@@ -63,7 +63,7 @@ class ISqlDriver(object):
     mobile_: bool
     pure_python_: bool
     default_port: int
-    cursor_proxy: Dict[str, "result.ResultProxy"]
+    cursor_proxy: Dict[str, "result.Result"]  # type: ignore [name-defined]
     open_: bool
     desktop_file: bool
     _true: Union[str, bool]
@@ -333,7 +333,7 @@ class ISqlDriver(object):
                 LOGGER.warning("Conexión invalida capturada.Solicitando nueva")
 
         setattr(new_session, "_conn_name", self.db_._name)
-        return new_session
+        return new_session  # type: ignore [return-value]
 
     def connection(self) -> "base.Connection":
         """Return a cursor connection."""
@@ -420,7 +420,7 @@ class ISqlDriver(object):
 
     def canRegenTables(self) -> bool:
         """Return if can regenerate tables."""
-        return True
+        return application.PROJECT.db_admin_mode
 
     def nextSerialVal(self, table_name: str, field_name: str) -> int:
         """Return next serial value."""
@@ -463,11 +463,7 @@ class ISqlDriver(object):
             )
 
         if str_qry:
-            try:
-                self.execute_query(str_qry)
-            except Exception as error:
-                LOGGER.error("nextSerialVal: %s", str(error))
-                self.session().rollback()
+            self.execute_query(str_qry)
 
         return res_
 
@@ -557,7 +553,7 @@ class ISqlDriver(object):
             if application.USE_MISMATCHED_VIEWS:
                 qry = pnsqlquery.PNSqlQuery(table_name)
                 names = qry.select().split(",")
-                if not len(metadata.fieldNames()):
+                if len(metadata.fieldNames()) == 0:
                     return False
 
                 for name in names:
@@ -724,6 +720,12 @@ class ISqlDriver(object):
     def alterTable(self, new_metadata: "pntablemetadata.PNTableMetaData") -> bool:
         """Modify a table structure."""
 
+        if not application.ALLOW_ALTER_TABLE:
+            LOGGER.warning(
+                "ALTER TABLE DESHABILITADO",
+            )
+            return False
+
         if self.hasCheckColumn(new_metadata):
             return False
 
@@ -738,7 +740,7 @@ class ISqlDriver(object):
 
         renamed_table = "%salteredtable%s" % (
             table_name,
-            QtCore.QDateTime().currentDateTime().toString("ddhhssz"),
+            QtCore.QDateTime.currentDateTime().toString("ddhhssz"),
         )
 
         query = pnsqlquery.PNSqlQuery(None, "dbAux")
@@ -836,7 +838,6 @@ class ISqlDriver(object):
             session_.rollback()
             result_insert_multi = False
         else:
-
             session_.commit()
 
             if new_metadata.name() not in self.tables("Views"):
@@ -866,25 +867,25 @@ class ISqlDriver(object):
     #    """Return if use a file like database."""
     #    return self.desktop_file
 
-    def execute_query(self, query: str) -> Optional["result.ResultProxy"]:
+    def execute_query(self, query: str) -> Optional["result.Result"]:  # type: ignore [name-defined]
         """Excecute a query and return result."""
 
         if not self.is_open():
-            raise Exception("execute_query: Database not open %s", self)
+            raise Exception("execute_query: Database not open %s" % self)
 
         self.set_last_error_null()
         session_ = self.db_.session()
-        result_ = None
+
         try:
             try:
                 if query.find("::bytea") > -1:
-                    result_ = (  # Esto es necesario para no obtener error en la consulta con los bytearray
+                    return (  # Esto es necesario para no obtener error en la consulta con los bytearray
                         session_.connection()
                         .execution_options(autocommit=True)
                         .execute("""%s""" % query)
                     )
                 else:
-                    result_ = session_.execute(text("""%s""" % query))
+                    return session_.execute(text("""%s""" % query))
             except sqlalchemy.exc.DBAPIError as error:
                 LOGGER.warning(
                     "Se ha producido un error DBAPI con la consulta %s. Ejecutando rollback necesario",
@@ -906,7 +907,7 @@ class ISqlDriver(object):
             )
             self.set_last_error("No se pudo ejecutar la query %s.\n%s" % (query, str(error)), query)
 
-        return result_
+        return None
 
     def getTimeStamp(self) -> str:
         """Return TimeStamp."""
@@ -944,7 +945,6 @@ class ISqlDriver(object):
             field_values = []
             for field, value in line:
                 if field.generated():
-
                     if field.type() in ("string", "stringlist", "bytearray"):
                         value = self.normalizeValue(value)
 
@@ -1021,7 +1021,6 @@ class ISqlDriver(object):
         )
 
         for number, table_fllarge in enumerate(fllarge_tables_list):
-
             util.setLabelText(util.translate("application", "Revisando tabla %s" % table_fllarge))
 
             sql = "SELECT refkey FROM %s WHERE 1 = 1" % table_fllarge
@@ -1253,7 +1252,6 @@ class ISqlDriver(object):
         limit_conn = mng_.limit_connections
 
         if self.pool_enabled():
-
             LOGGER.info("SqlAlchemy pool enabled")
             self._queqe_params["poolclass"] = pool.QueuePool
             self._queqe_params["pool_size"] = limit_conn
