@@ -1,7 +1,7 @@
 """Main module for starting up Pineboo."""
 
-
 from pineboolib import application, logging
+from pineboolib.application.utils import external
 
 from pineboolib.core import settings
 
@@ -9,6 +9,7 @@ from pineboolib.loader import dgi as dgi_module
 from pineboolib.loader import connection
 from pineboolib.core.utils import utils_base
 
+
 import gc
 import sys
 import shutil
@@ -40,7 +41,7 @@ def startup_framework(conn: Optional["projectconfig.ProjectConfig"] = None) -> N
     import pyfiglet  # type: ignore
 
     qapp = call_qapplication(sys.argv + ["-platform", "offscreen"])
-    init_logging(True)
+    init_logging(True, application.FRAMEWORK_DEBUG_LEVEL)
     init_cli(catch_ctrl_c=False)
 
     LOGGER.info(
@@ -49,13 +50,6 @@ def startup_framework(conn: Optional["projectconfig.ProjectConfig"] = None) -> N
         )
     )
 
-    debug_level = 200
-    if application.DEVELOPER_MODE:
-        LOGGER.warning("Developer mode activated")
-        debug_level = 1000
-
-    application.PROJECT.setDebugLevel(debug_level)
-
     application.PROJECT.set_app(qapp)
     dgi = dgi_module.load_dgi("qt", None)
     application.PROJECT.init_dgi(dgi)
@@ -68,10 +62,12 @@ def startup_framework(conn: Optional["projectconfig.ProjectConfig"] = None) -> N
     if not application.PROJECT.init_conn(connection=conn_):
         raise Exception("No main connection was established. Aborting Pineboo load.")
 
+    external.load_project_config_file()
+
     _initialize_data(True)
 
 
-def startup(enable_gui: bool = None) -> None:
+def startup(enable_gui: Optional[bool] = None) -> None:
     """Start up pineboo."""
     # FIXME: No hemos cargado pineboo aún. No se pueden usar métodos internos.
     from pineboolib.core.utils import check_dependencies
@@ -101,8 +97,18 @@ def startup(enable_gui: bool = None) -> None:
         trace_loggers = options.trace_loggers.split(",")
 
     init_logging(logtime=options.log_time, loglevel=options.loglevel, trace_loggers=trace_loggers)
-    if application.DEVELOPER_MODE:
-        LOGGER.info("Developer mode activated")
+
+    if options.project_name:
+        application.PROJECT_NAME = options.project_name
+
+    if options.external:
+        if not os.path.exists(options.external):
+            LOGGER.error("External: %s is not a valid directory", options.external)
+            sys.exit(1)
+        LOGGER.info("External: Adding %s to sys.path", options.external)
+        sys.path.insert(0, options.external)
+        application.EXTERNAL_FOLDER = options.external
+        external.load_project_config_file()
 
     ret = exec_main_with_profiler(options) if options.enable_profiler else exec_main(options)
 
@@ -200,7 +206,7 @@ def init_cli(catch_ctrl_c: bool = True) -> None:
     # es bastante incómodo y genera problemas graves para detectar el problema.
     # Agregamos sys.excepthook para controlar esto y hacer que PyQt6 no nos
     # dé un segfault, aunque el resultado no sea siempre correcto:
-    sys.excepthook = _excepthook
+    sys.excepthook = _excepthook  # type: ignore[assignment]
     # -------------------
     if catch_ctrl_c:
         # Fix Control-C / KeyboardInterrupt for PyQt:
@@ -322,7 +328,6 @@ def finish_testing(delete_tmpdir: bool = True) -> None:
     if delete_tmpdir:
         LOGGER.warning("Deleting temp folder %s", application.PROJECT.tmpdir)
         try:
-
             shutil.rmtree(application.PROJECT.tmpdir)
         except Exception as error:
             LOGGER.warning(
@@ -343,14 +348,12 @@ def exec_main(options: "optparse.Values") -> int:
     Also initializes all the objects
     """
 
+    if options.external_modules:
+        LOGGER.warn("Using external modules from %s", options.external_modules)
+        sys.path.insert(0, options.external_modules)
+
     init_cli()
 
-    # TODO: Refactorizar función en otras más pequeñas
-
-    application.PROJECT.setDebugLevel(options.debug_level)
-
-    # application.PROJECT.options = options
-
     app_args: List[str] = sys.argv
     if not options.enable_gui:
         app_args += ["-platform", "offscreen"]
@@ -359,6 +362,10 @@ def exec_main(options: "optparse.Values") -> int:
     application.USE_INTERACTIVE_GUI = options.enable_interactive_gui
     application.ENABLE_CALL_EXCEPTIONS = options.enable_call_exceptions
     application.PARSE_PROJECT_ON_INIT = options.parse_project_on_init
+    if options.omit_no_python_tags:
+        from pineboolib.application.parsers import parser_qsa
+
+        parser_qsa.IGNORE_NO_PYTHON_TAGS = True
 
     application.PROJECT.set_app(call_qapplication(app_args))
 
@@ -370,6 +377,8 @@ def exec_main(options: "optparse.Values") -> int:
 
     if options.flfiles_folder:
         application.PROJECT.USE_FLFILES_FOLDER = options.flfiles_folder
+        if options.update_flfiles:
+            application.UPDATE_FLFILES_FROM_FLFOLDER = True
 
     if options.trace_debug:
         # "sys.settrace" function could lead to arbitrary code execution
@@ -381,10 +390,10 @@ def exec_main(options: "optparse.Values") -> int:
         monkey_patch_connect()
 
     if options.enable_dbadmin:
-        application.PROJECT._db_admin_mode = True
+        application.PROJECT.db_admin_mode = True
         settings.CONFIG.set_value("application/dbadmin_enabled", True)
     if options.enable_quick:
-        application.PROJECT._db_admin_mode = False
+        application.PROJECT.db_admin_mode = False
         settings.CONFIG.set_value("application/dbadmin_enabled", False)
 
     if options.enable_preping:
@@ -438,7 +447,7 @@ def exec_main(options: "optparse.Values") -> int:
             if configdb is None:
                 return 2
         else:
-            application.PROJECT._db_admin_mode = True
+            application.PROJECT.db_admin_mode = True
             settings.CONFIG.set_value("application/dbadmin_enabled", True)
             configdb = connection.DEFAULT_SQLITE_CONN
 
@@ -505,9 +514,7 @@ def _initialize_data(is_framework: bool = False) -> None:
 
     if is_framework:
         LOGGER.info("STARTUP_FRAMEWORK:(3/7) Loading database.")
-    if not application.PROJECT.run():
-        if not application.DEVELOPER_MODE:
-            raise Exception("Project initialization failed!")
+    application.PROJECT.run()
 
     from pineboolib.application.acls import pnaccesscontrollists
 
