@@ -34,9 +34,6 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
         self.error_list = []
         self.alias_ = "SQL Server (PYMSSQL)"
         self.default_port = 1433
-        self.savepoint_command = "SAVE TRANSACTION"
-        self.rollback_savepoint_command = "ROLLBACK TRANSACTION"
-        self.commit_transaction_command = "COMMIT"
         self._like_true = "1"
         self._like_false = "0"
         self._safe_load = {"pymssql": "pymssql", "sqlalchemy": "sqlAlchemy"}
@@ -85,7 +82,7 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
         if self.is_open():
             cur = self.execute_query("SELECT NEXT VALUE FOR %s_%s_seq" % (table_name, field_name))
 
-            if cur and cur.returns_rows:
+            if cur and cur.returns_rows:  # type: ignore [attr-defined]
                 return cur.fetchone()[0]  # type: ignore [index] # noqa: F821
 
             LOGGER.warning("not exec sequence")
@@ -147,7 +144,6 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
 
         unlocks = 0
         for number, field in enumerate(field_list):
-
             sql += field.name()
             type_ = field.type()
             if type_ == "serial":
@@ -198,7 +194,6 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
                         % (primary_key, tmd.name(), field.name(), sql)
                     )
             else:
-
                 sql += " UNIQUE" if field.isUnique() else ""
                 sql += " NULL" if field.allowNull() else " NOT NULL"
 
@@ -241,7 +236,6 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
         table_list: List[str] = []
         result_list: List[Any] = []
         if self.is_open():
-
             where: List[str] = []
             if type_name in ("Tables", ""):
                 where.append("xtype ='U'")
@@ -265,7 +259,7 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
 
     def declareCursor(
         self, curname: str, fields: str, table: str, where: str, conn_db: "base.Connection"
-    ) -> Optional["result.ResultProxy"]:
+    ):
         """Set a refresh query for database."""
 
         if not self.is_open():
@@ -285,8 +279,6 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
             LOGGER.info("SQL: %s", sql)
             LOGGER.trace("Detalle:", stack_info=True)
 
-        return None
-
     def deleteCursor(self, cursor_name: str, cursor: Any) -> None:
         """Delete cursor."""
 
@@ -314,7 +306,7 @@ class FLPYMSSQL(isqldriver.ISqlDriver):
     def alterTable(self, new_metadata: "pntablemetadata.PNTableMetaData") -> bool:
         """Modify a table structure."""
 
-        return True
+        return False
 
     def recordInfo2(self, tablename: str) -> Dict[str, List[Any]]:
         """Return info from a database table."""
