@@ -1,11 +1,13 @@
 """
 Utility functions for QS files.
 """
+
 import traceback
 import re
 import math
 import sys
 import threading
+import json
 import os
 
 from PyQt6 import QtCore
@@ -114,6 +116,11 @@ class QsaRegExp(object):
         """Set regex global flag."""
         self.is_global = state
 
+    def exactMatch(self, value: str) -> Optional[Match[str]]:
+        """Return exactMatch."""
+
+        return self.pattern.fullmatch(value)
+
     global_ = property(get_global, set_global)
 
 
@@ -217,7 +224,7 @@ class MathClass(object):
         """Raise base to the power of exp."""
         return math.pow(base_, exp)
 
-    def round(self, value_1: float, value_2: int = 2) -> float:
+    def round(self, value_1: float, value_2: Optional[int] = None) -> float:
         """Round a number x to y decimal places."""
         return round(float(value_1), value_2)
 
@@ -311,7 +318,7 @@ def parse_float(value: Any) -> float:
 
         return ret
     except Exception:
-        LOGGER.exception("parseFloat: Error converting %s to float", value)
+        LOGGER.exception("parseFloat: Error converting %s to float" % value, stack_info=True)
         return float("nan")
 
 
@@ -387,7 +394,7 @@ def text(obj: Any) -> str:
 
 def start_timer(time: int, fun: Callable) -> "QtCore.QTimer":
     """Create new timer that calls a function."""
-    global TIMERS
+    global TIMERS  # noqa: F824
     timer = QtCore.QTimer()
     timer.timeout.connect(fun)  # type: ignore [attr-defined] # noqa: F821
     timer.start(time)
@@ -397,7 +404,7 @@ def start_timer(time: int, fun: Callable) -> "QtCore.QTimer":
 
 def kill_timer(timer: Optional["QtCore.QTimer"] = None) -> None:
     """Stop a given timer."""
-    global TIMERS
+    global TIMERS  # noqa: F824
     if timer is not None:
         timer.stop()
         TIMERS.remove(timer)
@@ -435,7 +442,7 @@ def is_nan(value: Any) -> bool:
     @param x. Valor numérico
     @return True o False
     """
-    if value in [None, ""]:
+    if value in [None, ""] or isinstance(value, bool):
         return True
 
     if isinstance(value, str) and value.find(":"):
@@ -478,7 +485,6 @@ def splice(*args: Any) -> Any:
                     array_.pop(i)
 
             elif len(real_args) > 2 and real_args[1] == 0:  # Insertion
-
                 for value in reversed(real_args[2:]):
                     array_.insert(real_args[0], value)
 
@@ -523,7 +529,6 @@ class Sort:
             for pos, value in enumerate(array_):
                 found = False
                 for new_pos, new_value in enumerate(list(new_array_)):
-
                     result = self._function(value, new_value)
                     # print("Comparando", value, new_value, result, "-->", new_array_)
                     if result == 0:
@@ -568,7 +573,6 @@ def user_id() -> str:
 
 def set_user_id(user_id: str) -> None:
     """Set user id."""
-
     qsadictmodules.from_project("sys").iface.current_user = user_id
 
 
@@ -672,6 +676,8 @@ def typeof_(obj: Any) -> str:
         result = "number"
     elif isinstance(obj, (dict, list, types.Array)):
         result = "object"
+    elif hasattr(obj, "__call__"):
+        result = "function"
 
     return result
 
@@ -730,3 +736,15 @@ def qt_translate_noop(string: str, path: str, mod: str) -> str:
     """Return a translation."""
 
     return utils_base.qt_translate_noop(string, path, mod)
+
+
+def require(name: str) -> Any:
+    """Return require."""
+
+    return qsadictmodules.from_project("formImport").from_(name)
+
+
+def to_json(text: str) -> Union[Dict, List]:
+    """Return json object from str."""
+    text = text.replace("'", '"')
+    return json.loads(text)
