@@ -1,9 +1,11 @@
 """Sys module."""
+
 # -*- coding: utf-8 -*-
 from pineboolib.qsa import qsa
 import traceback
 from pineboolib import logging
 
+
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -81,7 +83,6 @@ class FormInternalObj(qsa.FormDBWidget):
         """After commit flfiles."""
 
         if cur_files_.modeAccess() != cur_files_.Browse:
-
             value = cur_files_.valueBuffer("sha")
 
             _qry = qsa.FLSqlQuery()
@@ -125,3 +126,54 @@ class FormInternalObj(qsa.FormDBWidget):
         """Return default delegateCommit."""
 
         return qsa.from_project("formHTTP").iface.saveCursor(cursor)
+
+    def controlDatosCacheo(self, cursor: "qsa.FLSqlCursor", updated: int) -> bool:
+        """Return default controlDatosCacheo."""
+
+        from pineboolib import application
+
+        table_name: str = cursor.table()
+        pk_name = cursor.primaryKey()
+        pk_value = cursor.valueBuffer(pk_name)
+
+        if "fldatatables_cache" not in application.PROJECT.actions.keys():
+            qsa.debug("no hay ninguna acción con el nombre de fltadatable_cache")
+            return True
+
+        if table_name.endswith("_cachelite"):
+            qsa.debug("la tabla es _cacheclite")
+            return True
+
+        meta = cursor.metadata()
+
+        if not meta.useCachedFields():
+            qsa.debug("%s no usa cachedfields %s" % (table_name, meta.cachedFields()))
+            return True
+
+        modoAcceso = {
+            2: "Update",
+            1: "Insert",
+            3: "Delete",
+        }
+
+        if updated == 2:
+            registros: str = meta.cachedFields()
+            if registros != "*":
+                camposCacheados = registros.split(",")
+                cambios = False
+                for campo in camposCacheados:
+                    if cursor.valueBuffer(campo) != cursor.valueBufferCopy(campo):
+                        cambios = True
+                        break
+                if not cambios:
+                    qsa.debug("los campos actualizados no son cacheados")
+                    return True
+
+        if not qsa.AQUtil.execSql(
+            "INSERT INTO fldatatables_cache(mode,tablename,pk_value,timestamp) VALUES ('%s', '%s', '%s',CURRENT_TIMESTAMP)"
+            % (modoAcceso[updated], table_name, pk_value)
+        ):
+            qsa.debug("Ha fallado el insert")
+            return False
+
+        return True
